@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2018-2021)
+# Copyright (C) Duncan Macleod (2018-2020)
 #
 # This file is part of GWpy.
 #
@@ -20,7 +20,7 @@
 """Plotting observing segments for O1
 
 The data from the full
-`Observing Run 1 (O1) <https://www.gw-openscience.org/O1/>`__
+`Observing Run 1 (O1) <https://gwosc.org/O1/>`__
 have been released by |GWOSC|_.
 
 This example demonstrates how to download segment information into a
