@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Joseph Areeda (2015-2021)
+# Copyright (C) Joseph Areeda (2015-2020)
 #
 # This file is part of GWpy.
 #
@@ -36,6 +36,7 @@ from ..signal import filter_design
 from ..signal.window import recommended_overlap
 from ..time import to_gps
 from ..timeseries import TimeSeriesDict
+from ..timeseries.timeseries import DEFAULT_FFT_METHOD
 from ..plot.gps import (GPS_SCALES, GPSTransform)
 from ..plot.tex import label_to_latex
 from ..segments import DataQualityFlag
@@ -57,7 +58,7 @@ def timer(func):
     def timed_func(self, *args, **kwargs):  # pylint: disable=missing-docstring
         _start = time.time()
         out = func(self, *args, **kwargs)
-        self.log(2, '{0} took {1:.1f} sec'.format(name, time.time() - _start))
+        self.log(2, f'{name} took {time.time() - _start:.1f} sec')
         return out
 
     return timed_func
@@ -259,13 +260,33 @@ class CliProduct(object, metaclass=abc.ABCMeta):
         """Add an `~argparse.ArgumentGroup` for channel options
         """
         group = parser.add_argument_group(
-            'Data options', 'What data to load')
-        group.add_argument('--chan', type=str, nargs='+', action='append',
-                           required=True, help='channels to load')
-        group.add_argument('--start', type=to_gps, nargs='+', action='append',
-                           help='Starting GPS times (required)')
-        group.add_argument('--duration', type=to_s, default=10,
-                           help='Duration (seconds) [10]')
+            'Data options',
+            'What data to load',
+        )
+        group.add_argument(
+            '--chan',
+            type=str,
+            nargs='+',
+            action='append',
+            required=True,
+            help='channels to load',
+        )
+        group.add_argument(
+            '--start',
+            type=to_gps,
+            nargs='+',
+            action='append',
+            required=True,
+            help=(
+                'one or more starting times (integer GPS or date/time string)'
+            ),
+        )
+        group.add_argument(
+            '--duration',
+            type=to_s,
+            default=10,
+            help='Duration (seconds) [10]',
+        )
         return group
 
     @classmethod
@@ -273,14 +294,29 @@ class CliProduct(object, metaclass=abc.ABCMeta):
         """Add an `~argparse.ArgumentGroup` for data options
         """
         group = parser.add_argument_group(
-            'Data source options', 'Where to get the data')
+            'Data source options',
+            'Where to get the data',
+        )
         meg = group.add_mutually_exclusive_group()
-        meg.add_argument('-c', '--framecache', type=os.path.abspath,
-                         help='read data from cache')
-        meg.add_argument('-n', '--nds2-server', metavar='HOSTNAME',
-                         help='name of nds2 server to use, default is to '
-                         'try all of them')
-        meg.add_argument('--frametype', help='GWF frametype to read from')
+        meg.add_argument(
+            '-c',
+            '--framecache',
+            type=os.path.abspath,
+            help=(
+                'path to a file containing a list of paths '
+                'from which to read data'
+            ),
+        )
+        meg.add_argument(
+            '-n',
+            '--nds2-server',
+            metavar='HOSTNAME',
+            help='name of nds2 server to use, default is to try all of them',
+        )
+        meg.add_argument(
+            '--frametype',
+            help='GWF frametype to read from',
+        )
         return group
 
     @classmethod
@@ -291,12 +327,22 @@ class CliProduct(object, metaclass=abc.ABCMeta):
             'Signal processing options',
             'What to do with the data before plotting'
         )
-        group.add_argument('--highpass', type=to_hz,
-                           help='Frequency for highpass filter')
-        group.add_argument('--lowpass', type=to_hz,
-                           help='Frequency for lowpass filter')
-        group.add_argument('--notch', type=to_hz, nargs='*',
-                           help='Frequency for notch (can give multiple)')
+        group.add_argument(
+            '--highpass',
+            type=to_hz,
+            help='Frequency for highpass filter',
+        )
+        group.add_argument(
+            '--lowpass',
+            type=to_hz,
+            help='Frequency for lowpass filter',
+        )
+        group.add_argument(
+            '--notch',
+            type=to_hz,
+            nargs='*',
+            help='Frequency for notch (can give multiple)',
+        )
         return group
 
     # -- plot options
@@ -306,35 +352,75 @@ class CliProduct(object, metaclass=abc.ABCMeta):
         """Add an `~argparse.ArgumentGroup` for basic plot options
         """
         group = parser.add_argument_group('Plot options')
-        group.add_argument('-g', '--geometry', default='1200x600',
-                           metavar='WxH', help='size of resulting image')
-        group.add_argument('--dpi', type=int, default=rcParams['figure.dpi'],
-                           help='dots-per-inch for figure')
-        group.add_argument('--interactive', action='store_true',
-                           help='when running from ipython '
-                                'allows experimentation')
-        group.add_argument('--title', action='store',
-                           help='Set title (below suptitle, defaults to '
-                                'parameter summary')
-        group.add_argument('--suptitle',
-                           help='1st title line (larger than the others)')
-        group.add_argument('--out', default='gwpy.png',
-                           help='output filename')
+        group.add_argument(
+            '-g',
+            '--geometry',
+            default='1200x600',
+            metavar='WxH',
+            help='size of resulting image',
+        )
+        group.add_argument(
+            '--dpi',
+            type=int,
+            default=rcParams['figure.dpi'],
+            help='dots-per-inch for figure',
+        )
+        group.add_argument(
+            '--interactive',
+            action='store_true',
+            help=(
+                'presents display in an interactive window, see '
+                'https://matplotlib.org/stable/users/explain/'
+                'interactive.html#default-ui for details'
+            ),
+        )
+        group.add_argument(
+            '--title',
+            action='store',
+            help='Set title (below suptitle, defaults to parameter summary',
+        )
+        group.add_argument(
+            '--suptitle',
+            help='topmost title line (larger than the others)',
+        )
+        group.add_argument(
+            '--out',
+            default='gwpy.png',
+            help=(
+                'output filename (extension determines format: '
+                'png, pdf, svg are available)'
+            ),
+        )
 
         # legends match input files in position are displayed if specified.
-        group.add_argument('--legend', nargs='+', action='append', default=[],
-                           help='strings to match data files')
-        group.add_argument('--nolegend', action='store_true',
-                           help='do not display legend')
-        group.add_argument('--nogrid', action='store_true',
-                           help='do not display grid lines')
+        group.add_argument(
+            '--legend',
+            nargs='+',
+            action='append',
+            default=[],
+            help='strings to match data files',
+        )
+        group.add_argument(
+            '--nolegend',
+            action='store_true',
+            help='do not display legend',
+        )
+        group.add_argument(
+            '--nogrid',
+            action='store_true',
+            help='do not display grid lines',
+        )
 
         # allow custom styling with a style file
         group.add_argument(
-            '--style', metavar='FILE',
-            help='path to custom matplotlib style sheet, see '
-                 'http://matplotlib.org/users/style_sheets.html#style-sheets '
-                 'for details of how to write one')
+            '--style',
+            metavar='FILE',
+            help=(
+                'path to custom matplotlib style sheet, see '
+                'http://matplotlib.org/users/style_sheets.html#style-sheets '
+                'for details of how to write one'
+            ),
+        )
         return group
 
     @classmethod
@@ -351,39 +437,55 @@ class CliProduct(object, metaclass=abc.ABCMeta):
 
     @classmethod
     def _arg_axis(cls, axis, parser, **defaults):
-        name = '{} axis'.format(axis.title())
-        group = parser.add_argument_group('{0} options'.format(name))
+        name = f'{axis.title()} axis'
+        group = parser.add_argument_group(f'{name} options')
 
         # label
-        group.add_argument('--{0}label'.format(axis),
-                           default=defaults.get('label'),
-                           dest='{0}label'.format(axis),
-                           help='{0} label'.format(name))
+        group.add_argument(
+            f'--{axis}label',
+            default=defaults.get('label'),
+            dest=f'{axis}label',
+            help=f'{name} label',
+        )
 
         # min and max
         for extrema in ('min', 'max'):
             opt = axis + extrema
-            group.add_argument('--{0}'.format(opt), type=float,
-                               default=defaults.get(extrema), dest=opt,
-                               help='{0} value for {1}'.format(extrema, name))
+            group.add_argument(
+                f'--{opt}',
+                type=float,
+                default=defaults.get(extrema),
+                dest=opt,
+                help=f'{extrema} value for {name}',
+            )
 
         # scale
         scaleg = group.add_mutually_exclusive_group()
-        scaleg.add_argument('--{0}scale'.format(axis), type=str,
-                            default=defaults.get('scale'),
-                            dest='{0}scale'.format(axis),
-                            help='scale for {0}'.format(name))
+        scaleg.add_argument(
+            f'--{axis}scale',
+            type=str,
+            default=defaults.get('scale'),
+            dest=f'{axis}scale',
+            help=f'scale for {name}',
+        )
         if defaults.get('scale') == 'log':
-            scaleg.add_argument('--nolog{0}'.format(axis),
-                                action='store_const',
-                                dest='{0}scale'.format(axis),
-                                const=None, default='log',
-                                help='use logarithmic {0}'.format(name))
+            scaleg.add_argument(
+                f'--nolog{axis}',
+                action='store_const',
+                dest=f'{axis}scale',
+                const=None,
+                default='log',
+                help=f'use linear {name}',
+            )
         else:
-            scaleg.add_argument('--log{0}'.format(axis), action='store_const',
-                                dest='{0}scale'.format(axis),
-                                const='log', default=None,
-                                help='use logarithmic {0}'.format(name))
+            scaleg.add_argument(
+                f'--log{axis}',
+                action='store_const',
+                dest=f'{axis}scale',
+                const='log',
+                default=None,
+                help=f'use logarithmic {name}',
+            )
         return group
 
     def _finalize_arguments(self, args):
@@ -401,17 +503,18 @@ class CliProduct(object, metaclass=abc.ABCMeta):
         """
         # validate number of data sets requested
         if len(self.chan_list) < self.MIN_CHANNELS:
-            raise ValueError('this product requires at least {0} '
-                             'channels'.format(self.MIN_CHANNELS))
+            raise ValueError(
+                f'this product requires at least {self.MIN_CHANNELS} channels'
+            )
         if self.n_datasets < self.MIN_DATASETS:
             raise ValueError(
-                '%d datasets are required for this plot but only %d are '
-                'supplied' % (self.MIN_DATASETS, self.n_datasets)
+                f'{self.MIN_DATASETS} are required for this plot but only '
+                f'{self.n_datasets} are supplied'
             )
         if self.n_datasets > self.MAX_DATASETS:
             raise ValueError(
-                'A maximum of %d datasets allowed for this plot but %d '
-                'specified' % (self.MAX_DATASETS, self.n_datasets)
+                f'A maximum of {self.MAX_DATASETS} datasets allowed for this '
+                f'plot but {self.n_datasets} specified'
             )
 
     # -- data transfer --------------------------
@@ -455,10 +558,12 @@ class CliProduct(object, metaclass=abc.ABCMeta):
                 self.timeseries.append(data)
 
         # report what we have if they asked for it
-        self.log(3, ('Channels: %s' % self.chan_list))
-        self.log(3, ('Start times: %s, duration %s' % (
-            self.start_list, self.duration)))
-        self.log(3, ('Number of time series: %d' % len(self.timeseries)))
+        self.log(3, f'Channels: {self.chan_list}')
+        self.log(
+            3,
+            f'Start times: {self.start_list}, duration {self.duration}',
+        )
+        self.log(3, f'Number of time series: {len(self.timeseries)}')
 
     @staticmethod
     def _filter_timeseries(data, highpass=None, lowpass=None, notch=None):
@@ -506,13 +611,13 @@ class CliProduct(object, metaclass=abc.ABCMeta):
         notch = self.args.notch
         filt = ''
         if highpass and lowpass:
-            filt += "band pass (%.1f-%.1f)" % (highpass, lowpass)
+            filt += f"band pass ({highpass:.1f}-{lowpass:.1f})"
         elif highpass:
-            filt += "high pass (%.1f) " % highpass
+            filt += f"high pass ({highpass:.1f}) "
         elif lowpass:
-            filt += "low pass (%.1f) " % lowpass
+            filt += f"low pass ({lowpass:.1f}) "
         if notch:
-            filt += ', notch ({0})'.format(', '.join(map(str, notch)))
+            filt += f", notch ({', '.join(map(str, notch))})"
         return filt
 
     def get_suptitle(self):
@@ -545,16 +650,16 @@ class CliProduct(object, metaclass=abc.ABCMeta):
         """Generic method to set properties for X/Y axis
         """
         def _get(param):
-            return getattr(self.ax, 'get_{0}{1}'.format(axis, param))()
+            return getattr(self.ax, f'get_{axis}{param}')()
 
         def _set(param, *args, **kwargs):
-            return getattr(self.ax, 'set_{0}{1}'.format(axis, param))(
+            return getattr(self.ax, f'set_{axis}{param}')(
                 *args, **kwargs)
 
-        scale = getattr(self.args, '{}scale'.format(axis))
-        label = getattr(self.args, '{}label'.format(axis))
-        min_ = getattr(self.args, '{}min'.format(axis))
-        max_ = getattr(self.args, '{}max'.format(axis))
+        scale = getattr(self.args, f'{axis}scale')
+        label = getattr(self.args, f'{axis}label')
+        min_ = getattr(self.args, f'{axis}min')
+        max_ = getattr(self.args, f'{axis}max')
 
         # parse limits
         if (
@@ -581,7 +686,7 @@ class CliProduct(object, metaclass=abc.ABCMeta):
 
         # set label
         if label is None:
-            label = getattr(self, 'get_{}label'.format(axis))()
+            label = getattr(self, f'get_{axis}label')()
         if label:
             if self.usetex:
                 label = label_to_latex(label)
@@ -591,10 +696,13 @@ class CliProduct(object, metaclass=abc.ABCMeta):
         limits = _get('lim')
         scale = _get('scale')
         label = _get('label')
-        self.log(2, '{0}-axis parameters | scale: {1} | '
-                    'limits: {2[0]!s} - {2[1]!s}'.format(
-                        axis.upper(), scale, limits))
-        self.log(3, ('{0}-axis label: {1}'.format(axis.upper(), label)))
+        self.log(
+            2,
+            f'{axis.upper()}-axis parameters | '
+            f'scale: {scale} | '
+            f'limits: {limits[0]!s} - {limits[1]!s}'
+        )
+        self.log(3, (f'{axis.upper()}-axis label: {label}'))
 
     def set_xaxis_properties(self):
         """Set properties for X-axis
@@ -602,7 +710,7 @@ class CliProduct(object, metaclass=abc.ABCMeta):
         self._set_axis_properties('x')
 
     def set_yaxis_properties(self):
-        """Set properties for X-axis
+        """Set properties for Y-axis
         """
         self._set_axis_properties('y')
 
@@ -633,7 +741,7 @@ class CliProduct(object, metaclass=abc.ABCMeta):
             title_line = label_to_latex(title_line)
         if title_line:
             self.ax.set_title(title_line, fontsize=12)
-            self.log(3, ('Title is: %s' % title_line))
+            self.log(3, f'Title is: {title_line}')
 
     def set_suptitle(self, suptitle):
         """Set the super title for this plot.
@@ -643,24 +751,24 @@ class CliProduct(object, metaclass=abc.ABCMeta):
         if self.usetex:
             suptitle = label_to_latex(suptitle)
         self.plot.suptitle(suptitle, fontsize=18)
-        self.log(3, ('Super title is: %s' % suptitle))
+        self.log(3, f'Super title is: {suptitle}')
 
     def set_grid(self, enable):
         """Set the grid parameters for this plot.
         """
         if enable:
-            self.ax.grid(b=True, which='major',
+            self.ax.grid(True, which='major',
                          color='k', linestyle='solid')
-            self.ax.grid(b=True, which='minor',
+            self.ax.grid(True, which='minor',
                          color='0.06', linestyle='dotted')
         else:
-            self.ax.grid(b=False)
+            self.ax.grid(False)
 
     def save(self, outfile):
         """Save this product to the target `outfile`.
         """
         self.plot.savefig(outfile, edgecolor='white', bbox_inches='tight')
-        self.log(3, ('wrote %s' % outfile))
+        self.log(3, f'wrote {outfile}')
 
     def has_more_plots(self):
         """Determine whether this product has more plots to be created.
@@ -680,12 +788,12 @@ class CliProduct(object, metaclass=abc.ABCMeta):
     def run(self):
         """Make the plot.
         """
-        self.log(3, ('Verbosity level: %d' % self.verbose))
+        self.log(3, f'Verbosity level: {self.verbose}')
 
         self.log(3, 'Arguments:')
         argsd = vars(self.args)
         for key in sorted(argsd):
-            self.log(3, '{0:>15s} = {1}'.format(key, argsd[key]))
+            self.log(3, f'{key:>15s} = {argsd[key]}')
 
         # grab the data
         self.get_data()
@@ -772,23 +880,42 @@ class ImageProduct(CliProduct, metaclass=abc.ABCMeta):
         """Add an `~argparse.ArgumentGroup` for colour-axis options.
         """
         group = parser.add_argument_group('Colour axis options')
-        group.add_argument('--imin', type=float,
-                           help='minimum value for colorbar')
-        group.add_argument('--imax', type=float,
-                           help='maximum value for colorbar')
-        group.add_argument('--cmap',
-                           default=cls.DEFAULT_CMAP,
-                           help='Colormap. See '
-                                'https://matplotlib.org/examples/color/'
-                                'colormaps_reference.html for options')
-        group.add_argument('--color-scale', choices=('log', 'linear'),
-                           help='scale for colorbar')
-        group.add_argument('--norm', nargs='?', const='median',
-                           choices=('median', 'mean'), metavar='NORM',
-                           help='normalise each pixel against average in '
-                                'that frequency bin')
-        group.add_argument('--nocolorbar', action='store_true',
-                           help='hide the colour bar')
+        group.add_argument(
+            '--imin',
+            type=float,
+            help='minimum value for colorbar',
+        )
+        group.add_argument(
+            '--imax',
+            type=float,
+            help='maximum value for colorbar',
+        )
+        group.add_argument(
+            '--cmap',
+            default=cls.DEFAULT_CMAP,
+            help=(
+                'Colormap. See https://matplotlib.org/examples/color/'
+                'colormaps_reference.html for options'
+            ),
+        )
+        group.add_argument(
+            '--color-scale',
+            choices=('log', 'linear'),
+            help='scale for colorbar',
+        )
+        group.add_argument(
+            '--norm',
+            nargs='?',
+            const='median',
+            choices=('median', 'mean'),
+            metavar='NORM',
+            help='normalise each pixel against average in that frequency bin',
+        )
+        group.add_argument(
+            '--nocolorbar',
+            action='store_true',
+            help='hide the colour bar',
+        )
 
     @staticmethod
     def get_color_label():
@@ -820,6 +947,8 @@ class FFTMixin(object, metaclass=abc.ABCMeta):
 
     This just adds FFT-based command line options
     """
+    DEFAULT_FFTLENGTH = 1.
+
     @classmethod
     def init_data_options(cls, parser):
         """Set up data input and signal processing options including FFTs
@@ -832,54 +961,87 @@ class FFTMixin(object, metaclass=abc.ABCMeta):
         """Add an `~argparse.ArgumentGroup` for FFT options
         """
         group = parser.add_argument_group('Fourier transform options')
-        group.add_argument('--secpfft', type=float, default=1.,
-                           help='length of FFT in seconds')
-        group.add_argument('--overlap', type=float,
-                           help='overlap as fraction of FFT length [0-1)')
-        group.add_argument('--window', type=str, default='hann',
-                           help='window function to use when overlapping FFTs')
+        group.add_argument(
+            '--secpfft',
+            type=float,
+            default=cls.DEFAULT_FFTLENGTH,
+            help='length of FFT in seconds',
+        )
+        group.add_argument(
+            '--overlap',
+            type=float,
+            help='overlap as fraction of FFT length [0-1)',
+        )
+        group.add_argument(
+            '--window',
+            type=str,
+            default='hann',
+            help='window function to use when overlapping FFTs',
+        )
+        group.add_argument(
+            '--average-method',
+            dest='method',
+            default=DEFAULT_FFT_METHOD,
+            choices=('median', 'welch', 'bartlett'),
+            help='FFT averaging method',
+        )
         return group
 
     @classmethod
     def _arg_faxis(cls, axis, parser, **defaults):
         defaults.setdefault('scale', 'log')
         axis = axis.lower()
-        name = '{0} axis'.format(axis.title())
-        group = parser.add_argument_group('{0} options'.format(name))
+        name = f'{axis.title()} axis'
+        group = parser.add_argument_group(f'{name} options')
 
         # label
-        group.add_argument('--{0}label'.format(axis),
-                           default=defaults.get('label'),
-                           dest='{0}label'.format(axis),
-                           help='{0} label'.format(name))
+        group.add_argument(
+            f'--{axis}label',
+            default=defaults.get('label'),
+            dest=f'{axis}label',
+            help=f'{name} label',
+        )
 
         # min and max
         for extrema in ('min', 'max'):
             meg = group.add_mutually_exclusive_group()
             for ax_ in (axis, 'f'):
                 meg.add_argument(
-                    '--{0}{1}'.format(ax_, extrema), type=float,
+                    f'--{ax_}{extrema}',
+                    type=float,
                     default=defaults.get(extrema),
-                    dest='{0}{1}'.format(axis, extrema),
-                    help='{0} value for {1}'.format(extrema, name))
+                    dest=f'{axis}{extrema}',
+                    help=f'{extrema} value for {name}',
+                )
 
         # scale
         scaleg = group.add_mutually_exclusive_group()
-        scaleg.add_argument('--{0}scale'.format(axis), type=str,
-                            default=defaults.get('scale'),
-                            dest='{0}scale'.format(axis),
-                            help='scale for {0}'.format(name))
+        scaleg.add_argument(
+            f'--{axis}scale',
+            type=str,
+            default=defaults.get('scale'),
+            dest=f'{axis}scale',
+            help=f'scale for {name}',
+        )
         for ax_ in (axis, 'f'):
             if defaults.get('scale') == 'log':
                 scaleg.add_argument(
-                    '--nolog{0}'.format(ax_), action='store_const',
-                    dest='{0}scale'.format(axis), const=None, default='log',
-                    help='use linear {0}'.format(name))
+                    f'--nolog{ax_}',
+                    action='store_const',
+                    dest=f'{axis}scale',
+                    const=None,
+                    default='log',
+                    help=f'use linear {name}',
+                )
             else:
                 scaleg.add_argument(
-                    '--log{0}'.format(ax_), action='store_const',
-                    dest='{0}scale'.format(axis), const='log', default=None,
-                    help='use logarithmic {0}'.format(name))
+                    f'--log{ax_}',
+                    action='store_const',
+                    dest=f'{axis}scale',
+                    const='log',
+                    default=None,
+                    help='use logarithmic {name}',
+                )
 
         return group
 
@@ -903,14 +1065,27 @@ class TimeDomainProduct(CliProduct, metaclass=abc.ABCMeta):
         ``--epoch`` option for the time axis.
         """
         group = super().arg_xaxis(parser)
-        group.add_argument('--epoch', type=to_gps,
-                           help='center X axis on this GPS time, may be'
-                                'absolute date/time or delta')
+        group.add_argument(
+            '--epoch',
+            type=to_gps,
+            help=(
+                'center X axis on this GPS time, '
+                'may be absolute date/time or delta'
+            ),
+        )
 
-        group.add_argument('--std-seg', action='store_true',
-                           help='add DQ segment describing IFO state')
-        group.add_argument('--seg', type=str, nargs='+', action='append',
-                           help='specify one or more DQ segment names')
+        group.add_argument(
+            '--std-seg',
+            action='store_true',
+            help='add DQ segment describing IFO state',
+        )
+        group.add_argument(
+            '--seg',
+            type=str,
+            nargs='+',
+            action='append',
+            help='specify one or more DQ segment names',
+        )
         return group
 
     def _finalize_arguments(self, args):
@@ -937,8 +1112,7 @@ class TimeDomainProduct(CliProduct, metaclass=abc.ABCMeta):
             unit = trans.get_unit_name()
             utc = re.sub(r'\.0+', '',
                          Time(epoch, format='gps', scale='utc').iso)
-            return 'Time ({unit}) from {utc} ({gps})'.format(
-                unit=unit, gps=epoch, utc=utc)
+            return f'Time ({unit}) from {utc} ({epoch})'
         return ''
 
 
@@ -949,3 +1123,11 @@ class FrequencyDomainProduct(CliProduct, metaclass=abc.ABCMeta):
         """Default X-axis label for plot
         """
         return 'Frequency (Hz)'
+
+
+class TransferFunctionProduct(FrequencyDomainProduct):
+    """`CliProduct` with frequency on the X-axis and a complex
+    frequency series
+    """
+
+    MIN_DATASETS = 2
