@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Joseph Areeda (2017-2021)
+# Copyright (C) Joseph Areeda (2017-2020)
 #
 # This file is part of GWpy.
 #
@@ -27,11 +27,12 @@ from astropy.units import Quantity
 
 from ..segments import Segment
 from ..time import to_gps
-from .spectrogram import (FFTMixin, Spectrogram)
+from .spectrogram import Spectrogram
 
 
 class Qtransform(Spectrogram):
     """Plot the Q-transform (Omega)"""
+    DEFAULT_FFTLENGTH = None
     MAX_DATASETS = 1
     action = 'qtransform'
 
@@ -53,8 +54,7 @@ class Qtransform(Spectrogram):
 
     @classmethod
     def init_data_options(cls, parser):
-        # call super of FFTMixin to skip setting FFT arguments
-        super(FFTMixin, cls).init_data_options(parser)
+        super().init_data_options(parser)
         cls.arg_qxform(parser)
 
     @classmethod
@@ -128,9 +128,7 @@ class Qtransform(Spectrogram):
         self.args.tres = search / xpix / 2
         self.log(
             3,
-            'Max time resolution (tres) set to {:.4f}'.format(
-                self.args.tres,
-            ),
+            f'Max time resolution (tres) set to {self.args.tres:.4f}',
         )
 
         args.start = [[int(gps - search/2)]]
@@ -162,14 +160,14 @@ class Qtransform(Spectrogram):
         return 'Normalized energy'
 
     def get_suptitle(self):
-        return 'Q-transform: {0}'.format(self.chan_list[0])
+        return f'Q-transform: {self.chan_list[0]}'
 
     def get_title(self):
         """Default title for plot
         """
         def fformat(x):  # float format
             if isinstance(x, (list, tuple)):
-                return '[{0}]'.format(', '.join(map(fformat, x)))
+                return f"[{', '.join(map(fformat, x))}]"
             if isinstance(x, Quantity):
                 x = x.value
             elif isinstance(x, str):
@@ -179,18 +177,17 @@ class Qtransform(Spectrogram):
                     'in a future release.',
                 )
                 x = float(x)
-            return '{0:.2f}'.format(x)
+            return f'{x:.2f}'
 
         bits = [('Q', fformat(self.result.q))]
-        bits.append(('tres', '{:.3g}'.format(self.qxfrm_args['tres'])))
+        bits.append(('tres', f"{self.qxfrm_args['tres']:.3g}"))
         if self.qxfrm_args.get('qrange'):
             bits.append(('q-range', fformat(self.qxfrm_args['qrange'])))
-        if self.qxfrm_args['whiten']:
+        if self.qxfrm_args['whiten'] is not None:
             bits.append(('whitened',))
         bits.extend([
             ('f-range', fformat(self.result.yspan)),
-            ('e-range', '[{:.3g}, {:.3g}]'.format(self.result.min(),
-                                                  self.result.max())),
+            ('e-range', f'[{self.result.min():.3g}, {self.result.max():.3g}]'),
         ])
         return ', '.join([': '.join(bit) for bit in bits])
 
@@ -199,8 +196,16 @@ class Qtransform(Spectrogram):
         spectrogram"""
         args = self.args
 
-        asd = self.timeseries[0].asd().value
-        if (asd.min() == 0):
+        fftlength = args.secpfft
+        overlap = args.overlap * fftlength if fftlength else None
+        method = args.method
+        asd = self.timeseries[0].asd(
+            fftlength=fftlength,
+            overlap=overlap,
+            method=method,
+        )
+
+        if (asd.value.min() == 0):
             self.log(0, 'Input data has a zero in ASD. '
                      'Q-transform not possible.')
             self.got_error = True
@@ -209,6 +214,10 @@ class Qtransform(Spectrogram):
             gps = self.qxfrm_args['gps']
             outseg = Segment(gps, gps).protract(args.plot[self.plot_num])
 
+            # use the precomputed ASD as the whitener if needed
+            if self.qxfrm_args.get("whiten") is True:
+                self.qxfrm_args["whiten"] = asd
+
             # This section tries to optimize the amount of data that is
             # processed and the time resolution needed to create a good
             # image. NB:For each time span specified
@@ -223,9 +232,9 @@ class Qtransform(Spectrogram):
             self.qxfrm_args['search'] = int(len(proc_ts) * proc_ts.dt.value)
 
             self.log(3, 'Q-transform arguments:')
-            self.log(3, '{0:>15s} = {1}'.format('outseg', outseg))
-            for key in sorted(self.qxfrm_args):
-                self.log(3, '{0:>15s} = {1}'.format(key, self.qxfrm_args[key]))
+            self.log(3, f'         outseg = {outseg}')
+            for key, val in sorted(self.qxfrm_args.items()):
+                self.log(3, f'{key:>15s} = {val}')
 
             qtrans = proc_ts.q_transform(outseg=outseg, **self.qxfrm_args)
 
@@ -246,7 +255,10 @@ class Qtransform(Spectrogram):
     def save(self, outdir):  # pylint: disable=arguments-differ
         cname = re.sub('[-_:]', '_', self.timeseries[0].channel.name).replace(
             '_', '-', 1)
-        png = '{0}-{1}-{2}.png'.format(cname, float(self.args.gps),
-                                       self.args.plot[self.plot_num])
+        png = (
+            f'{cname}-'
+            f'{float(self.args.gps)}-'
+            f'{self.args.plot[self.plot_num]}.png'
+        )
         outfile = os.path.join(outdir, png)
         return super().save(outfile)
