@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -36,5 +36,4 @@ class TestCliCoherence(_TestCliSpectrum):
         assert prod.ref_chan == prod.chan_list[0]
 
     def test_get_suptitle(self, prod):
-        assert prod.get_suptitle() == 'Coherence: {0}'.format(
-            prod.chan_list[0])
+        assert prod.get_suptitle() == f'Coherence: {prod.chan_list[0]}'
