@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -23,8 +23,9 @@ import os
 import re
 from unittest import mock
 
+import pytest
+
 from ... import cli
-from ...testing.utils import skip_missing_dependency
 from .base import (update_namespace, mock_nds2_connection)
 from .test_spectrogram import TestCliSpectrogram as _TestCliSpectrogram
 
@@ -35,6 +36,7 @@ class TestCliQtransform(_TestCliSpectrogram):
     TEST_ARGS = [
         '--chan', 'X1:TEST-CHANNEL', '--gps', '5', '--search', '10',
         '--nds2-server', 'nds.test.gwpy', '--outdir', os.path.curdir,
+        '--average-method', 'median',
     ]
 
     def test_finalize_arguments(self, prod):
@@ -54,21 +56,20 @@ class TestCliQtransform(_TestCliSpectrogram):
         _float_reg = r"[+-]?(\d+(\.\d*)?|\.\d+)([eE][+-]?\d+)?"
         title_reg = re.compile(
             r"\A"
-            r"q: {float}, "
-            r"tres: {float}, "
+            fr"q: {_float_reg}, "
+            fr"tres: {_float_reg}, "
             r"whitened, "
-            r"f-range: \[{float}, {float}\], "
-            r"e-range: \[{float}, {float}\]"
-            r"\Z".format(float=_float_reg),
+            fr"f-range: \[{_float_reg}, {_float_reg}\], "
+            fr"e-range: \[{_float_reg}, {_float_reg}\]"
+            r"\Z",
             re.I,
         )
         assert title_reg.match(dataprod.get_title())
 
     def test_get_suptitle(self, prod):
-        assert prod.get_suptitle() == 'Q-transform: {0}'.format(
-            prod.chan_list[0])
+        assert prod.get_suptitle() == f'Q-transform: {prod.chan_list[0]}'
 
-    @skip_missing_dependency('nds2')
+    @pytest.mark.requires("nds2")
     def test_run(self, prod):
         conn, _ = mock_nds2_connection()
         outf = 'X1-TEST_CHANNEL-5.0-0.5.png'
