@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -34,11 +34,6 @@ from .units import parse_unit
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
 
-try:  # python >= 3.7
-    Pattern = re.Pattern
-except AttributeError:  # python < 3.7
-    Pattern = re._pattern_type
-
 QUOTE_REGEX = re.compile(r'^[\s\"\']+|[\s\"\']+$')
 
 
@@ -140,7 +135,7 @@ class Channel(object):
                 try:
                     setattr(self, key, val)
                 except AttributeError:
-                    setattr(self, '_%s' % key, val)
+                    setattr(self, f'_{key}', val)
 
     # -- properties -----------------------------
 
@@ -265,7 +260,7 @@ class Channel(object):
         if type_ is None:
             self._type = None
         else:
-            self._type = io_nds2.Nds2ChannelType.find(type_).name
+            self._type = io_nds2.Nds2ChannelType.find(type_).nds2name
 
     @property
     def ndstype(self):
@@ -312,7 +307,7 @@ class Channel(object):
                 url = urlparse(href)
                 assert url.scheme in ('http', 'https', 'file')
             except (AttributeError, ValueError, AssertionError):
-                raise ValueError("Invalid URL %r" % href)
+                raise ValueError(f"Invalid URL {href!r}")
             self._url = href
 
     @property
@@ -393,13 +388,13 @@ class Channel(object):
         """Name of this channel as stored in the NDS database
         """
         if self.type not in [None, 'raw', 'reduced', 'online']:
-            return '%s,%s' % (self.name, self.type)
+            return f'{self.name},{self.type}'
         return self.name
 
     # -- classmethods ---------------------------
 
     @classmethod
-    def query(cls, name, kerberos=None):
+    def query(cls, name, kerberos=None, **kwargs):
         """Query the LIGO Channel Information System for the `Channel`
         matching the given name
 
@@ -413,19 +408,25 @@ class Channel(object):
             default behaviour will check for credentials and request username
             and password if none are found (`None`)
 
+        kwargs
+            other keyword arguments are passed directly to
+            :func:`ciecplib.get`
+
         Returns
         -------
         c : `Channel`
              a new `Channel` containing all of the attributes set from
              its entry in the CIS
         """
-        channellist = ChannelList.query(name, kerberos=kerberos)
+        channellist = ChannelList.query(name, kerberos=kerberos, **kwargs)
         if not channellist:
-            raise ValueError("No channels found matching '%s'" % name)
+            raise ValueError(f"No channels found matching '{name}'")
         if len(channellist) > 1:
-            raise ValueError("%d channels found matching '%s', please refine "
-                             "search, or use `ChannelList.query` to return "
-                             "all results" % (len(channellist), name))
+            raise ValueError(
+                f"{len(channellist)} channels found matching '{name}', "
+                "please refine search, or use `ChannelList.query` to "
+                "return all results"
+            )
         return channellist[0]
 
     @classmethod
@@ -582,11 +583,11 @@ class Channel(object):
         return self.name
 
     def __repr__(self):
-        repr_ = '<Channel("%s"' % (str(self))
+        repr_ = f'<Channel("{self}"'
         if self.type:
-            repr_ += ' [%s]' % self.type
-        repr_ += ', %s' % self.sample_rate
-        return repr_ + ') at %s>' % hex(id(self))
+            repr_ += f' [{self.type}]'
+        repr_ += f', {self.sample_rate}'
+        return repr_ + f') at {hex(id(self))}>'
 
     def __eq__(self, other):
         for attr in ['name', 'sample_rate', 'unit', 'url', 'type', 'dtype']:
@@ -659,14 +660,14 @@ class ChannelList(list):
             namestr = namestr.strip('\' \n')
             if ',' not in namestr:
                 break
-            for nds2type in io_nds2.Nds2ChannelType.names() + ['']:
-                if nds2type and ',%s' % nds2type in namestr:
+            for nds2type in io_nds2.Nds2ChannelType.nds2names() + ['']:
+                if nds2type and f',{nds2type}' in namestr:
                     try:
                         channel, ctype, namestr = namestr.split(',', 2)
                     except ValueError:
                         channel, ctype = namestr.split(',')
                         namestr = ''
-                    out.append('%s,%s' % (channel, ctype))
+                    out.append(f'{channel},{ctype}')
                     break
                 elif nds2type == '' and ',' in namestr:
                     channel, namestr = namestr.split(',', 1)
@@ -723,14 +724,14 @@ class ChannelList(list):
             a new `ChannelList` containing the matching channels
         """
         # format name regex
-        if isinstance(name, Pattern):
+        if isinstance(name, re.Pattern):
             flags = name.flags
             name = name.pattern
         else:
             flags = 0
         if exact_match:
-            name = name if name.startswith(r'\A') else r"\A%s" % name
-            name = name if name.endswith(r'\Z') else r"%s\Z" % name
+            name = name if name.startswith(r'\A') else fr"\A{name}"
+            name = name if name.endswith(r'\Z') else fr"{name}\Z"
         name_regexp = re.compile(name, flags=flags)
 
         matched = list(self)
@@ -762,7 +763,7 @@ class ChannelList(list):
         return self.__class__(matched)
 
     @classmethod
-    def query(cls, name, kerberos=None):
+    def query(cls, name, kerberos=None, **kwargs):
         """Query the LIGO Channel Information System a `ChannelList`.
 
         Parameters
@@ -775,13 +776,17 @@ class ChannelList(list):
             default behaviour will check for credentials and request username
             and password if none are found (`None`)
 
+        kwargs
+            other keyword arguments are passed directly to
+            :func:`ciecplib.get`
+
         Returns
         -------
         channels : `ChannelList`
             a new list containing all `Channels <Channel>` found.
         """
         from .io import cis
-        return cis.query(name, kerberos=kerberos)
+        return cis.query(name, kerberos=kerberos, **kwargs)
 
     @classmethod
     def query_nds2(cls, names, host=None, port=None, connection=None,
