@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2015-2021)
+# Copyright (C) Duncan Macleod (2015-2020)
 #
 # This file is part of GWpy.
 #
@@ -72,7 +72,11 @@ from collections import OrderedDict
 from numpy import inf
 
 from ...io import registry
-from ...io.utils import (FILE_LIKE, file_list, identify_factory)
+from ...io.utils import (
+    file_list,
+    identify_factory,
+    with_open,
+)
 from .. import (Channel, ChannelList)
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
@@ -114,7 +118,7 @@ def read_channel_list_file(*source):
             try:
                 match = CHANNEL_DEFINITION.match(channel).groupdict()
             except AttributeError as exc:
-                exc.args = ('Cannot parse %r as channel list entry' % channel,)
+                exc.args = (f"Cannot parse {channel!r} as channel list entry",)
                 raise
             # remove Nones from match
             match = dict((k, v) for k, v in match.items() if v is not None)
@@ -134,13 +138,10 @@ def read_channel_list_file(*source):
     return out
 
 
+@with_open(mode="w", pos=1)
 def write_channel_list_file(channels, fobj):
     """Write a `~gwpy.detector.ChannelList` to a INI-format channel list file
     """
-    if not isinstance(fobj, FILE_LIKE):
-        with open(fobj, "w") as fobj:
-            return write_channel_list_file(channels, fobj)
-
     out = configparser.ConfigParser(dict_type=OrderedDict)
     for channel in channels:
         group = channel.group
@@ -149,18 +150,17 @@ def write_channel_list_file(channels, fobj):
         for param, value in channel.params.items():
             out.set(group, param, value)
         if channel.sample_rate is not None:
-            entry = '%s %s' % (str(channel),
-                               str(channel.sample_rate.to('Hz').value))
+            entry = f"{channel} {channel.sample_rate.to('Hz').value}"
         else:
             entry = str(channel)
-        entry += ' %s' % channel.params.get('safe', 'safe')
-        entry += ' %s' % channel.params.get('fidelity', 'clean')
+        entry += f" {channel.params.get('safe', 'safe')}"
+        entry += f" {channel.params.get('fidelity', 'clean')}"
         try:
             clist = out.get(group, 'channels')
         except configparser.NoOptionError:
-            out.set(group, 'channels', '\n%s' % entry)
+            out.set(group, 'channels', f'\n{entry}')
         else:
-            out.set(group, 'channels', clist + '\n%s' % entry)
+            out.set(group, 'channels', clist + f'\n{entry}')
 
     out.write(fobj)
 
