@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -171,17 +171,18 @@ class TestChannel(object):
         (None, None, None),
         ('m-trend', 'm-trend', 16),
         (8, 's-trend', 8),
-        ('blah', 'RAISE', '')
     ])
     def test_type_ndstype(self, arg, type_, ndstype):
-        if type_ == 'RAISE':  # check invalid raises correct exception
-            with pytest.raises(ValueError) as exc:
-                c = self.TEST_CLASS('', type=arg)
-            assert str(exc.value) == '%r is not a valid Nds2ChannelType' % arg
-        else:
-            c = self.TEST_CLASS('', type=arg)
-            assert getattr(c, 'type') == type_
-            assert getattr(c, 'ndstype') == ndstype
+        c = self.TEST_CLASS('', type=arg)
+        assert getattr(c, 'type') == type_
+        assert getattr(c, 'ndstype') == ndstype
+
+    def test_type_ndstype_error(self):
+        with pytest.raises(
+            ValueError,
+            match="^'blah' is not a valid Nds2ChannelType$",
+        ):
+            self.TEST_CLASS('', type="blah")
 
     @pytest.mark.parametrize('arg, dtype', [
         (None, None),
@@ -199,17 +200,18 @@ class TestChannel(object):
         None,
         'https://blah',
         'file://local/path',
+    ])
+    def test_url(self, url):
+        new = self.TEST_CLASS('test', url=url)
+        assert new.url == url
+
+    @pytest.mark.parametrize('url', [
         'BAD',
         1,
     ])
-    def test_url(self, url):
-        if url is not None and not str(url).startswith(('http', 'file')):
-            with pytest.raises(ValueError) as exc:
-                new = self.TEST_CLASS('test', url=url)
-            assert str(exc.value) == "Invalid URL %r" % url
-        else:
-            new = self.TEST_CLASS('test', url=url)
-            assert new.url == url
+    def test_url_error(self, url):
+        with pytest.raises(ValueError, match=f"^Invalid URL {url!r}$"):
+            self.TEST_CLASS('test', url=url)
 
     def test_frametype(self):
         new = self.TEST_CLASS('test', frametype='BLAH')
@@ -298,10 +300,14 @@ class TestChannel(object):
             assert getattr(c, key) is None
 
         # check errors
-        with pytest.raises(ValueError) as exc:
+        with pytest.raises(
+            ValueError,
+            match=(
+                "^Cannot parse channel name according to "
+                "LIGO channel-naming convention T990033$"
+            ),
+        ):
             self.TEST_CLASS.parse_channel_name('blah')
-        assert str(exc.value) == ('Cannot parse channel name according to '
-                                  'LIGO channel-naming convention T990033')
 
         # check parsing returns expected result
         assert self.TEST_CLASS.parse_channel_name(name) == pdict
@@ -312,7 +318,7 @@ class TestChannel(object):
             assert getattr(c, key) == pdict[key]
         assert c.ndsname == name
 
-    @utils.skip_missing_dependency("ciecplib")
+    @pytest.mark.requires("ciecplib")
     @pytest.mark.parametrize('name', ('X1:TEST-CHANNEL', 'Y1:TEST_CHANNEL'))
     def test_query(self, name):
         requests_mock = pytest.importorskip("requests_mock")
@@ -331,18 +337,17 @@ class TestChannel(object):
             results = []
 
         # mock response and test parsing
-        url = "https://cis.ligo.org/api/channel/?q={}".format(name)
         with requests_mock.Mocker() as rmock:
-            # mock the request to get the list of IdPs
-            from ciecplib.utils import DEFAULT_IDPLIST_URL
             rmock.get(
-                DEFAULT_IDPLIST_URL,
-                text="https://login.ligo.org/idp/profile/SAML2/SOAP/ECP LIGO",
+                f"https://cis.ligo.org/api/channel/?q={name}",
+                json=results,
             )
-            # mock our request and test result parsing
-            rmock.get(url, json=results)
             if name == 'X1:TEST-CHANNEL':
-                c = self.TEST_CLASS.query(name, kerberos=True)
+                c = self.TEST_CLASS.query(
+                    name,
+                    kerberos=False,
+                    idp="https://idp.example.com/profile/SAML2/SOAP/ECP",
+                )
                 assert c.name == 'X1:TEST-CHANNEL'
                 assert c.unit == units.m
                 assert c.sample_rate == 16384 * units.Hz
@@ -350,12 +355,18 @@ class TestChannel(object):
                 assert c.model == 'x1model'
                 assert c.url == 'https://cis.ligo.org/channel/123456'
             else:
-                with pytest.raises(ValueError) as exc:
-                    self.TEST_CLASS.query(name, kerberos=True)
-                assert str(exc.value) == 'No channels found matching %r' % name
+                with pytest.raises(
+                    ValueError,
+                    match=f"^No channels found matching {name!r}$",
+                ):
+                    self.TEST_CLASS.query(
+                        name,
+                        kerberos=False,
+                        idp="https://idp.example.com/profile/SAML2/SOAP/ECP",
+                    )
 
     @pytest.mark.parametrize('name', ('X1:TEST-CHANNEL', 'Y1:TEST_CHANNEL'))
-    @utils.skip_missing_dependency('nds2')
+    @pytest.mark.requires("nds2")
     def test_query_nds2(self, name):
         # mock NDS2 query
         ndsb = mocks.nds2_buffer('X1:TEST-CHANNEL', [], 0, 64, 'm')
@@ -380,7 +391,7 @@ class TestChannel(object):
                 with pytest.raises(ValueError):
                     c = self.TEST_CLASS.query_nds2(name, host='test')
 
-    @utils.skip_missing_dependency('nds2')
+    @pytest.mark.requires("nds2")
     def test_from_nds2(self):
         nds2c = mocks.nds2_channel('X1:TEST-CHANNEL', 64, 'm')
         c = self.TEST_CLASS.from_nds2(nds2c)
@@ -428,7 +439,7 @@ class TestChannelList(object):
         cl = instance.sieve(name='GWPY-CHANNEL', sample_range=[2, 16])
         assert cl == instance[1:]
 
-    @utils.skip_missing_dependency('nds2')
+    @pytest.mark.requires("nds2")
     def test_query_nds2(self):
         # mock NDS2 query
         buffers = []
@@ -448,7 +459,7 @@ class TestChannelList(object):
             assert len(
                 self.TEST_CLASS.query_nds2([self.NAMES[-1]], host='test')) == 0
 
-    @utils.skip_missing_dependency('nds2')
+    @pytest.mark.requires("nds2")
     def test_query_nds2_availability(self):
         # mock NDS2 connection
         ndsb = mocks.nds2_buffer(self.NAMES[0], [], 0, 64, 'm')
@@ -468,73 +479,73 @@ class TestChannelList(object):
             utils.assert_segmentlist_equal(avail[self.NAMES[0]],
                                            [(0, 10), (20, 30)])
 
-    def test_read_write_omega_config(self):
+    def test_read_write_omega_config(self, tmp_path):
+        tmp = tmp_path / "config.ini"
         # write OMEGA_CONFIG to file and read it back
-        with utils.TemporaryFilename(suffix='.txt') as tmp:
-            with open(tmp, 'w') as f:
-                f.write(OMEGA_CONFIG)
-            cl = self.TEST_CLASS.read(tmp, format='omega-scan')
-            assert len(cl) == 2
-            assert cl[0].name == 'L1:GDS-CALIB_STRAIN'
-            assert cl[0].sample_rate == 4096 * units.Hertz
-            assert cl[0].frametype == 'L1_HOFT_C00'
-            assert cl[0].params == {
-                'channelName': 'L1:GDS-CALIB_STRAIN',
-                'frameType': 'L1_HOFT_C00',
-                'sampleFrequency': 4096,
-                'searchTimeRange': 64,
-                'searchFrequencyRange': (0, float('inf')),
-                'searchQRange': (4, 96),
-                'searchMaximumEnergyLoss': 0.2,
-                'whiteNoiseFalseRate': 1e-3,
-                'searchWindowDuration': 0.5,
-                'plotTimeRanges': (1, 4, 16),
-                'plotFrequencyRange': (),
-                'plotNormalizedEnergyRange': (0, 25.5),
-                'alwaysPlotFlag': 1,
-            }
-            assert cl[1].name == 'L1:PEM-CS_SEIS_LVEA_VERTEX_Z_DQ'
-            assert cl[1].frametype == 'L1_R'
+        with open(tmp, 'w') as f:
+            f.write(OMEGA_CONFIG)
+        cl = self.TEST_CLASS.read(tmp, format='omega-scan')
+        assert len(cl) == 2
+        assert cl[0].name == 'L1:GDS-CALIB_STRAIN'
+        assert cl[0].sample_rate == 4096 * units.Hertz
+        assert cl[0].frametype == 'L1_HOFT_C00'
+        assert cl[0].params == {
+            'channelName': 'L1:GDS-CALIB_STRAIN',
+            'frameType': 'L1_HOFT_C00',
+            'sampleFrequency': 4096,
+            'searchTimeRange': 64,
+            'searchFrequencyRange': (0, float('inf')),
+            'searchQRange': (4, 96),
+            'searchMaximumEnergyLoss': 0.2,
+            'whiteNoiseFalseRate': 1e-3,
+            'searchWindowDuration': 0.5,
+            'plotTimeRanges': (1, 4, 16),
+            'plotFrequencyRange': (),
+            'plotNormalizedEnergyRange': (0, 25.5),
+            'alwaysPlotFlag': 1,
+        }
+        assert cl[1].name == 'L1:PEM-CS_SEIS_LVEA_VERTEX_Z_DQ'
+        assert cl[1].frametype == 'L1_R'
 
-            # write omega config again using ChannelList.write and read it back
-            # and check that the two lists match
-            with open(tmp, 'w') as f:
-                cl.write(f, format='omega-scan')
-            cl2 = type(cl).read(tmp, format='omega-scan')
-            assert cl == cl2
+        # write omega config again using ChannelList.write and read it back
+        # and check that the two lists match
+        with open(tmp, 'w') as f:
+            cl.write(f, format='omega-scan')
+        cl2 = type(cl).read(tmp, format='omega-scan')
+        assert cl == cl2
 
-    def test_read_write_clf(self):
+    def test_read_write_clf(self, tmp_path):
+        tmp = tmp_path / "config.clf"
         # write clf to file and read it back
-        with utils.TemporaryFilename(suffix='.ini') as tmp:
-            with open(tmp, 'w') as f:
-                f.write(CLF)
-            cl = ChannelList.read(tmp)
-            assert len(cl) == 4
-            a = cl[0]
-            assert a.name == 'H1:GDS-CALIB_STRAIN'
-            assert a.sample_rate == 16384 * units.Hz
-            assert a.frametype == 'H1_HOFT_C00'
-            assert a.frequency_range[0] == 4. * units.Hz
-            assert a.frequency_range[1] == float('inf') * units.Hz
-            assert a.safe is False
-            assert a.params == {'qhigh': '150', 'safe': 'unsafe',
-                                'fidelity': 'clean'}
-            b = cl[1]
-            assert b.name == 'H1:ISI-GND_STS_HAM2_X_DQ'
-            assert b.frequency_range[0] == .1 * units.Hz
-            assert b.frequency_range[1] == 60. * units.Hz
-            c = cl[2]
-            assert c.name == 'H1:ISI-GND_STS_HAM2_Y_DQ'
-            assert c.sample_rate == 256 * units.Hz
-            assert c.safe is False
-            d = cl[3]
-            assert d.name == 'H1:ISI-GND_STS_HAM2_Z_DQ'
-            assert d.safe is True
-            assert d.params['fidelity'] == 'glitchy'
+        with open(tmp, 'w') as f:
+            f.write(CLF)
+        cl = ChannelList.read(tmp)
+        assert len(cl) == 4
+        a = cl[0]
+        assert a.name == 'H1:GDS-CALIB_STRAIN'
+        assert a.sample_rate == 16384 * units.Hz
+        assert a.frametype == 'H1_HOFT_C00'
+        assert a.frequency_range[0] == 4. * units.Hz
+        assert a.frequency_range[1] == float('inf') * units.Hz
+        assert a.safe is False
+        assert a.params == {'qhigh': '150', 'safe': 'unsafe',
+                            'fidelity': 'clean'}
+        b = cl[1]
+        assert b.name == 'H1:ISI-GND_STS_HAM2_X_DQ'
+        assert b.frequency_range[0] == .1 * units.Hz
+        assert b.frequency_range[1] == 60. * units.Hz
+        c = cl[2]
+        assert c.name == 'H1:ISI-GND_STS_HAM2_Y_DQ'
+        assert c.sample_rate == 256 * units.Hz
+        assert c.safe is False
+        d = cl[3]
+        assert d.name == 'H1:ISI-GND_STS_HAM2_Z_DQ'
+        assert d.safe is True
+        assert d.params['fidelity'] == 'glitchy'
 
-            # write omega config again using ChannelList.write and read it back
-            # and check that the two lists match
-            with open(tmp, 'w') as f:
-                cl.write(f)
-            cl2 = type(cl).read(tmp)
-            assert cl == cl2
+        # write clf again using ChannelList.write and read it back
+        # and check that the two lists match
+        with open(tmp, 'w') as f:
+            cl.write(f)
+        cl2 = type(cl).read(tmp)
+        assert cl == cl2
