@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -23,6 +23,7 @@ import re
 import warnings
 
 from astropy import units
+from astropy.units import imperial as units_imperial
 from astropy.units.format.generic import Generic
 
 __author__ = "Duncan Macleod <duncan.macleod@ligo.org>"
@@ -80,9 +81,9 @@ class GWpyFormat(Generic):
             else:
                 if cls.warn:
                     warnings.warn(
-                        '{0} Mathematical operations using this unit should '
-                        'work, but conversions to other units will '
-                        'not.'.format(str(exc).rstrip(' ')),
+                        f"{str(exc).rstrip(' ')} Mathematical operations "
+                        "using this unit should work, but conversions to "
+                        "other units will not.",
                         category=units.UnitsWarning)
                 try:  # return previously created unit
                     return UNRECOGNIZED_UNITS[name]
@@ -145,7 +146,7 @@ def parse_unit(name, parse_strict='warn', format='gwpy'):
 # pylint: disable=no-member,invalid-name
 
 # enable imperial units
-units.add_enabled_units(units.imperial)
+units.add_enabled_units(units_imperial)
 
 # -- custom units settings
 # the following happens in two sets
@@ -160,9 +161,18 @@ units.add_enabled_units(units.imperial)
 # 1) alternative names
 registry = units.get_current_unit_registry().registry
 for unit, aliases in [
-        (units.Unit('ct'), ('counts',)),
-        (units.Unit('Celsius'), ('Degrees_C', 'DegC')),
-        (units.Unit('Fahrenheit'), ('Degrees_F', 'DegF')),
+    (units.Unit('ct'), ('counts',)),
+    (units.Unit('Celsius'), ('Degrees_C', 'DegC')),
+    (units.Unit('Fahrenheit'), ('Degrees_F', 'DegF')),
+    # GW observatories like to record 'time' as the unit
+    (units.Unit('second'), (
+        'time',
+        'time (s)',
+        'time [s]',
+        'Time [sec]',
+        'Time (sec)',
+        'Seconds',  # GWOSC
+    )),
 ]:
     unit.names.extend(aliases)
     for alias in aliases:
@@ -176,8 +186,8 @@ units.def_unit(['NONE', 'undef'], namespace=_ns,
                doc='No unit has been defined for these data')
 
 # other dimenionless units
-units.def_unit('strain', represents=units.Unit(''), namespace=_ns)
-units.def_unit('coherence', namespace=_ns)
+units.def_unit('strain', namespace=_ns)
+units.def_unit('coherence', represents=units.dimensionless_unscaled, namespace=_ns)
 
 # alias for 'second' but with prefices
 units.def_unit((['sec'], ['sec']), represents=units.second, prefixes=True,
@@ -188,11 +198,11 @@ units.def_unit((['torr'], ['torr']), represents=101325/760.*units.pascal,
                prefixes=True, namespace=_ns)
 
 # pounds per square inch gauge
-units.def_unit('psig', represents=units.imperial.psi, prefixes=True,
+units.def_unit('psig', represents=units_imperial.psi, prefixes=True,
                namespace=_ns, doc='Pound per square inch gauge: pressure')
 
 # cubic feet
-units.def_unit('cf', represents=units.imperial.foot**3, namespace=_ns)
+units.def_unit('cf', represents=units_imperial.foot**3, namespace=_ns)
 
 # cubic feet per minute
 units.def_unit('cfm', represents=_ns['cf']/units.minute, namespace=_ns)
