@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -77,7 +77,8 @@ class TestSpectralVariance(_TestArray2D):
         utils.assert_array_equal(array.yindex, array.bins[:-1])
 
     def test_transpose(self, array):
-        return NotImplemented
+        with pytest.raises(NotImplementedError):
+            array.T
 
     # -- test utilities -------------------------
 
@@ -90,9 +91,11 @@ class TestSpectralVariance(_TestArray2D):
                 epoch=array.epoch,
             ),
         )
-        with pytest.raises(NotImplementedError) as exc:
+        with pytest.raises(
+            NotImplementedError,
+            match="^cannot slice SpectralVariance across bins$",
+        ):
             array[0, ::2]
-        assert str(exc.value) == 'cannot slice SpectralVariance across bins'
 
     # -- test methods ---------------------------
 
@@ -104,8 +107,14 @@ class TestSpectralVariance(_TestArray2D):
         assert array.y0 == self.bins[0]
         assert array.dy == self.bins[1] - self.bins[0]
 
-    def test_is_compatible(self, array):
-        return super(_TestArray2D, self).test_is_compatible(array)
+    def test_crop_float_precision(self):
+        pytest.skip("float precision test not supported for SpectralVariance")
+
+    def test_is_compatible_yindex(self, array):
+        pytest.skip(f"not implemented for {type(self).__name__}")
+
+    def test_is_compatible_error_yindex(self, array):
+        pytest.skip(f"not implemented for {type(self).__name__}")
 
     def test_plot(self, array):
         with rc_context(rc={'text.usetex': False}):
