@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -23,13 +23,17 @@ and associated metadata for those files, designed to make identifying
 relevant data, and sieving large file lists, easier for the user.
 """
 
-import os.path
+import contextlib
+import os
 import warnings
 from collections import (namedtuple, OrderedDict)
-from pathlib import Path
 
 from ..time import LIGOTimeGPS
-from .utils import (FILE_LIKE, file_path)
+from .utils import (
+    FILE_LIKE,
+    file_path,
+    with_open,
+)
 
 try:
     from lal.utils import CacheEntry
@@ -48,6 +52,27 @@ else:
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
 
 
+@contextlib.contextmanager
+def _silence_lal_debug_warnings():
+    """Temporarily silence debug warnings from LAL.
+    """
+    try:
+        import lal
+    except ImportError:
+        yield
+        return
+
+    debuglevel = lal.GetDebugLevel()
+    # silence LAL debug warnings
+    lal.ClobberDebugLevel(0)
+
+    try:
+        yield
+    finally:
+        # reset
+        lal.ClobberDebugLevel(debuglevel)
+
+
 def _preformat_entry(entry):
     path = file_path(entry)
     obs, tag, seg = filename_metadata(path)
@@ -61,12 +86,12 @@ def _preformat_entry(entry):
 
 def _format_entry_lal(entry):
     path, obs, tag, seg = _preformat_entry(entry)
-    return "{} {} {} {} {}".format(obs, tag, seg[0], abs(seg), path)
+    return f"{obs} {tag} {seg[0]} {abs(seg)} {path}"
 
 
 def _parse_entry_lal(line, gpstype=LIGOTimeGPS):
     from ..segments import Segment
-    obs, desc, start, dur, path = map(str, line)
+    obs, desc, start, dur, path = line
     start = gpstype(start)
     end = start + float(dur)
     return _CacheEntry(obs, desc, Segment(start, end), path)
@@ -74,16 +99,17 @@ def _parse_entry_lal(line, gpstype=LIGOTimeGPS):
 
 def _format_entry_ffl(entry):
     path, obs, tag, seg = _preformat_entry(entry)
-    return "{} {} {} 0 0".format(path, seg[0], abs(seg))
+    return f"{path} {seg[0]} {abs(seg)} 0 0"
 
 
 def _parse_entry_ffl(line, gpstype=LIGOTimeGPS):
     from ..segments import Segment
-    path, start, dur, _, _ = map(str, line)
-    start = gpstype(start)
+    path, start, dur, _, _ = line
+    with _silence_lal_debug_warnings():
+        start = gpstype(start)
     end = start + float(dur)
     try:
-        observatory, description = Path(path).name.split('-', 2)[:2]
+        observatory, description = os.path.basename(path).split('-', 2)[:2]
     except ValueError:
         return _CacheEntry(None, None, Segment(start, end), path)
     return _CacheEntry(observatory, description, Segment(start, end), path)
@@ -112,14 +138,15 @@ class _CacheEntry(namedtuple(
             return cls(*filename_metadata(path) + (path,))
 
         try:
-            return _parse_entry_ffl(parts)
+            return _parse_entry_ffl(parts, gpstype=gpstype)
         except (RuntimeError, TypeError, ValueError) as exc:
             try:
-                return _parse_entry_lal(parts)
+                return _parse_entry_lal(parts, gpstype=gpstype)
             except ValueError:
                 pass
-            exc.args = ("Cannot identify format for cache entry {!r}".format(
-                line.strip()),)
+            exc.args = (
+                f"Cannot identify format for cache entry {line.strip()!r}",
+            )
             raise
 
 
@@ -136,24 +163,31 @@ def _iter_cache(cachefile, gpstype=LIGOTimeGPS):
         path = None
     for line in cachefile:
         try:
-            yield _CacheEntry.parse(line, gpstype=LIGOTimeGPS)
+            yield _CacheEntry.parse(line, gpstype=gpstype)
         except ValueError:
             # virgo FFL format (seemingly) supports nested FFL files
             parts = line.split()
             if len(parts) == 3 and os.path.abspath(parts[0]) != path:
                 with open(parts[0], 'r') as cache2:
-                    for entry in _iter_cache(cache2):
+                    for entry in _iter_cache(cache2, gpstype=gpstype):
                         yield entry
             else:
                 raise
 
 
-def read_cache(cachefile, coltype=LIGOTimeGPS, sort=None, segment=None):
+@with_open
+def read_cache(
+    cachefile,
+    coltype=LIGOTimeGPS,
+    sort=None,
+    segment=None,
+    strict=False,
+):
     """Read a LAL- or FFL-format cache file as a list of file paths
 
     Parameters
     ----------
-    cachefile : `str`, `file`
+    cachefile : `str`, `pathlib.Path`, `file`
         Input file or file path to read.
 
     coltype : `LIGOTimeGPS`, `int`, optional
@@ -166,23 +200,22 @@ def read_cache(cachefile, coltype=LIGOTimeGPS, sort=None, segment=None):
         A GPS `[start, stop)` interval, if given only files overlapping this
         interval will be returned.
 
+    strict : `bool`, optional
+        If `False` warn about entries that don't follow the LIGO-T050017
+        standard, then skip them; if `True` all errors are raised as
+        exceptions.
+
     Returns
     -------
     paths : `list` of `str`
         A list of file paths as read from the cache file.
     """
-    # open file
-    if not isinstance(cachefile, FILE_LIKE):
-        with open(file_path(cachefile), 'r') as fobj:
-            return read_cache(fobj, coltype=coltype, sort=sort,
-                              segment=segment)
-
     # read file
     cache = [x.path for x in _iter_cache(cachefile, gpstype=coltype)]
 
     # sieve and sort
     if segment:
-        cache = sieve(cache, segment=segment)
+        cache = sieve(cache, segment=segment, strict=strict)
     if sort:
         cache.sort(key=sort)
 
@@ -190,7 +223,7 @@ def read_cache(cachefile, coltype=LIGOTimeGPS, sort=None, segment=None):
     return cache
 
 
-def read_cache_entry(line):
+def read_cache_entry(line, gpstype=LIGOTimeGPS):
     """Read a file path from a line in a cache file.
 
     Parameters
@@ -198,6 +231,9 @@ def read_cache_entry(line):
     line : `str`, `bytes`
         Line of text to parse
 
+    gpstype : `LIGOTimeGPS`, `int`, optional
+        Type for GPS times.
+
     Returns
     -------
     path : `str`
@@ -208,7 +244,7 @@ def read_cache_entry(line):
     ValueError
         if the line cannot be parsed successfully
     """
-    return _CacheEntry.parse(line).path
+    return _CacheEntry.parse(line, gpstype=gpstype).path
 
 
 def open_cache(*args, **kwargs):  # pragma: no cover
@@ -218,6 +254,7 @@ def open_cache(*args, **kwargs):  # pragma: no cover
     return read_cache(*args, **kwargs)
 
 
+@with_open(mode="w", pos=1)
 def write_cache(cache, fobj, format=None):
     """Write a `list` of cache entries to a file
 
@@ -226,7 +263,7 @@ def write_cache(cache, fobj, format=None):
     cache : `list` of `str`
         The list of file paths to write
 
-    fobj : `file`, `str`
+    fobj : `file`, `str`, `pathlib.Path`
         The open file object, or file path to write to.
 
     format : `str`, optional
@@ -236,11 +273,6 @@ def write_cache(cache, fobj, format=None):
         - ``'lal'`` : write a LAL-format cache
         - ``'ffl'`` : write an FFL-format cache
     """
-    # open file
-    if isinstance(fobj, str):
-        with open(fobj, 'w') as fobj2:
-            return write_cache(cache, fobj2, format=format)
-
     if format is None:
         formatter = str
     elif format.lower() == "lal":
@@ -248,14 +280,14 @@ def write_cache(cache, fobj, format=None):
     elif format.lower() == "ffl":
         formatter = _format_entry_ffl
     else:
-        raise ValueError("Unrecognised cache format {!r}".format(format))
+        raise ValueError(f"Unrecognised cache format {format!r}")
 
     # write file
     for line in map(formatter, cache):
         try:
             print(line, file=fobj)
         except TypeError:  # bytes-mode
-            fobj.write("{}\n".format(line).encode("utf-8"))
+            fobj.write(f"{line}\n".encode("utf-8"))
 
 
 def is_cache(cache):
@@ -272,11 +304,12 @@ def is_cache(cache):
         `True` if the input object is a cache, or a file in LAL cache format,
         otherwise `False`
     """
-    if isinstance(cache, (str,) + FILE_LIKE):
+    if isinstance(cache, (str, os.PathLike) + FILE_LIKE):
         try:
-            return bool(len(read_cache(cache)))
-        except (TypeError, ValueError, UnicodeDecodeError, ImportError):
-            # failed to parse cache
+            return bool(len(read_cache(cache, coltype=float)))
+        except Exception:
+            # if parsing the file as a cache fails for _any reason_
+            # presume it isn't a cache file
             return False
     if HAS_CACHE and isinstance(cache, Cache):
         return True
@@ -352,12 +385,13 @@ def filename_metadata(filename):
     ("A", "B", Segment(0.456, 1.801))
     """
     from ..segments import Segment
-    name = Path(filename).name
+    name = os.path.basename(filename)
     try:
         obs, desc, start, dur = name.split('-')
     except ValueError as exc:
-        exc.args = ('Failed to parse {!r} as LIGO-T050017-compatible '
-                    'filename'.format(name),)
+        exc.args = (
+            f'Failed to parse {name!r} as a LIGO-T050017-compatible filename',
+        )
         raise
     start = float(start)
     dur = dur.rsplit('.', 1)[0]
@@ -457,7 +491,7 @@ def find_contiguous(*caches):
         yield sieve(flat, segment=segment)
 
 
-def sieve(cache, segment=None):
+def sieve(cache, segment=None, strict=True):
     """Filter the cache to find those entries that overlap ``segment``
 
     Parameters
@@ -467,8 +501,32 @@ def sieve(cache, segment=None):
 
     segment : `~gwpy.segments.Segment`
         The ``[start, stop)`` interval to match against.
+
+    strict : `bool`, optional
+        If `True` raise all exceptions, if `False` emit warnings when
+        the file segment cannot be determined.
+
+    Warns
+    -----
+    UserWarning
+        For any files for which the file segment cannot be determined,
+        if ``strict=False`` is given; these files are excluded from the
+        sieved cache.
     """
-    return type(cache)(e for e in cache if segment.intersects(file_segment(e)))
+    out = type(cache)()
+    for e in cache:
+        try:  # try and get the segment for this entry
+            seg = file_segment(e)
+        except ValueError as exc:
+            # if running in 'strict' mode, raise all errors
+            if strict:
+                raise
+            # otherwise warn and ignore
+            warnings.warn(str(exc))
+            continue
+        if segment.intersects(seg):  # if overlaps, keep it
+            out.append(e)
+    return out
 
 
 # -- moved functions ----------------------------------------------------------
