@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -28,7 +28,6 @@ import numpy
 import pytest
 
 from ...segments import (Segment, SegmentList)
-from ...testing.utils import skip_missing_dependency
 from .. import cache as io_cache
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
@@ -38,8 +37,8 @@ SEGMENTS = SegmentList(map(Segment, [
     (1, 2),
     (4, 5),
 ]))
-CACHE = [os.path.join('tmp', 'A-B-%d-%d.tmp' % (seg[0], seg[1] - seg[0])) for
-         seg in SEGMENTS]
+CACHE = [os.path.join("tmp", f"A-B-{seg[0]}-{seg[1]-seg[0]}.tmp")
+         for seg in SEGMENTS]
 
 
 # -- fixtures -----------------------------------------------------------------
@@ -60,55 +59,56 @@ def segments():
     (None, CACHE[0]),
     pytest.param(
         "lal",
-        "A B {0[0]} {1} {2}".format(SEGMENTS[0], abs(SEGMENTS[0]), CACHE[0]),
+        f"A B {SEGMENTS[0][0]} {abs(SEGMENTS[0])} {CACHE[0]}",
         id="lal"),
     pytest.param(
         "ffl",
-        "{0} {1[0]} {2} 0 0".format(CACHE[0], SEGMENTS[0], abs(SEGMENTS[0])),
+        f"{CACHE[0]} {SEGMENTS[0][0]} {abs(SEGMENTS[0])} 0 0",
         id="ffl"),
 ])
-def test_read_write_cache(cache, tmpfile, format, entry1):
+def test_read_write_cache(cache, tmp_path, format, entry1):
+    tmp = tmp_path / "test.lcf"
+
     # write cache using filename
-    io_cache.write_cache(cache, tmpfile, format=format)
+    io_cache.write_cache(cache, tmp, format=format)
 
     # check that first line is proper LAL format
-    with open(tmpfile, "r") as tmp:
-        assert tmp.readline().strip() == entry1
+    with tmp.open("r") as tmpf:
+        assert tmpf.readline().strip() == entry1
 
     # now read it back ans check we get the same answer
-    assert io_cache.read_cache(tmpfile) == cache
+    assert io_cache.read_cache(tmp) == cache
 
     # check read/write with a file object
-    with open(tmpfile, "w") as tmp:
-        io_cache.write_cache(cache, tmp, format=format)
-    with open(tmpfile, "r") as tmp:
-        assert io_cache.read_cache(tmp) == cache
+    with tmp.open("w") as tmpf:
+        io_cache.write_cache(cache, tmpf, format=format)
+    with tmp.open("r") as tmpf:
+        assert io_cache.read_cache(tmpf) == cache
 
     # check sieving and sorting works
     assert io_cache.read_cache(
-        tmpfile,
+        tmp,
         sort=lambda e: -io_cache.filename_metadata(e)[2][0],
         segment=Segment(0, 2),
     ) == cache[1::-1]
 
 
-@skip_missing_dependency('lal.utils')
-def test_write_cache_cacheentry(cache, tmpfile):
+@pytest.mark.requires("lal.utils")
+def test_write_cache_cacheentry(cache, tmp_path):
     from lal.utils import CacheEntry
+    tmp = tmp_path / "test.lcf"
     lcache = list(map(CacheEntry.from_T050017, cache))
-    with open(tmpfile, 'w') as f:
-        io_cache.write_cache(lcache, f, format=None)
+    with tmp.open("w") as tmpf:
+        io_cache.write_cache(lcache, tmpf, format=None)
 
     # check first line looks like a LAL-format cache entry
-    with open(tmpfile, "r") as tmp:
-        assert tmp.readline().strip() == "A B {0[0]} {1} {2}".format(
-            SEGMENTS[0],
-            abs(SEGMENTS[0]),
-            CACHE[0],
+    with tmp.open("r") as tmpf:
+        assert tmpf.readline().strip() == (
+            f"A B {SEGMENTS[0][0]} {abs(SEGMENTS[0])} {CACHE[0]}"
         )
 
     # read from file name
-    assert io_cache.read_cache(tmpfile) == cache
+    assert io_cache.read_cache(tmp) == cache
 
 
 @pytest.mark.parametrize('input_, result', [
@@ -120,14 +120,14 @@ def test_is_cache(input_, result):
     assert io_cache.is_cache(input_) is result
 
 
-@skip_missing_dependency('lal.utils')
+@pytest.mark.requires("lal.utils")
 def test_is_cache_lal():
     cache = [io_cache.CacheEntry.from_T050017('/tmp/A-B-12345-6.txt')]
     assert io_cache.is_cache(cache)
     assert not io_cache.is_cache(cache + [None])
 
 
-@skip_missing_dependency('glue.lal')
+@pytest.mark.requires("glue.lal")
 def test_is_cache_glue():
     assert io_cache.is_cache(io_cache.Cache())
 
@@ -139,21 +139,29 @@ def test_is_cache_glue():
         assert io_cache.is_cache(f) is False
 
 
-@skip_missing_dependency('lal.utils')
-def test_is_cache_file():
-
-    # check file(path) is return as True if parsed as Cache
+@pytest.mark.requires("lal.utils")
+def test_is_cache_file(tmp_path):
+    """Check that `gwpy.io.cache.is_cache` returns `True` when it should
+    """
+    # write a cache file
     e = io_cache.CacheEntry.from_T050017('/tmp/A-B-12345-6.txt')
-    with tempfile.NamedTemporaryFile() as f:
-        # empty file should return False
-        assert io_cache.is_cache(f) is False
-        assert io_cache.is_cache(f.name) is False
+    tmp = tmp_path / "tmpfile"
+    io_cache.write_cache([e], tmp)
 
-        # cache file should return True
-        io_cache.write_cache([e], f)
-        f.seek(0)
-        assert io_cache.is_cache(f) is True
-        assert io_cache.is_cache(f.name) is True
+    # check that we can identify it properly
+    assert io_cache.is_cache(tmp)  # file name
+    with tmp.open("r") as tmpf:
+        assert io_cache.is_cache(tmpf)  # open file object
+
+
+@pytest.mark.requires("lal.utils")
+def test_is_cache_file_empty(tmp_path):
+    """Check that `gwpy.io.cache.is_cache` returns False when it should
+    """
+    tmp = tmp_path / "tmpfile"
+    assert not io_cache.is_cache(tmp)  # FileNotFoundError
+    tmp.touch()
+    assert not io_cache.is_cache(tmp)  # empty file
 
 
 def test_is_cache_entry():
@@ -200,13 +208,20 @@ def test_filename_metadata_error():
         io_cache.filename_metadata("A-B-0-4xml.gz")
 
 
-def test_file_segment():
+@pytest.mark.parametrize(("filename", "seg"), [
+    # basic
+    ("A-B-1-2.ext", Segment(1, 3)),
+    # multiple file extensions
+    ("A-B-1-2.ext.gz", Segment(1, 3)),
+    # non-integer
+    ("A-B-1.23-4.ext.gz", Segment(1.23, 5.23)),
+])
+def test_file_segment(filename, seg):
     """Test :func:`gwpy.io.cache.file_segment`
     """
-    # check basic
-    fs = io_cache.file_segment('A-B-1-2.ext')
+    fs = io_cache.file_segment(filename)
     assert isinstance(fs, Segment)
-    assert fs == Segment(1, 3)
+    assert fs == seg
 
     # check mutliple file extensions
     assert io_cache.file_segment('A-B-1-2.ext.gz') == (1, 3)
@@ -214,11 +229,15 @@ def test_file_segment():
     # check floats (and multiple file extensions)
     assert io_cache.file_segment('A-B-1.23-4.ext.gz') == (1.23, 5.23)
 
-    # test errors
-    with pytest.raises(ValueError) as exc:
+
+def test_file_segment_errors():
+    """Test :func:`gwpy.io.cache.file_segment` error handling.
+    """
+    with pytest.raises(
+        ValueError,
+        match="^Failed to parse 'blah' as a LIGO-T050017-compatible filename$"
+    ):
         io_cache.file_segment('blah')
-    assert str(exc.value) == ('Failed to parse \'blah\' as '
-                              'LIGO-T050017-compatible filename')
 
 
 def test_flatten(cache):
@@ -253,6 +272,28 @@ def test_sieve(cache, segments):
     assert io_cache.sieve(cache, segments[0]) == cache[:2]
 
 
+def test_sieve_strict():
+    """Check that the ``strict`` keyword does its job in :func:`sieve()`
+    """
+    cache = [
+        "A-B-0-1.txt",
+        "A-B-1-1.txt",
+        "A-B-2-1.txt",
+        "somethingelse.txt",
+    ]
+
+    # check that strict=True raises an error
+    with pytest.raises(ValueError):
+        io_cache.sieve(cache, Segment(0, 2), strict=True)
+
+    # but strict=False only emits a warning
+    with pytest.warns(UserWarning):
+        assert (
+            io_cache.sieve(cache, Segment(0, 2), strict=False)
+            == cache[:2]
+        )
+
+
 def test_file_list():
     with pytest.deprecated_call():
         assert io_cache.file_list("1,2,3") == ["1", "2", "3"]
