@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -27,7 +27,6 @@ import pytest
 from ...detector import Channel
 from ...segments import (Segment, SegmentList)
 from ...testing import mocks
-from ...testing.utils import skip_missing_dependency
 from ...utils.tests.test_enum import TestNumpyTypeEnum as _TestNumpyTypeEnum
 from .. import nds2 as io_nds2
 
@@ -38,16 +37,16 @@ class _TestNds2Enum(object):
     TEST_CLASS = None
 
     def test_any(self):
-        assert self.TEST_CLASS.any() == 2 ** (len(self.TEST_CLASS) - 1) - 1
+        assert self.TEST_CLASS.any() == 2 * max(self.TEST_CLASS).value - 1
 
     def test_find_errors(self):
         """Test error raising for :meth:`gwpy.io.nds2.Nds2ChannelType.find`
         """
-        with pytest.raises(ValueError) as exc:
+        with pytest.raises(
+            ValueError,
+            match=f"'blah' is not a valid {self.TEST_CLASS.__name__}",
+        ):
             self.TEST_CLASS.find('blah')
-        assert str(exc.value) == "'blah' is not a valid {}".format(
-            self.TEST_CLASS.__name__,
-        )
 
 
 class TestNds2ChannelType(_TestNds2Enum):
@@ -55,18 +54,30 @@ class TestNds2ChannelType(_TestNds2Enum):
     """
     TEST_CLASS = io_nds2.Nds2ChannelType
 
-    def test_name(self):
-        assert self.TEST_CLASS.MTREND.name == 'm-trend'
+    def test_nds2name(self):
+        assert self.TEST_CLASS.MTREND.nds2name == 'm-trend'
 
-    def test_names(self):
-        assert sorted(self.TEST_CLASS.names()) == sorted(
-            io_nds2.NDS2_TYPE_NAME.values())
+    def test_nds2names(self):
+        expected = sorted(
+            io_nds2._NDS2_CHANNEL_TYPE[x.name][1]
+            for x in self.TEST_CLASS
+        )
+        assert sorted(self.TEST_CLASS.nds2names()) == expected
 
-    @pytest.mark.parametrize('input_', ['m-trend', 'MTREND'])
-    def test_find(self, input_):
+    @pytest.mark.parametrize(('input_', 'expected'), (
+        (TEST_CLASS.MTREND.value, TEST_CLASS.MTREND),
+        (TEST_CLASS.MTREND.name, TEST_CLASS.MTREND),
+        (TEST_CLASS.MTREND.nds2name, TEST_CLASS.MTREND),
+        ('mtrend', TEST_CLASS.MTREND),
+        ('rds', TEST_CLASS.RDS),
+        ('RDS', TEST_CLASS.RDS),
+        ('reduced', TEST_CLASS.RDS),
+        ('REDUCED', TEST_CLASS.RDS),
+    ))
+    def test_find(self, input_, expected):
         """Test :meth:`gwpy.io.nds2.Nds2ChannelType.find`
         """
-        assert self.TEST_CLASS.find(input_) == self.TEST_CLASS.MTREND
+        assert self.TEST_CLASS.find(input_) == expected
 
 
 class TestNds2DataType(_TestNds2Enum, _TestNumpyTypeEnum):
@@ -161,7 +172,7 @@ def test_host_resolution_order_warning():
     assert len(record) == 1  # make sure only one warning was emitted
 
 
-@skip_missing_dependency('nds2')
+@pytest.mark.requires("nds2")
 @pytest.mark.parametrize('host, port, callport', [
     ('nds.test.gwpy', None, None),
     ('nds.test.gwpy', 31200, 31200),
@@ -178,7 +189,7 @@ def test_connect(connector, host, port, callport):
         connector.assert_called_once_with(host, callport)
 
 
-@skip_missing_dependency('nds2')
+@pytest.mark.requires("nds2")
 @mock.patch('gwpy.io.nds2.connect')
 def test_auth_connect(connect):
     """Test `gwpy.io.nds2.auth_connect`
@@ -187,7 +198,7 @@ def test_auth_connect(connect):
     connect.assert_called_once_with('host', 'port')
 
 
-@skip_missing_dependency('nds2')
+@pytest.mark.requires("nds2")
 @mock.patch('gwpy.io.nds2.kinit')
 @mock.patch(
     'gwpy.io.nds2.connect',
@@ -207,14 +218,13 @@ def test_auth_connect_kinit(connect, kinit):
     connect.assert_called_with('host', 'port')
 
 
-@skip_missing_dependency('nds2')
+@pytest.mark.requires("nds2")
 @mock.patch('gwpy.io.nds2.connect', side_effect=RuntimeError('Anything else'))
 def test_auth_connect_error(connect):
     """Test errors from `gwpy.io.nds2.auth_connect`
     """
-    with pytest.raises(RuntimeError) as exc:
+    with pytest.raises(RuntimeError, match="Anything else"):
         io_nds2.auth_connect('host', 'port')
-    assert str(exc.value) == 'Anything else'
     connect.assert_called_once_with("host", "port")
 
 
@@ -235,7 +245,7 @@ def test_open_connection(auth_connect):
     auth_connect.assert_called_once_with('test', None)
 
 
-@skip_missing_dependency('nds2')
+@pytest.mark.requires("nds2")
 @mock.patch('nds2.connection')
 def test_find_channels(connection):
     """Test `gwpy.io.nds2.find_channels`
@@ -280,14 +290,14 @@ def test_find_channels(connection):
 
     # test unique errors (with nds1 protocol)
     conn.find_channels.return_value = [chan, chan]  # any two channels
-    with pytest.raises(ValueError) as exc:
-        assert io_nds2.find_channels(['X1:test'], host='test',
-                                     unique=True) == [chan]
-    assert str(exc.value) == (
-        "unique NDS2 channel match not found for 'X1:test'")
+    with pytest.raises(
+        ValueError,
+        match="^unique NDS2 channel match not found for 'X1:test'$",
+    ):
+        io_nds2.find_channels(['X1:test'], host='test', unique=True)
 
 
-@skip_missing_dependency('nds2')
+@pytest.mark.requires("nds2")
 @mock.patch('gwpy.io.nds2.find_channels', return_value=['X1:test'])
 @mock.patch('gwpy.io.nds2.auth_connect')
 def test_get_availability(auth_connect, _):
@@ -329,7 +339,7 @@ def test_minute_trend_times(start, end, out):
     assert io_nds2.minute_trend_times(start, end) == out
 
 
-@skip_missing_dependency('nds2')
+@pytest.mark.requires("nds2")
 def test_get_nds2_name():
     """Test `gwpy.io.nds2._get_nds2_name`
     """
@@ -344,7 +354,7 @@ def test_get_nds2_name():
         assert io_nds2._get_nds2_name(channel) == name
 
 
-@skip_missing_dependency('nds2')
+@pytest.mark.requires("nds2")
 def test_get_nds2_names():
     """Test `gwpy.io.nds2._get_nds2_names`
     """
