@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2018-2021)
+# Copyright (C) Cardiff University (2018-2022)
 #
 # This file is part of GWpy.
 #
@@ -28,7 +28,10 @@ import numpy
 
 from astropy.time import Time
 
-from matplotlib import rcParams
+from matplotlib import (
+    __version__ as matplotlib_version,
+    rcParams,
+)
 from matplotlib.artist import allow_rasterization
 from matplotlib.axes import Axes as _Axes
 from matplotlib.axes._base import _process_plot_var_args
@@ -78,7 +81,14 @@ def xlim_as_gps(func):
 
 def restore_grid(func):
     """Wrap ``func`` to preserve the Axes current grid settings.
+
+    Prior to matplotlib 3.7.0 (unreleased ATOW) pcolor() and pcolormesh()
+    automatically removed a grid on a set of Axes. This decorator just
+    undoes that.
     """
+    if matplotlib_version >= "3.7.0":
+        return func
+
     @wraps(func)
     def wrapped_func(self, *args, **kwargs):
         try:
@@ -91,6 +101,11 @@ def restore_grid(func):
         except KeyError:  # matplotlib < 3.3.3
             grid = (self.xaxis._gridOnMinor, self.xaxis._gridOnMajor,
                     self.yaxis._gridOnMinor, self.yaxis._gridOnMajor)
+        # matplotlib >=3.5.0,<3.7.0 presents a warning if you have a grid
+        # that it won't be automatically removed, so we forcibly remove it
+        # ahead of time, knowing that if we had one, we will restore it
+        # in the 'finally' block below.
+        self.grid(False)
         try:
             return func(self, *args, **kwargs)
         finally:
@@ -102,6 +117,44 @@ def restore_grid(func):
     return wrapped_func
 
 
+def deprecate_c_sort(func):
+    """Wrap ``func`` to replace the deprecated ``c_sort`` keyword.
+
+    This was renamed ``sortbycolor``.
+    """
+    @wraps(func)
+    def wrapped(self, *args, **kwargs):
+        if "c_sort" in kwargs:
+            warnings.warn(
+                f"the `c_sort` keyword for {func.__name__} was "
+                "renamed `sortbycolor`, this warning will result "
+                "in an error in future versions of GWpy",
+                DeprecationWarning,
+            )
+            kwargs.setdefault(
+                "sortbycolor",
+                kwargs.pop("c_sort"),
+            )
+        return func(self, *args, **kwargs)
+    return wrapped
+
+
+def _sortby(sortby, *arrays):
+    """Sort a set of arrays by the first one (including the first one)
+    """
+    # try and sort the colour array by value
+    sortidx = numpy.asanyarray(sortby, dtype=float).argsort()
+
+    def _sort(arr):
+        if arr is None or isinstance(arr, Number):
+            return arr
+        return numpy.asarray(arr)[sortidx]
+
+    # apply the sorting to each data array, and scatter
+    for arr in (sortby,) + arrays:
+        yield _sort(arr)
+
+
 # -- new Axes -----------------------------------------------------------------
 
 class Axes(_Axes):
@@ -109,7 +162,10 @@ class Axes(_Axes):
         super().__init__(*args, **kwargs)
 
         # handle Series in `ax.plot()`
-        self._get_lines = PlotArgsProcessor(self)
+        if matplotlib_version >= "3.8.0":
+            self._get_lines = PlotArgsProcessor()
+        else:
+            self._get_lines = PlotArgsProcessor(self)
 
         # reset data formatters (for interactive plots) to support
         # GPS time display
@@ -128,8 +184,7 @@ class Axes(_Axes):
                 unit = trans.get_unit_name()
                 iso = Time(epoch, format='gps', scale='utc').iso
                 utc = iso.rstrip('0').rstrip('.')
-                ax.set_label_text('Time [{0!s}] from {1!s} UTC ({2!r})'.format(
-                    unit, utc, epoch))
+                ax.set_label_text(f"Time [{unit}] from {utc} UTC ({epoch!r})")
 
         try:
             super().draw(*args, **kwargs)
@@ -176,33 +231,23 @@ class Axes(_Axes):
 
     # -- overloaded plotting methods ------------
 
+    @deprecate_c_sort
     def scatter(self, x, y, s=None, c=None, **kwargs):
         # This method overloads Axes.scatter to enable quick
         # sorting of data by the 'colour' array before scatter
         # plotting.
 
-        # if we weren't asked to sort, or don't have any colours, don't
-        sort = kwargs.pop("sortbycolor", False)
-        if not sort:
-            return super().scatter(x, y, s=s, c=c, **kwargs)
+        if kwargs.pop("sortbycolor", False) and c is not None:
+            # try and sort the colour array by value
+            try:
+                c, x, y, s = _sortby(c, x, y, s)
+            except ValueError as exc:
+                exc.args = (
+                    "Axes.scatter argument 'sortbycolor' can only be used "
+                    "with a simple array of floats in the colour array 'c'",
+                )
+                raise
 
-        # try and sort the colour array by value
-        try:
-            sortidx = numpy.asanyarray(c, dtype=float).argsort()
-        except ValueError as exc:
-            exc.args = (
-                "Axes.scatter argument 'sortbycolor' can only be used "
-                "with a simple array of floats in the colour array 'c'",
-            )
-            raise
-
-        def _sort(arr):
-            if arr is None or isinstance(arr, Number):
-                return arr
-            return numpy.asarray(arr)[sortidx]
-
-        # apply the sorting to each data array, and scatter
-        x, y, c, s = map(_sort, (x, y, c, s))
         return super().scatter(x, y, s=s, c=c, **kwargs)
 
     scatter.__doc__ = _Axes.scatter.__doc__.replace(
@@ -415,6 +460,7 @@ class Axes(_Axes):
 
         return out
 
+    @deprecate_c_sort
     def tile(self, x, y, w, h, color=None,
              anchor='center', edgecolors='face', linewidth=0.8,
              **kwargs):
@@ -465,14 +511,16 @@ class Axes(_Axes):
         >>> ax.tile(x, y, w, h, anchor='ll')
         >>> pyplot.show()
         """
-        # get color and sort
-        if color is not None and kwargs.get('c_sort', True):
-            sortidx = color.argsort()
-            x = x[sortidx]
-            y = y[sortidx]
-            w = w[sortidx]
-            h = h[sortidx]
-            color = color[sortidx]
+        if kwargs.pop("sortbycolor", False) and color is not None:
+            # try and sort the colour array by value
+            try:
+                color, x, y, w, h = _sortby(color, x, y, w, h)
+            except ValueError as exc:
+                exc.args = (
+                    "Axes.tile argument 'sortbycolor' can only be used "
+                    "with a simple array of floats in the `color` array",
+                )
+                raise
 
         # define how to make a polygon for each tile
         if anchor == 'll':
@@ -492,7 +540,7 @@ class Axes(_Axes):
                 return ((x-w/2., y-h/2.), (x-w/2., y+h/2.),
                         (x+w/2., y+h/2.), (x+w/2., y-h/2.))
         else:
-            raise ValueError("Unrecognised tile anchor {!r}".format(anchor))
+            raise ValueError(f"Unrecognised tile anchor '{anchor}'")
 
         # build collection
         cmap = kwargs.pop('cmap', rcParams['image.cmap'])
@@ -510,30 +558,10 @@ class Axes(_Axes):
     # -- overloaded auxiliary methods -----------
 
     def legend(self, *args, **kwargs):
-        # handle deprecated keywords
-        linewidth = kwargs.pop("linewidth", None)
-        if linewidth:
-            warnings.warn(
-                "the linewidth keyword to gwpy.plot.Axes.legend has been "
-                "deprecated and will be removed in a future release; "
-                "please update your code to use a custom legend handler, "
-                "e.g. gwpy.plot.legend.HandlerLine2D.",
-                DeprecationWarning,
-            )
-        alpha = kwargs.pop("alpha", None)
-        if alpha:
-            kwargs.setdefault("framealpha", alpha)
-            warnings.warn(
-                "the alpha keyword to gwpy.plot.Axes.legend has been "
-                "deprecated and will be removed in a future release; "
-                "use framealpha instead.",
-                DeprecationWarning,
-            )
-
-        # build custom handler
+        # build custom handler to render thick lines by default
         handler_map = kwargs.setdefault("handler_map", dict())
         if isinstance(handler_map, dict):
-            handler_map.setdefault(Line2D, HandlerLine2D(linewidth or 6))
+            handler_map.setdefault(Line2D, HandlerLine2D(6))
 
         # create legend
         return super().legend(*args, **kwargs)
@@ -610,6 +638,10 @@ class PlotArgsProcessor(_process_plot_var_args):
         """Find `Series` data in `plot()` args and unwrap
         """
         newargs = []
+        # matplotlib 3.8.0 includes the Axes object up-front
+        if args and isinstance(args[0], Axes):
+            newargs.append(args[0])
+            args = args[1:]
         while args:
             # strip first argument
             this, args = args[:1], args[1:]
