@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -73,7 +73,7 @@ class BodePlot(Plot):
     frequencies : `numpy.ndarray`, optional
         list of frequencies (in Hertz) at which to plot
 
-    db : `bool`, optional, default: `True`
+    dB : `bool`, optional, default: `True`
         if `True`, display magnitude in decibels, otherwise display
         amplitude.
 
