@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Louisiana State University (2014-2017)
+#               Cardiff University (2017-2022)
 #
 # This file is part of GWpy.
 #
@@ -21,13 +22,17 @@
 
 import itertools
 import importlib
-import warnings
 from collections.abc import (KeysView, ValuesView)
 from itertools import zip_longest
 
 import numpy
 
-from matplotlib import (figure, get_backend, _pylab_helpers)
+from matplotlib import (
+    _pylab_helpers,
+    backends,
+    figure,
+    get_backend,
+)
 from matplotlib.artist import setp
 from matplotlib.gridspec import GridSpec
 from matplotlib.ticker import LogFormatterSciNotation
@@ -53,7 +58,12 @@ iterable_types = (list, tuple, KeysView, ValuesView,)
 def interactive_backend():
     """Returns `True` if the current backend is interactive
     """
-    from matplotlib.rcsetup import interactive_bk
+    try:
+        interactive_bk = backends.backend_registry.list_builtin(
+            backends.BackendFilter.INTERACTIVE,
+        )
+    except AttributeError:  # matplotlib < 3.9.0
+        from matplotlib.rcsetup import interactive_bk
     return get_backend() in interactive_bk
 
 
@@ -78,8 +88,10 @@ def get_backend_mod(name=None):
     """
     if name is None:
         name = get_backend()
-    backend_name = (name[9:] if name.startswith("module://") else
-                    "matplotlib.backends.backend_{}".format(name.lower()))
+    backend_name = (
+        name[9:] if name.startswith("module://")
+        else f"matplotlib.backends.backend_{name.lower()}"
+    )
     return importlib.import_module(backend_name)
 
 
@@ -164,9 +176,10 @@ class Plot(figure.Figure):
         nrows, ncols = geometry
         if axes_groups and nrows * ncols != len(axes_groups):
             # mismatching data and geometry
-            raise ValueError("cannot group data into {0} axes with a "
-                             "{1}x{2} grid".format(len(axes_groups), nrows,
-                                                   ncols))
+            raise ValueError(
+                f"cannot group data into {len(axes_groups)} with "
+                f"a {nrows}x{ncols} grid"
+            )
 
         # create grid spec
         gs = GridSpec(nrows, ncols)
@@ -179,8 +192,10 @@ class Plot(figure.Figure):
         for axis in ('x', 'y'):
             unit = _common_axis_unit(flatdata, axis=axis)
             if unit:
-                axes_kw.setdefault('{}label'.format(axis),
-                                   unit.to_string('latex_inline_dimensional'))
+                axes_kw.setdefault(
+                    f"{axis}label",
+                    unit.to_string('latex_inline_dimensional'),
+                )
 
         # create axes for each group and draw each data object
         for group, (row, col) in zip_longest(
@@ -222,11 +237,14 @@ class Plot(figure.Figure):
         # -- only if the user hasn't customised the subplot params
         figsize = kwargs.get('figsize') or rcParams['figure.figsize']
         subplotpars = get_subplot_params(figsize)
-        use_subplotpars = 'subplotpars' not in kwargs and all([
-            rcParams['figure.subplot.%s' % pos]
-            == MPL_RCPARAMS['figure.subplot.%s' % pos]
-            for pos in ('left', 'bottom', 'right', 'top')
-        ])
+        use_subplotpars = (
+            'subplotpars' not in kwargs
+            and all([
+                rcParams[f"figure.subplot.{pos}"]
+                == MPL_RCPARAMS[f"figure.subplot.{pos}"]
+                for pos in ('left', 'bottom', 'right', 'top')
+            ])
+        )
         if use_subplotpars:
             kwargs['subplotpars'] = subplotpars
 
@@ -328,12 +346,22 @@ class Plot(figure.Figure):
 
     # -- colour bars ----------------------------
 
-    def colorbar(self, mappable=None, cax=None, ax=None, fraction=0.,
-                 emit=True, **kwargs):
-        """Add a colorbar to the current `Plot`
+    def colorbar(
+        self,
+        mappable=None,
+        cax=None,
+        ax=None,
+        fraction=0.,
+        use_axesgrid=True,
+        emit=True,
+        **kwargs,
+    ):
+        """Add a colorbar to the current `Plot`.
 
-        A colorbar must be associated with an `Axes` on this `Plot`,
-        and an existing mappable element (e.g. an image).
+        This method differs from the default
+        :meth:`matplotlib.figure.Figure.colorbar` in that it doesn't
+        resize the parent `Axes` to accommodate the colorbar, but rather
+        draws a new Axes alongside it.
 
         Parameters
         ----------
@@ -347,8 +375,16 @@ class Plot(figure.Figure):
             Axes relative to which to position colorbar
 
         fraction : `float`, optional
-            Fraction of original axes to use for colorbar, give `fraction=0`
-            to not resize the original axes at all.
+            Fraction of original axes to use for colorbar.
+            The default (``fraction=0``) is to not resize the
+            original axes at all.
+
+        use_axesgrid : `bool`
+            Use :mod:`mpl_toolkits.axes_grid1` to generate the
+            colorbar axes (default: `True`).
+            This takes precedence over the ``use_gridspec``
+            keyword argument from the upstream
+            :meth:`~matplotlib.figure.Figure.colorbar` method.
 
         emit : `bool`, optional
             If `True` update all mappables on `Axes` to match the same
@@ -363,6 +399,11 @@ class Plot(figure.Figure):
         cbar : `~matplotlib.colorbar.Colorbar`
             the newly added `Colorbar`
 
+        Notes
+        -----
+        To revert to the default matplotlib behaviour, pass
+        ``use_axesgrid=False, fraction=0.15``.
+
         See also
         --------
         matplotlib.figure.Figure.colorbar
@@ -427,15 +468,6 @@ class Plot(figure.Figure):
 
         return cbar
 
-    def add_colorbar(self, *args, **kwargs):
-        """DEPRECATED, use `Plot.colorbar` instead
-        """
-        warnings.warn(
-            "{0}.add_colorbar was renamed {0}.colorbar, this warnings will "
-            "result in an error in the future".format(type(self).__name__),
-            DeprecationWarning)
-        return self.colorbar(*args, **kwargs)
-
     # -- extra methods --------------------------
 
     def add_segments_bar(self, segments, ax=None, height=0.14, pad=0.1,
@@ -482,7 +514,6 @@ class Plot(figure.Figure):
         # set options for new axes
         axes_kw = {
             'pad': pad,
-            'add_to_figure': True,
             'sharex': ax if sharex is True else sharex or None,
             'axes_class': get_projection_class('segments'),
         }
@@ -498,9 +529,11 @@ class Plot(figure.Figure):
             pass
 
         # add new axes
-        if ax.get_axes_locator():
+        try:
             divider = ax.get_axes_locator()._axes_divider
-        else:
+        except AttributeError:
+            # get_axes_locator() is None _or_ the _axes_divider property
+            # has been removed
             from mpl_toolkits.axes_grid1 import make_axes_locatable
             divider = make_axes_locatable(ax)
         if location not in {'top', 'bottom'}:
@@ -519,19 +552,11 @@ class Plot(figure.Figure):
 
         # plot segments
         segax.plot(segments, **plotargs)
-        segax.grid(b=False, which='both', axis='y')
+        segax.grid(False, which='both', axis='y')
         segax.autoscale(axis='y', tight=True)
 
         return segax
 
-    def add_state_segments(self, *args, **kwargs):
-        """DEPRECATED: use :meth:`Plot.add_segments_bar`
-        """
-        warnings.warn('add_state_segments() was renamed add_segments_bar(), '
-                      'this warning will result in an error in the future',
-                      DeprecationWarning)
-        return self.add_segments_bar(*args, **kwargs)
-
 
 # -- utilities ----------------------------------------------------------------
 
@@ -620,7 +645,7 @@ def _group_axes_data(inputs, separate=None, flat=False):
 
 def _common_axis_unit(data, axis='x'):
     units = set()
-    uname = '{}unit'.format(axis)
+    uname = f"{axis}unit"
     for x in data:
         units.add(getattr(x, uname, None))
     if len(units) == 1:
