@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Louisiana State University (2014-2017)
+#               Cardiff University (2017-2022)
 #
 # This file is part of GWpy.
 #
@@ -19,8 +20,6 @@
 """Plotting utilities for segments
 """
 
-import warnings
-
 from matplotlib.artist import allow_rasterization
 from matplotlib.colors import is_color_like
 from matplotlib.ticker import (Formatter, MultipleLocator)
@@ -89,8 +88,10 @@ class SegmentAxes(Axes):
             return self.plot_segmentlistdict
         if isinstance(obj, ligo.segments.segmentlist):
             return self.plot_segmentlist
-        raise TypeError("no known {0}.plot_xxx method for {1}".format(
-            type(self).__name__, type(obj).__name__))
+        raise TypeError(
+            f"no known {type(self).__name__}.plot_xxx method "
+            f"for {type(obj).__name__}",
+        )
 
     def plot(self, *args, **kwargs):
         """Plot data onto these axes
@@ -176,12 +177,6 @@ class SegmentAxes(Axes):
                                       **kwargs))
         return out
 
-    def plot_dqdict(self, *args, **kwargs):
-        warnings.warn('plot_dqdict() was renamed plot_dict; this warning will '
-                      'result in an error in an upcoming release',
-                      DeprecationWarning)
-        return self.plot_dict(*args, **kwargs)
-
     def plot_flag(self, flag, y=None, **kwargs):
         """Plot a `~gwpy.segments.DataQualityFlag` onto these axes.
 
@@ -256,12 +251,6 @@ class SegmentAxes(Axes):
 
         return coll  # return active collection
 
-    def plot_dqflag(self, *args, **kwargs):
-        warnings.warn('plot_dqflag() was renamed plot_flag; this warning will '
-                      'result in an error in an upcoming release',
-                      DeprecationWarning)
-        return self.plot_flag(*args, **kwargs)
-
     def plot_segmentlist(self, segmentlist, y=None, height=.8, label=None,
                          collection=True, rasterized=None, **kwargs):
         """Plot a `~gwpy.segments.SegmentList` onto these axes
