@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2018-2021)
+# Copyright (C) Duncan Macleod (2018-2020)
 #
 # This file is part of GWpy.
 #
@@ -19,15 +19,11 @@
 """Tests for `gwpy.plot.log`
 """
 
-try:
-    from unittest import mock
-except ImportError:  # python < 3
-    import mock
+from unittest import mock
 
 import pytest
 
 from matplotlib import (
-    __version__ as mpl_version,
     rc_context,
 )
 
@@ -58,7 +54,7 @@ class TestLogFormatter(object):
             1,
             None,
             r'$\mathdefault{10^{0}}$',
-            r'$\mathdefault{10^{0}}$' if mpl_version > "3.2.1" else "$10^{0}$",
+            r'$\mathdefault{10^{0}}$',
             id="fmt=None",
         ),
         pytest.param(
