@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2018-2021)
+# Copyright (C) Duncan Macleod (2018-2020)
 #
 # This file is part of GWpy.
 #
@@ -69,11 +69,6 @@ class TestSegmentAxes(_TestAxes):
         c = ax.plot_flag(flag, known={'facecolor': 'black'})
         c = ax.plot_flag(flag, known='fancy')
 
-    def test_plot_dqflag(self, ax, flag):
-        with pytest.deprecated_call():
-            ax.plot_dqflag(flag)
-        assert ax.collections  # make sure it plotted something
-
     def test_plot_dict(self, ax, flag):
         dqd = DataQualityDict()
         dqd['a'] = flag
@@ -90,10 +85,6 @@ class TestSegmentAxes(_TestAxes):
         colls = ax.plot_dict(dqd, label='anything')
         assert colls[0].get_label() == 'anything'
 
-    def test_plot_dqdict(self, ax, flag):
-        with pytest.deprecated_call():
-            ax.plot_dqdict(DataQualityDict(a=flag))
-
     def test_plot_segmentlist(self, ax, segments):
         c = ax.plot_segmentlist(segments)
         assert isinstance(c, PatchCollection)
@@ -145,7 +136,7 @@ class TestSegmentAxes(_TestAxes):
     # -- disable tests from upstream
 
     def test_imshow(self):
-        return NotImplemented
+        pytest.skip(f"not implemented for {type(self).__name__}")
 
 
 def test_segmentrectangle():
