@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2018-2021)
+# Copyright (C) Duncan Macleod (2018-2020)
 #
 # This file is part of GWpy.
 #
@@ -26,18 +26,41 @@ import pytest
 from .. import tex as plot_tex
 
 
-def which_patcher(error=False):
-    def which_(arg):
-        if error:
-            raise ValueError
-        return arg
-    return which_
+def _which(arg):
+    """Fake which to force pdflatex to being not found
+    """
+    if arg == "pdflatex":
+        return None
+    return arg
 
 
-@pytest.mark.parametrize('error', (False, True))
-def test_has_tex(error):
-    with mock.patch('gwpy.plot.tex.which', side_effect=which_patcher(error)):
-        assert plot_tex.has_tex() is not error
+@mock.patch("gwpy.plot.tex.which", _which)
+def test_has_tex_missing_exe():
+    """Test that `gwpy.plot.tex.has_tex` returns `False` when
+    any one of the necessary executables is missing.
+    """
+    plot_tex.has_tex.cache_clear()
+    assert not plot_tex.has_tex()
+
+
+@mock.patch("gwpy.plot.tex._test_usetex", side_effect=RuntimeError)
+def test_has_tex_bad_latex(_):
+    """Test that `gwpy.plot.tex.has_tex` returns `False` when
+    the LaTeX figure fails to render.
+    """
+    plot_tex.has_tex.cache_clear()
+    assert not plot_tex.has_tex()
+
+
+@mock.patch("gwpy.plot.tex.which", return_value="path")
+@mock.patch("gwpy.plot.tex._test_usetex")
+def test_has_tex_true(_which_, _test_usetex):
+    """Test that `gwpy.plot.tex.has_tex` returns `True` when
+    all of the necessary executables are found, and the LaTeX figure
+    doesn't raise an exception.
+    """
+    plot_tex.has_tex.cache_clear()
+    assert plot_tex.has_tex()
 
 
 @pytest.mark.parametrize('in_, out', [
