@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Louisiana State University (2014-2017)
+#               Cardiff University (2017-2021)
 #
 # This file is part of GWpy.
 #
@@ -20,8 +21,8 @@
 """
 
 import re
-
-from ..utils.shell import which
+from functools import lru_cache
+from shutil import which
 
 __author__ = "Duncan Macleod <duncan.macleod@ligo.org>"
 
@@ -32,32 +33,52 @@ MACROS = [
 ]
 
 
+def _test_usetex():
+    """Draw (but don't show) a test image using matplotlib and LaTeX.
+    """
+    from matplotlib import (pyplot, rc_context)
+    with rc_context({"text.usetex": True}):
+        fig = pyplot.figure()
+        try:
+            ax = fig.gca()
+            ax.set_xlabel(r"\LaTeX")
+            fig.canvas.draw()
+        finally:
+            pyplot.close(fig)
+
+
+@lru_cache(maxsize=None)
 def has_tex():
     """Returns whether tex is installed on this system
 
-    Checks for ``latex``, ``pdflatex``, and ``dvipng`` on the path.
+    Checks for ``latex``, ``pdflatex``, and ``dvipng`` on the path, and
+    then attemps to draw an image using LaTeX syntax.
 
     Returns
     -------
     hastex : `bool`
-        `True` if all required executables are found on the path, otherwise
-        `False`
+        `True` if the test image is drawn correctly, otherwise `False`
     """
+    # run basic sanity checks
     for exe in ('latex', 'pdflatex', 'dvipng'):
-        try:
-            which(exe)
-        except (ValueError, KeyError):
+        if which(exe) is None:
             return False
+
+    # attempt to render an image with latex
+    try:
+        _test_usetex()
+    except Exception:  # failed for any reason
+        return False
+
     return True
 
 
-HAS_TEX = has_tex()
-
 # -- tex formatting -----------------------------------------------------------
 
 LATEX_CONTROL_CHARS = ["%", "\\", "_", "~", "&", "#"]
-re_latex_control = re.compile(r'(?<!\\)[%s](?!.*{)'
-                              % ''.join(LATEX_CONTROL_CHARS))
+re_latex_control = re.compile(
+    rf"(?<!\\)[{''.join(LATEX_CONTROL_CHARS)}](?!.*{{)",
+)
 
 
 def float_to_latex(x, format="%.2g"):  # pylint: disable=redefined-builtin
@@ -103,8 +124,8 @@ def float_to_latex(x, format="%.2g"):  # pylint: disable=redefined-builtin
     if exponent.startswith('-0'):
         exponent = '-' + exponent[2:]
     if float(mantissa) == 1.0:
-        return r"10^{%s}" % exponent
-    return r"%s\!\!\times\!\!10^{%s}" % (mantissa, exponent)
+        return fr"10^{{{exponent}}}"
+    return fr"{mantissa}\!\!\times\!\!10^{{{exponent}}}"
 
 
 def label_to_latex(text):
@@ -147,7 +168,7 @@ def label_to_latex(text):
         a, b = m.span()
         char = m.group()[0]
         out.append(text[x:a])
-        out.append(r'\%s' % char)
+        out.append(fr"\{char}")
         x = b
     if not x:  # no match
         return text
