@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2018-2021)
+# Copyright (C) Louisiana State University (2014-2017)
+#               Cardiff University (2017-2021)
 #
 # This file is part of GWpy.
 #
@@ -23,17 +24,31 @@ from astropy.units.format import LatexInline
 
 
 class LatexInlineDimensional(LatexInline):
-    """Custom LaTeX formatter that includes physical type (if available)
+    r"""Custom LaTeX formatter that includes physical type (if available)
 
-    Mainly for auto-labelling `Axes` in matplotlib figures
+    Mainly for auto-labelling `Axes` in matplotlib figures.
+
+    Examples
+    --------
+    The built-in astropy ``latex_inline`` formatter gives this:
+
+    >>> Unit('m/s').to_string(format='latex_inline')
+    '$\mathrm{m\,s^{-1}}$'
+
+    This custom 'dimensional' formatter gives:
+
+    >>> Unit('m/s').to_string(format='latex_inline_dimensional')
+    'Speed [$\mathrm{m\,s^{-1}}$]'
     """
     name = 'latex_inline_dimensional'
 
     @classmethod
-    def to_string(cls, unit):
-        u = '[{0}]'.format(super().to_string(unit))
+    def to_string(cls, unit, *args, **kwargs):
+        u = f"[{super().to_string(unit, *args, **kwargs)}]"
 
         if unit.physical_type not in {None, 'unknown', 'dimensionless'}:
-            ptype = cls._latex_escape(unit.physical_type.title())
-            return '{0} {1}'.format(ptype, u)
+            # format physical type of unit for LaTeX
+            ptype = str(unit.physical_type).title().replace("_", r"\_")
+            # return '<Physical type> [<unit>]'
+            return f"{ptype} {u}"
         return u
