@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Louisiana State University (2014-2017)
+#               Cardiff University (2017-2023)
 #
 # This file is part of GWpy.
 #
@@ -70,16 +71,6 @@ DEFAULT_SEGMENT_SERVER = os.getenv('DEFAULT_SEGMENT_SERVER',
 
 # -- utilities ----------------------------------------------------------------
 
-def _select_query_method(cls, url):
-    """Select the correct query method based on the URL
-
-    Works for `DataQualityFlag` and `DataQualityDict`
-    """
-    if urlparse(url).netloc.startswith('geosegdb.'):  # only DB2 server
-        return cls.query_segdb
-    return cls.query_dqsegdb
-
-
 def _parse_query_segments(args, func):
     """Parse *args for query_dqsegdb() or query_segdb()
 
@@ -361,95 +352,6 @@ class DataQualityFlag(object):
 
     # -- classmethods ---------------------------
 
-    @classmethod
-    def query(cls, flag, *args, **kwargs):
-        """Query for segments of a given flag
-
-        This method intelligently selects the `~DataQualityFlag.query_segdb`
-        or the `~DataQualityFlag.query_dqsegdb` methods based on the
-        ``url`` kwarg given.
-
-        Parameters
-        ----------
-        flag : `str`
-            The name of the flag for which to query
-
-        *args
-            Either, two `float`-like numbers indicating the
-            GPS [start, stop) interval, or a `SegmentList`
-            defining a number of summary segments
-
-        url : `str`, optional
-            URL of the segment database, defaults to
-            ``$DEFAULT_SEGMENT_SERVER`` environment variable, or
-            ``'https://segments.ligo.org'``
-
-        See also
-        --------
-        DataQualityFlag.query_segdb
-        DataQualityFlag.query_dqsegdb
-            for details on the actual query engine, and documentation of
-            other keyword arguments appropriate for each query
-
-        Returns
-        -------
-        flag : `DataQualityFlag`
-            A new `DataQualityFlag`, with the `known` and `active` lists
-            filled appropriately.
-        """
-        query_ = _select_query_method(
-            cls, kwargs.get('url', DEFAULT_SEGMENT_SERVER))
-        return query_(flag, *args, **kwargs)
-
-    @classmethod
-    def query_segdb(cls, flag, *args, **kwargs):
-        """Query the initial LIGO segment database for the given flag
-
-        Parameters
-        ----------
-        flag : `str`
-            The name of the flag for which to query
-
-        *args
-            Either, two `float`-like numbers indicating the
-            GPS [start, stop) interval, or a `SegmentList`
-            defining a number of summary segments
-
-        url : `str`, optional
-            URL of the segment database, defaults to
-            ``$DEFAULT_SEGMENT_SERVER`` environment variable, or
-            ``'https://segments.ligo.org'``
-
-        Returns
-        -------
-        flag : `DataQualityFlag`
-            A new `DataQualityFlag`, with the `known` and `active` lists
-            filled appropriately.
-        """
-        warnings.warn("query_segdb is deprecated and will be removed in a "
-                      "future release", DeprecationWarning)
-
-        # parse arguments
-        qsegs = _parse_query_segments(args, cls.query_segdb)
-
-        # process query
-        try:
-            flags = DataQualityDict.query_segdb([flag], qsegs, **kwargs)
-        except TypeError as exc:
-            if 'DataQualityDict' in str(exc):
-                raise TypeError(str(exc).replace('DataQualityDict',
-                                                 cls.__name__))
-            else:
-                raise
-        if len(flags) > 1:
-            raise RuntimeError("Multiple flags returned for single query, "
-                               "something went wrong:\n    %s"
-                               % '\n    '.join(flags.keys()))
-        elif len(flags) == 0:
-            raise RuntimeError("No flags returned for single query, "
-                               "something went wrong.")
-        return flags[flag]
-
     @classmethod
     def query_dqsegdb(cls, flag, *args, **kwargs):
         """Query the advanced LIGO DQSegDB for the given flag
@@ -518,6 +420,9 @@ class DataQualityFlag(object):
 
         return out
 
+    # alias for compatibility
+    query = query_dqsegdb
+
     @classmethod
     def fetch_open_data(cls, flag, start, end, **kwargs):
         """Fetch Open Data timeline segments into a flag.
@@ -538,7 +443,7 @@ class DataQualityFlag(object):
             timeout for download (seconds)
 
         host : `str`, optional
-            URL of LOSC host, default: ``'losc.ligo.org'``
+            URL of GWOSC host, default: ``'https://gwosc.org'``
 
         Returns
         -------
@@ -548,18 +453,20 @@ class DataQualityFlag(object):
         Examples
         --------
         >>> from gwpy.segments import DataQualityFlag
-        >>> print(DataQualityFlag.fetch_open_data('H1_DATA', 'Jan 1 2010',
-        ...                                       'Jan 2 2010'))
+        >>> print(DataQualityFlag.fetch_open_data(
+        ...     "H1_DATA",
+        ...     "Sep 14 2015",
+        ...     "Sep 15 2015",
+        ... ))
         <DataQualityFlag('H1:DATA',
-                         known=[[946339215 ... 946425615)],
-                         active=[[946340946 ... 946351800)
-                                 [946356479 ... 946360620)
-                                 [946362652 ... 946369150)
-                                 [946372854 ... 946382630)
-                                 [946395595 ... 946396751)
-                                 [946400173 ... 946404977)
-                                 [946412312 ... 946413577)
-                                 [946415770 ... 946422986)],
+                         known=[[1126224017 ... 1126310417)]
+                         active=[[1126251604 ... 1126252133)
+                                 [1126252291 ... 1126274322)
+                                 [1126276234 ... 1126281754)
+                               ...
+                                 [1126308670 ... 1126309577)
+                                 [1126309637 ... 1126309817)
+                                 [1126309877 ... 1126310417)]
                          description=None)>
         """
         start = to_gps(start).gpsSeconds
@@ -1068,135 +975,6 @@ class DataQualityDict(OrderedDict):
 
     # -- classmethods ---------------------------
 
-    @classmethod
-    def query(cls, flags, *args, **kwargs):
-        """Query for segments of a set of flags.
-
-        This method intelligently selects the `~DataQualityDict.query_segdb`
-        or the `~DataQualityDict.query_dqsegdb` methods based on the
-        ``url`` kwarg given.
-
-        Parameters
-        ----------
-        flags : `iterable`
-            A list of flag names for which to query.
-
-        *args
-            Either, two `float`-like numbers indicating the
-            GPS [start, stop) interval, or a `SegmentList`
-            defining a number of summary segments
-
-        url : `str`, optional
-            URL of the segment database, defaults to
-            ``$DEFAULT_SEGMENT_SERVER`` environment variable, or
-            ``'https://segments.ligo.org'``
-
-        See also
-        --------
-        DataQualityDict.query_segdb
-        DataQualityDict.query_dqsegdb
-            for details on the actual query engine, and documentation of
-            other keyword arguments appropriate for each query
-
-        Returns
-        -------
-        flagdict : `DataQualityDict`
-            A `dict` of `(name, DataQualityFlag)` pairs
-        """
-        query_ = _select_query_method(
-            cls, kwargs.get('url', DEFAULT_SEGMENT_SERVER))
-        return query_(flags, *args, **kwargs)
-
-    @classmethod
-    def query_segdb(cls, flags, *args, **kwargs):
-        """Query the inital LIGO segment database for a list of flags.
-
-        Parameters
-        ----------
-        flags : `iterable`
-            A list of flag names for which to query.
-        *args
-            Either, two `float`-like numbers indicating the
-            GPS [start, stop) interval, or a `SegmentList`
-            defining a number of summary segments.
-        url : `str`, optional
-            URL of the segment database, defaults to
-            ``$DEFAULT_SEGMENT_SERVER`` environment variable, or
-            ``'https://segments.ligo.org'``
-
-        Returns
-        -------
-        flagdict : `DataQualityDict`
-            An ordered `DataQualityDict` of (name, `DataQualityFlag`)
-            pairs.
-        """
-        warnings.warn("query_segdb is deprecated and will be removed in a "
-                      "future release", DeprecationWarning)
-
-        # parse segments
-        qsegs = _parse_query_segments(args, cls.query_segdb)
-
-        url = kwargs.pop('url', DEFAULT_SEGMENT_SERVER)
-        if kwargs.pop('on_error', None) is not None:
-            warnings.warn("DataQualityDict.query_segdb doesn't accept the "
-                          "on_error keyword argument")
-        if kwargs.keys():
-            raise TypeError("DataQualityDict.query_segdb has no keyword "
-                            "argument '%s'" % list(kwargs.keys()[0]))
-
-        # process query
-        from glue.segmentdb import (segmentdb_utils as segdb_utils,
-                                    query_engine as segdb_engine)
-        connection = segdb_utils.setup_database(url)
-        engine = segdb_engine.LdbdQueryEngine(connection)
-        segdefs = []
-        for flag in flags:
-            dqflag = DataQualityFlag(name=flag)
-            ifo = dqflag.ifo
-            name = dqflag.tag
-            if dqflag.version is None:
-                vers = '*'
-            else:
-                vers = dqflag.version
-            for gpsstart, gpsend in qsegs:
-                if float(gpsend) == +inf:
-                    gpsend = int(to_gps('now'))
-                gpsstart = float(gpsstart)
-                if not gpsstart.is_integer():
-                    raise ValueError("Segment database queries can only"
-                                     "operate on integer GPS times")
-                gpsend = float(gpsend)
-                if not gpsend.is_integer():
-                    raise ValueError("Segment database queries can only"
-                                     "operate on integer GPS times")
-                segdefs += segdb_utils.expand_version_number(
-                    engine, (ifo, name, vers, gpsstart, gpsend, 0, 0))
-        segs = segdb_utils.query_segments(engine, 'segment', segdefs)
-        segsum = segdb_utils.query_segments(engine, 'segment_summary', segdefs)
-        # build output
-        out = cls()
-        for definition, segments, summary in zip(segdefs, segs, segsum):
-            # parse flag name
-            flag = ':'.join(map(str, definition[:3]))
-            name = flag.rsplit(':', 1)[0]
-            # if versionless
-            if flag.endswith('*'):
-                flag = name
-                key = name
-            # if asked for versionless, but returned a version
-            elif flag not in flags and name in flags:
-                key = name
-            # other
-            else:
-                key = flag
-            # define flag
-            if key not in out:
-                out[key] = DataQualityFlag(name=flag)
-            # add segments
-            out[key].known.extend(summary)
-            out[key].active.extend(segments)
-        return out
-
     @classmethod
     def query_dqsegdb(cls, flags, *args, **kwargs):
         """Query the advanced LIGO DQSegDB for a list of flags.
@@ -1243,7 +1021,7 @@ class DataQualityDict(OrderedDict):
         outq = Queue()
         for i in range(len(flags)):
             t = _QueryDQSegDBThread(inq, outq, qsegs, **kwargs)
-            t.setDaemon(True)
+            t.daemon = True
             t.start()
         for i, flag in enumerate(flags):
             inq.put((i, flag))
@@ -1267,6 +1045,9 @@ class DataQualityDict(OrderedDict):
                 new[flag] = result
         return new
 
+    # alias for compatibility
+    query = query_dqsegdb
+
     @classmethod
     def read(cls, source, names=None, format=None, **kwargs):
         """Read segments from file into a `DataQualityDict`
@@ -1484,12 +1265,19 @@ class DataQualityDict(OrderedDict):
 
         # parse a table into the target DataQualityDict
         def _parse_segments(table, listattr):
+            # handle missing *_ns columns in LIGO_LW XML
+            # (LIGO DMT doesn't/didn't write them)
+            if 'start_time_ns' in table.columnnames:
+                row_segment = operator.attrgetter("segment")
+            else:
+                row_segment = operator.attrgetter("start_time", "end_time")
+
             for row in table:
                 for flag in out:
                     # match row ID to list of IDs found for this flag
                     if int(row.segment_def_id) in id_[flag]:
                         getattr(out[flag], listattr).append(
-                            Segment(*map(gpstype, row.segment)),
+                            Segment(*map(gpstype, row_segment(row))),
                         )
                         break
 
@@ -1501,17 +1289,11 @@ class DataQualityDict(OrderedDict):
 
         return out
 
-    def to_ligolw_tables(self, ilwdchar_compat=None, **attrs):
+    def to_ligolw_tables(self, **attrs):
         """Convert this `DataQualityDict` into a trio of LIGO_LW segment tables
 
         Parameters
         ----------
-        ilwdchar_compat : `bool`, optional
-            whether to write in the old format, compatible with
-            ILWD characters (`True`), or to use the new format (`False`);
-            the current default is `True` to maintain backwards
-            compatibility, but this will change for gwpy-1.0.0.
-
         **attrs
             other attributes to add to all rows in all tables
             (e.g. ``'process_id'``)
@@ -1527,18 +1309,7 @@ class DataQualityDict(OrderedDict):
         segmenttable : :class:`~ligo.lw.lsctables.SegmentTable`
             the ``segment`` table
         """
-        if ilwdchar_compat is None:
-            warnings.warn("ilwdchar_compat currently defaults to `True`, "
-                          "but this will change to `False` in the future, to "
-                          "maintain compatibility in future releases, "
-                          "manually specify `ilwdchar_compat=True`",
-                          PendingDeprecationWarning)
-            ilwdchar_compat = True
-
-        if ilwdchar_compat:
-            from glue.ligolw import lsctables
-        else:
-            from ligo.lw import lsctables
+        from ligo.lw import lsctables
         from ..io.ligolw import to_table_type as to_ligolw_table_type
 
         SegmentDefTable = lsctables.SegmentDefTable
@@ -1680,7 +1451,11 @@ class DataQualityDict(OrderedDict):
             if segments is None and source.netloc:
                 try:
                     tmp = {key: self[key].query(
-                        self[key].name, self[key].known, **kwargs)}
+                        self[key].name,
+                        self[key].known,
+                        url=source.geturl(),
+                        **kwargs,
+                    )}
                 except URLError as exc:
                     if on_error == 'ignore':
                         pass
