@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Louisiana State University (2014-2017)
+#               Cardiff University (2017-2021)
 #
 # This file is part of GWpy.
 #
@@ -24,7 +25,7 @@ from functools import reduce
 
 from astropy.io import registry as io_registry
 
-from ...io.ligolw import (is_xml, build_content_handler, read_ligolw,
+from ...io.ligolw import (is_ligolw, build_content_handler, read_ligolw,
                           write_tables, patch_ligotimegps)
 from ...segments import (DataQualityFlag, DataQualityDict)
 
@@ -102,7 +103,7 @@ def read_ligolw_flag(source, name=None, **kwargs):
 
 # -- write --------------------------------------------------------------------
 
-def write_ligolw(flags, target, attrs=None, ilwdchar_compat=None, **kwargs):
+def write_ligolw(flags, target, attrs=None, **kwargs):
     """Write this `DataQualityFlag` to the given LIGO_LW Document
 
     Parameters
@@ -128,8 +129,7 @@ def write_ligolw(flags, target, attrs=None, ilwdchar_compat=None, **kwargs):
         flags = DataQualityDict({flags.name: flags})
     return write_tables(
         target,
-        flags.to_ligolw_tables(ilwdchar_compat=ilwdchar_compat,
-                               **attrs or dict()),
+        flags.to_ligolw_tables(**attrs or dict()),
         **kwargs
     )
 
@@ -139,9 +139,9 @@ def write_ligolw(flags, target, attrs=None, ilwdchar_compat=None, **kwargs):
 # register methods for DataQualityDict
 io_registry.register_reader('ligolw', DataQualityFlag, read_ligolw_flag)
 io_registry.register_writer('ligolw', DataQualityFlag, write_ligolw)
-io_registry.register_identifier('ligolw', DataQualityFlag, is_xml)
+io_registry.register_identifier('ligolw', DataQualityFlag, is_ligolw)
 
 # register methods for DataQualityDict
 io_registry.register_reader('ligolw', DataQualityDict, read_ligolw_dict)
 io_registry.register_writer('ligolw', DataQualityDict, write_ligolw)
-io_registry.register_identifier('ligolw', DataQualityDict, is_xml)
+io_registry.register_identifier('ligolw', DataQualityDict, is_ligolw)
