@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Louisiana State University (2014-2017)
+#               Cardiff University (2017-2021)
 #
 # This file is part of GWpy.
 #
@@ -19,10 +20,8 @@
 """Tests for :mod:`gwpy.segments`
 """
 
-import importlib
-import os.path
 import re
-import tempfile
+import warnings
 from io import BytesIO
 from unittest import mock
 from urllib.error import HTTPError
@@ -36,49 +35,91 @@ from matplotlib import rc_context
 from ...plot import SegmentAxes
 from ...segments import (Segment, SegmentList,
                          DataQualityFlag, DataQualityDict)
-from ...testing import (mocks, utils)
+from ...testing import utils
 from ...testing.errors import pytest_skip_network_error
-from ...utils.misc import null_context
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
 
 
 # -- veto definer fixture -----------------------------------------------------
 
-VETO_DEFINER_FILE = """<?xml version='1.0' encoding='utf-8'?>
+VETO_DEFINER_FILE = """
+<?xml version='1.0' encoding='utf-8'?>
 <!DOCTYPE LIGO_LW SYSTEM "http://ldas-sw.ligo.caltech.edu/doc/ligolwAPI/html/ligolw_dtd.txt">
 <LIGO_LW>
     <Table Name="veto_definer:table">
-        <Column Type="int_4s" Name="veto_definer:category"/>
-        <Column Type="lstring" Name="veto_definer:comment"/>
-        <Column Type="int_4s" Name="veto_definer:end_pad"/>
-        <Column Type="ilwd:char" Name="veto_definer:process_id"/>
-        <Column Type="lstring" Name="veto_definer:name"/>
-        <Column Type="int_4s" Name="veto_definer:version"/>
-        <Column Type="int_4s" Name="veto_definer:start_pad"/>
-        <Column Type="int_4s" Name="veto_definer:start_time"/>
-        <Column Type="lstring" Name="veto_definer:ifo"/>
-        <Column Type="int_4s" Name="veto_definer:end_time"/>
+        <Column Type="int_4s" Name="category"/>
+        <Column Type="lstring" Name="comment"/>
+        <Column Type="int_4s" Name="end_pad"/>
+        <Column Type="int_8s" Name="process:process_id"/>
+        <Column Type="lstring" Name="name"/>
+        <Column Type="int_4s" Name="version"/>
+        <Column Type="int_4s" Name="start_pad"/>
+        <Column Type="int_4s" Name="start_time"/>
+        <Column Type="lstring" Name="ifo"/>
+        <Column Type="int_4s" Name="end_time"/>
         <Stream Delimiter="," Type="Local" Name="veto_definer:table">
             1,"Test flag 1",2,,"TEST-FLAG",1,-1,100,"X1",0,
             2,"Test flag 1",2,,"TEST-FLAG_2",1,1,100,"X1",200,
             2,"Test flag 1",2,,"TEST-FLAG_2",2,-2,200,"X1",0,
-            2,"Test flag 1",2,,"TEST-FLAG_2",2,-2,100,"Y1",0,
+            2,"Test flag 1",2,,"TEST-FLAG_2",2,-2,100,"Y1",0
         </Stream>
     </Table>
 </LIGO_LW>
-"""  # noqa: E501
+""".strip()  # noqa: E501
 
 
-@pytest.fixture(scope='module')
-def veto_definer():
-    with tempfile.NamedTemporaryFile(suffix='.xml', mode='w',
-                                     delete=False) as f:
-        f.write(VETO_DEFINER_FILE)
-        f.seek(0)
-        yield f.name
-    if os.path.isfile(f.name):
-        os.remove(f.name)
+@pytest.fixture
+def veto_definer(tmp_path):
+    tmp = tmp_path / "veto-definer.xml"
+    tmp.write_text(VETO_DEFINER_FILE)
+    return tmp
+
+
+# -- XML without _ns columns --------------------------------------------------
+
+LIGOLW_NO_NS = """
+<?xml version="1.0"?>
+<!DOCTYPE LIGO_LW SYSTEM "http://ldas-sw.ligo.caltech.edu/doc/ligolwAPI/html/ligolw_dtd.txt">
+<LIGO_LW>
+  <Table Name="segment_definergroup:segment_definer:table">
+    <Column Name="segment_def_id" Type="int_8s"/>
+    <Column Name="ifos" Type="lstring"/>
+    <Column Name="name" Type="lstring"/>
+    <Column Name="version" Type="int_4s"/>
+    <Column Name="comment" Type="lstring"/>
+    <Stream Name="segment_definergroup:segment_definer:table" Type="Local" Delimiter=",">
+      0,"X1","TEST_FLAG",1,"Test flag",
+    </Stream>
+  </Table>
+  <Table Name="segment_summarygroup:segment_summary:table">
+    <Column Name="segment_sum_id" Type="int_8s"/>
+    <Column Name="start_time" Type="int_4s"/>
+    <Column Name="end_time" Type="int_4s"/>
+    <Column Name="comment" Type="lstring"/>
+    <Column Name="segment_definer:segment_def_id" Type="int_8s"/>
+    <Stream Name="segment_summarygroup:segment_summary:table" Type="Local" Delimiter=",">
+      0,1366644592,1366644608,"",0,
+    </Stream>
+  </Table>
+  <Table Name="segmentgroup:segment:table">
+    <Column Name="segment_id" Type="int_8s"/>
+    <Column Name="start_time" Type="int_4s"/>
+    <Column Name="end_time" Type="int_4s"/>
+    <Column Name="segment_definer:segment_def_id" Type="int_8s"/>
+    <Stream Name="segmentgroup:segment:table" Type="Local" Delimiter=",">
+      0,1366644592,1366644593,0,
+    </Stream>
+  </Table>
+</LIGO_LW>
+""".strip()  # noqa: E501
+
+
+@pytest.fixture
+def ligolw_no_ns(tmp_path):
+    tmp = tmp_path / "test.xml"
+    tmp.write_text(LIGOLW_NO_NS)
+    return tmp
 
 
 # -- test data ----------------------------------------------------------------
@@ -152,74 +193,28 @@ QUERY_RESULTC = type(QUERY_RESULT)({x: y.copy().coalesce() for
                                     x, y in QUERY_RESULT.items()})
 
 
-def query_segdb(query_func, *args, **kwargs):
-    """Mock a query to an S6-style DB2 database
-    """
+def mock_query_segments(flag, start, end, **kwargs):
     try:
-        with mock.patch('glue.segmentdb.segmentdb_utils.setup_database'), \
-             mock.patch('glue.segmentdb.segmentdb_utils.expand_version_number',
-                        mocks.segdb_expand_version_number(1, 4)), \
-             mock.patch('glue.segmentdb.segmentdb_utils.query_segments',
-                        mocks.segdb_query_segments(QUERY_RESULT)):
-            return query_func(*args, **kwargs)
-    except ImportError as e:  # pragma: no-cover
-        pytest.skip(str(e))
-
-
-def segdb_expand_version_number(min_, max_):
-    def expand_version_number(engine, segdef):
-        ifo, name, version, start_time, end_time, start_pad, end_pad = segdef
-        if version != '*':
-            return [segdef]
-        return [[ifo, name, v, start_time, end_time, start_pad, end_pad] for
-                v in range(min_, max_+1)[::-1]]
-
-    return expand_version_number
-
-
-def segdb_query_segments(result):
-    def query_segments(engine, tablename, segdefs):
-        out = []
-        for ifo, flag, version, start, end, startpad, endpad in segdefs:
-            flag = '%s:%s:%d' % (ifo, flag, version)
-            if flag not in result:
-                out.append([])
-            if tablename == 'segment':
-                out.append(result[flag].active)
-            else:
-                out.append(result[flag].known)
-        return out
-    return query_segments
-
-
-def dqsegdb2_query_segments(result, deactivated=False,
-                            active_indicates_ifo_badness=False, **kwargs):
-    """Build a mock of `dqsegdb2.query.query_segments` for testing
-    """
-    def query_segments(flag, start, end, host=None):
-        try:
-            ifo, name, version = flag.split(':')
-            version = int(version)
-        except ValueError:
-            ifo, name = flag.split(':', 1)
-            version = None
-        span = SegmentList([Segment(start, end)])
-        reflag = re.compile(flag)
-        try:
-            actual = list(filter(reflag.match, result))[0]
-        except IndexError:
-            raise HTTPError('test-url/', 404, 'Not found', None, None)
-        return {
-            'ifo': ifo,
-            'name': name,
-            'version': version,
-            'known': list(map(tuple, result[actual].known & span)),
-            'active': list(map(tuple, result[actual].active & span)),
-            'query_information': {},
-            'metadata': kwargs,
-        }
-
-    return query_segments
+        ifo, name, version = flag.split(':')
+        version = int(version)
+    except ValueError:
+        ifo, name = flag.split(':', 1)
+        version = None
+    span = SegmentList([Segment(start, end)])
+    reflag = re.compile(flag)
+    try:
+        actual = list(filter(reflag.match, QUERY_RESULT))[0]
+    except IndexError:
+        raise HTTPError('test-url/', 404, 'Not found', None, None)
+    return {
+        'ifo': ifo,
+        'name': name,
+        'version': version,
+        'known': list(map(tuple, QUERY_RESULT[actual].known & span)),
+        'active': list(map(tuple, QUERY_RESULT[actual].active & span)),
+        'query_information': {},
+        'metadata': kwargs,
+    }
 
 
 # -- DataQualityFlag ----------------------------------------------------------
@@ -438,13 +433,9 @@ class TestDataQualityFlag(object):
         with pytest.raises(TypeError):
             flag.pad(*PADDING, kwarg='test')
 
-    @utils.skip_missing_dependency('ligo.lw.lsctables')
-    @pytest.mark.parametrize("lsctables", (
-        pytest.param("glue.ligolw.lsctables", id="glue.ligolw"),
-        pytest.param("ligo.lw.lsctables", id="python-ligo-lw"),
-    ))
-    def test_from_veto_def(self, lsctables):
-        VetoDef = importlib.import_module(lsctables).VetoDef
+    @pytest.mark.requires("ligo.lw.lsctables")
+    def test_from_veto_def(self):
+        from ligo.lw.lsctables import VetoDef
 
         def veto_def(ifo, name, version, **kwargs):
             vdef = VetoDef()
@@ -469,13 +460,11 @@ class TestDataQualityFlag(object):
         assert f.name == 'X1:TEST-FLAG'
         assert f.version is None
 
+    @mock.patch("gwpy.segments.flag.query_segments", mock_query_segments)
     def test_populate(self):
         name = QUERY_FLAGS[0]
         flag = self.TEST_CLASS(name, known=QUERY_RESULT[name].known)
-
-        with mock.patch('gwpy.segments.flag.query_segments',
-                        dqsegdb2_query_segments(QUERY_RESULT)):
-            flag.populate()
+        flag.populate()
         utils.assert_flag_equal(flag, QUERY_RESULTC[name])
 
     # -- test I/O -------------------------------
@@ -508,88 +497,66 @@ class TestDataQualityFlag(object):
                 _read_write(autoidentify=True)
             _read_write(autoidentify=True, write_kw={'overwrite': True})
 
-    def test_read_write_hdf5(self, flag):
-        with utils.TemporaryFilename(suffix=".h5") as fp:
-            flag.write(fp, path="test")
-            f2 = self.TEST_CLASS.read(fp, path="test", format="hdf5")
-            utils.assert_flag_equal(f2, flag)
+    def test_read_write_hdf5(self, flag, tmp_path):
+        tmp = tmp_path / "test.h5"
+        flag.write(tmp, path="test")
+        f2 = self.TEST_CLASS.read(tmp, path="test", format="hdf5")
+        utils.assert_flag_equal(f2, flag)
 
-            # test direct access from dataset
-            with h5py.File(fp, "r") as h5f:
-                f2 = self.TEST_CLASS.read(h5f["test"])
-                utils.assert_flag_equal(f2, flag)
+        # test direct access from dataset
+        with h5py.File(tmp, "r") as h5f:
+            f2 = self.TEST_CLASS.read(h5f["test"])
+        utils.assert_flag_equal(f2, flag)
 
-            # test auto-discover of single dataset
-            f2 = self.TEST_CLASS.read(fp)
-            utils.assert_flag_equal(f2, flag)
+        # test auto-discover of single dataset
+        f2 = self.TEST_CLASS.read(tmp)
+        utils.assert_flag_equal(f2, flag)
 
-    @utils.skip_missing_dependency('ligo.lw.lsctables')
-    @pytest.mark.parametrize("ilwdchar_compat", [False, True])
-    def test_read_write_ligolw(self, flag, ilwdchar_compat):
+    @pytest.mark.requires("ligo.lw.lsctables")
+    def test_read_write_ligolw(self, flag):
         utils.test_read_write(
-            flag, "ligolw", extension="xml",
+            flag,
+            "ligolw",
+            extension="xml",
             assert_equal=utils.assert_flag_equal,
             autoidentify=False,
-            read_kw={}, write_kw={"ilwdchar_compat": ilwdchar_compat},
+            read_kw={},
         )
 
-    @utils.skip_missing_dependency('ligo.lw.lsctables')
-    def test_write_ligolw_attrs(self, flag):
+    @pytest.mark.requires("ligo.lw.lsctables")
+    def test_write_ligolw_attrs(self, tmp_path, flag):
         from gwpy.io.ligolw import read_table
-        with tempfile.NamedTemporaryFile(suffix='.xml') as f:
-            flag.write(
-                f,
-                format='ligolw',
-                attrs={'process_id': 100},
-                ilwdchar_compat=False,
-            )
-            segdeftab = read_table(f, 'segment_definer')
-            assert int(segdeftab[0].process_id) == 100
+        tmp = tmp_path / "tmp.xml"
+        flag.write(
+            tmp,
+            format='ligolw',
+            attrs={'process_id': 100},
+        )
+        segdeftab = read_table(tmp, 'segment_definer')
+        assert int(segdeftab[0].process_id) == 100
+
+    @pytest.mark.requires("ligo.lw.lsctables")
+    def test_read_ligolw_no_ns(self, ligolw_no_ns):
+        flag = self.TEST_CLASS.read(ligolw_no_ns, format="ligolw")
+        assert flag.name == "X1:TEST_FLAG:1"
+        assert flag.known == [(1366644592, 1366644608)]
+        assert flag.active == [(1366644592, 1366644593)]
 
     # -- test queries ---------------------------
 
+    @mock.patch("gwpy.segments.flag.query_segments", mock_query_segments)
     def test_query(self):
-        with mock.patch('gwpy.segments.flag.query_segments',
-                        dqsegdb2_query_segments(QUERY_RESULT)):
-            result = self.TEST_CLASS.query(QUERY_FLAGS[0], 0, 10)
-
+        result = self.TEST_CLASS.query(QUERY_FLAGS[0], 0, 10)
         assert isinstance(result, self.TEST_CLASS)
         RESULT = QUERY_RESULT[QUERY_FLAGS[0]].copy().coalesce()
         utils.assert_segmentlist_equal(result.known, RESULT.known)
         utils.assert_segmentlist_equal(result.active, RESULT.active)
 
-    def test_query_segdb(self):
-        with pytest.deprecated_call():
-            result = query_segdb(self.TEST_CLASS.query_segdb,
-                                 QUERY_FLAGS[0], 0, 10)
-        RESULT = QUERY_RESULT[QUERY_FLAGS[0]]
-
-        assert isinstance(result, self.TEST_CLASS)
-        utils.assert_segmentlist_equal(result.known, RESULT.known)
-        utils.assert_segmentlist_equal(result.active, RESULT.active)
-
-        with pytest.deprecated_call():
-            result2 = query_segdb(self.TEST_CLASS.query_segdb,
-                                  QUERY_FLAGS[0], (0, 10))
-        utils.assert_flag_equal(result, result2)
-
-        with pytest.deprecated_call():
-            result2 = query_segdb(self.TEST_CLASS.query_segdb,
-                                  QUERY_FLAGS[0], SegmentList([(0, 10)]))
-        utils.assert_flag_equal(result, result2)
-
-        with pytest.deprecated_call():
-            with pytest.raises(ValueError):
-                self.TEST_CLASS.query_segdb(QUERY_FLAGS[0], 1, 2, 3)
-            with pytest.raises(ValueError):
-                self.TEST_CLASS.query_segdb(QUERY_FLAGS[0], (1, 2, 3))
-
     @pytest.mark.parametrize('name, flag', [
         (QUERY_FLAGS[0], QUERY_FLAGS[0]),  # regular query
         (QUERY_FLAGS[0].rsplit(':', 1)[0], QUERY_FLAGS[0]),  # versionless
     ])
-    @mock.patch('gwpy.segments.flag.query_segments',
-                dqsegdb2_query_segments(QUERY_RESULT))
+    @mock.patch('gwpy.segments.flag.query_segments', mock_query_segments)
     def test_query_dqsegdb(self, name, flag):
         # standard query
         result = self.TEST_CLASS.query_dqsegdb(name, 0, 10)
@@ -612,9 +579,11 @@ class TestDataQualityFlag(object):
                                           SegmentList([(0, 10)]))
 
         # flag not in database
-        with pytest.raises(HTTPError) as exc:
+        with pytest.raises(
+            HTTPError,
+            match=r"^HTTP Error 404: Not found \[X1:GWPY-TEST:0\]$",
+        ):
             self.TEST_CLASS.query_dqsegdb('X1:GWPY-TEST:0', 0, 10)
-        assert str(exc.value) == 'HTTP Error 404: Not found [X1:GWPY-TEST:0]'
 
         # bad syntax
         with pytest.raises(ValueError):
@@ -622,8 +591,7 @@ class TestDataQualityFlag(object):
         with pytest.raises(ValueError):
             self.TEST_CLASS.query_dqsegdb(QUERY_FLAGS[0], (1, 2, 3))
 
-    @mock.patch('gwpy.segments.flag.query_segments',
-                dqsegdb2_query_segments(QUERY_RESULT))
+    @mock.patch('gwpy.segments.flag.query_segments', mock_query_segments)
     def test_query_dqsegdb_multi(self):
         segs = SegmentList([Segment(0, 2), Segment(8, 10)])
         result = self.TEST_CLASS.query_dqsegdb(QUERY_FLAGS[0], segs)
@@ -753,7 +721,7 @@ class TestDataQualityDict(object):
 
     # -- test I/O -------------------------------
 
-    @utils.skip_missing_dependency('ligo.lw.lsctables')
+    @pytest.mark.requires("ligo.lw.lsctables")
     def test_from_veto_definer_file(self, veto_definer):
         # read veto definer
         vdf = self.TEST_CLASS.from_veto_definer_file(veto_definer)
@@ -804,17 +772,17 @@ class TestDataQualityDict(object):
             _read_write(autoidentify=True)
         _read_write(autoidentify=True, write_kw={'overwrite': True})
 
-    @utils.skip_missing_dependency('ligo.lw.lsctables')
-    @pytest.mark.parametrize("ilwdchar_compat", [False, True])
-    def test_read_write_ligolw(self, instance, ilwdchar_compat):
+    @pytest.mark.requires("ligo.lw.lsctables")
+    def test_read_write_ligolw(self, instance):
         def _assert(a, b):
             return utils.assert_dict_equal(a, b, utils.assert_flag_equal)
         utils.test_read_write(
-            instance, "ligolw", extension="xml",
+            instance,
+            "ligolw",
+            extension="xml",
             assert_equal=_assert,
             autoidentify=False,
             read_kw={},
-            write_kw={"ilwdchar_compat": ilwdchar_compat},
         )
 
     def test_read_on_missing(self, instance):
@@ -832,50 +800,35 @@ class TestDataQualityDict(object):
                                             **kwargs)
 
             # check on_missing='error' (default) raises ValueError
-            with pytest.raises(ValueError) as exc:
+            with pytest.raises(
+                ValueError,
+                match="^'randomname' not found in any input file$",
+            ):
                 _read()
-            assert str(exc.value) == ('\'randomname\' not found in any input '
-                                      'file')
 
             # check on_missing='warn' prints warning
             with pytest.warns(UserWarning):
                 _read(on_missing='warn')
 
             # check on_missing='ignore' does nothing
-            with pytest.warns(None) as record:
+            with warnings.catch_warnings():
+                warnings.simplefilter("error")
                 _read(on_missing='ignore')
-            assert not record.list
 
             # check on_missing=<anything else> raises exception
-            with pytest.raises(ValueError) as exc:
+            with pytest.raises(ValueError):
                 _read(on_missing='blah')
 
-    @utils.skip_missing_dependency('ligo.lw.lsctables')
-    @pytest.mark.parametrize("ilwdchar_compat", [None, False, True])
-    def test_to_ligolw_tables(self, instance, ilwdchar_compat):
-        if ilwdchar_compat is None:
-            ctx = pytest.warns(PendingDeprecationWarning)
-        else:
-            ctx = null_context()
-        with ctx:
-            tables = instance.to_ligolw_tables(
-                ilwdchar_compat=ilwdchar_compat,
-            )
-
-        if ilwdchar_compat is False:
-            mod = "ligo.lw.lsctables"
-        else:  # True or None
-            mod = "glue.ligolw.lsctables"
-        for tab in tables:
-            assert type(tab).__module__ == mod
+    @pytest.mark.requires("ligo.lw.lsctables")
+    def test_to_ligolw_tables(self, instance):
+        tables = instance.to_ligolw_tables()
         assert len(tables[0]) == len(instance)  # segdef
         assert len(tables[1]) == sum(len(x.known) for x in instance.values())
         assert len(tables[2]) == sum(len(x.active) for x in instance.values())
 
     # -- test queries ---------------------------
 
-    @mock.patch('gwpy.segments.flag.query_segments',
-                dqsegdb2_query_segments(QUERY_RESULT))
+    @mock.patch('gwpy.segments.flag.query_segments', mock_query_segments)
     def test_query(self):
         result = self.TEST_CLASS.query(QUERY_FLAGS, 0, 10)
         RESULT = QUERY_RESULT.copy().coalesce()
@@ -883,8 +836,7 @@ class TestDataQualityDict(object):
         assert isinstance(result, self.TEST_CLASS)
         utils.assert_dict_equal(result, RESULT, utils.assert_flag_equal)
 
-    @mock.patch('gwpy.segments.flag.query_segments',
-                dqsegdb2_query_segments(QUERY_RESULT))
+    @mock.patch('gwpy.segments.flag.query_segments', mock_query_segments)
     def test_query_dqsegdb(self):
         result = self.TEST_CLASS.query_dqsegdb(QUERY_FLAGS, 0, 10)
         RESULT = QUERY_RESULTC
@@ -902,13 +854,7 @@ class TestDataQualityDict(object):
         with pytest.raises(ValueError):
             self.TEST_CLASS.query_dqsegdb(QUERY_FLAGS, 0, 10, on_error='blah')
 
-    def test_query_segdb(self):
-        with pytest.deprecated_call():
-            result = query_segdb(self.TEST_CLASS.query_segdb,
-                                 QUERY_FLAGS, 0, 10)
-        assert isinstance(result, self.TEST_CLASS)
-        utils.assert_dict_equal(result, QUERY_RESULT, utils.assert_flag_equal)
-
+    @mock.patch('gwpy.segments.flag.query_segments', mock_query_segments)
     def test_populate(self):
         def fake():
             return self.TEST_CLASS({
@@ -926,22 +872,20 @@ class TestDataQualityDict(object):
         span = SegmentList([Segment(0, 2)])
 
         # and populate using a mocked query
-        with mock.patch('gwpy.segments.flag.query_segments',
-                        dqsegdb2_query_segments(QUERY_RESULT)):
-            vdf.populate()
-            vdf2.populate()
-            vdf3.populate(segments=span)
+        vdf.populate()
+        vdf2.populate()
+        vdf3.populate(segments=span)
 
-            # test warnings on bad entries
-            vdf['TEST'] = self.ENTRY_CLASS('X1:BLAHBLAHBLAH:1', known=[(0, 1)])
-            with pytest.warns(UserWarning) as record:
-                vdf.populate(on_error='warn')
-                vdf.populate(on_error='ignore')
-            assert len(record) == 1
-            vdf.pop('TEST')
+        # test warnings on bad entries
+        vdf['TEST'] = self.ENTRY_CLASS('X1:BLAHBLAHBLAH:1', known=[(0, 1)])
+        with pytest.warns(UserWarning) as record:
+            vdf.populate(on_error='warn')
+            vdf.populate(on_error='ignore')
+        assert len(record) == 1
+        vdf.pop('TEST')
 
-            with pytest.raises(ValueError):
-                vdf.populate(on_error='blah')
+        with pytest.raises(ValueError):
+            vdf.populate(on_error='blah')
 
         # check basic populate worked
         utils.assert_dict_equal(vdf, QUERY_RESULTC, utils.assert_flag_equal)
