@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -27,11 +27,11 @@ import numpy
 from numpy import fft as npfft
 
 from scipy import signal
-from scipy.signal.ltisys import LinearTimeInvariant
 
 from astropy.units import (Unit, Quantity)
 
-from .window import planck
+from ..types.array import COPY_IF_NEEDED
+from .window import (get_window, planck)
 
 __author__ = "Duncan Macleod <duncan.macleod@ligo.org>"
 __all__ = ['lowpass', 'highpass', 'bandpass', 'notch', 'concatenate_zpks']
@@ -89,8 +89,8 @@ def _design_fir(wp, ws, sample_rate, gpass, gstop, window='hamming', **kwargs):
     if wp[0] > ws[0]:
         kwargs.setdefault('pass_zero', False)
     if ws.shape == (1,):
-        kwargs.setdefault('width', ws - wp)
-    kwargs.setdefault('nyq', sample_rate/2.)
+        kwargs.setdefault("width", ws.item() - wp.item())
+    kwargs.setdefault('fs', sample_rate)
     return signal.firwin(nt, wp, window=window, **kwargs)
 
 
@@ -182,7 +182,7 @@ def truncate_transfer(transfer, ncorner=None):
     return out
 
 
-def truncate_impulse(impulse, ntaps, window='hanning'):
+def truncate_impulse(impulse, ntaps, window='hann'):
     """Smoothly truncate a time domain impulse response
 
     Parameters
@@ -194,7 +194,7 @@ def truncate_impulse(impulse, ntaps, window='hanning'):
         number of taps in the final filter
 
     window : `str`, `numpy.ndarray`, optional
-        window function to truncate with, default: ``'hanning'``
+        window function to truncate with, default: ``'hann'``
         see :func:`scipy.signal.get_window` for details on acceptable formats
 
     Returns
@@ -205,14 +205,14 @@ def truncate_impulse(impulse, ntaps, window='hanning'):
     out = impulse.copy()
     trunc_start = int(ntaps / 2)
     trunc_stop = out.size - trunc_start
-    window = signal.get_window(window, ntaps)
+    window = get_window(window, ntaps)
     out[0:trunc_start] *= window[trunc_start:ntaps]
     out[trunc_stop:out.size] *= window[0:trunc_start]
     out[trunc_start:trunc_stop] = 0
     return out
 
 
-def fir_from_transfer(transfer, ntaps, window='hanning', ncorner=None):
+def fir_from_transfer(transfer, ntaps, window='hann', ncorner=None):
     """Design a Type II FIR filter given an arbitrary transfer function
 
     Parameters
@@ -224,7 +224,7 @@ def fir_from_transfer(transfer, ntaps, window='hanning', ncorner=None):
         number of taps in the final filter, must be an even number
 
     window : `str`, `numpy.ndarray`, optional
-        window function to truncate with, default: ``'hanning'``
+        window function to truncate with, default: ``'hann'``
         see :func:`scipy.signal.get_window` for details on acceptable formats
 
     ncorner : `int`, optional
@@ -282,9 +282,9 @@ def bilinear_zpk(zeros, poles, gain, fs=1.0, unit='Hz'):
     zpk : `tuple`
         digital version of input zpk
     """
-    zeros = numpy.array(zeros, dtype=float, copy=False)
+    zeros = numpy.array(zeros, dtype=float, copy=COPY_IF_NEEDED)
     zeros = zeros[numpy.isfinite(zeros)]
-    poles = numpy.array(poles, dtype=float, copy=False)
+    poles = numpy.array(poles, dtype=float, copy=COPY_IF_NEEDED)
     gain = gain
 
     # convert from Hz to rad/s if needed
@@ -348,19 +348,18 @@ def parse_filter(args, analog=False, sample_rate=None):
         return 'ba', (b, a)
 
     # parse IIR filter
-    if isinstance(args, LinearTimeInvariant):
-        lti = args
-    elif (
-        isinstance(args, numpy.ndarray)
-        and args.ndim == 2
-        and args.shape[1] == 6
-    ):
-        lti = signal.lti(*signal.sos2zpk(args))
-    else:
-        lti = signal.lti(*args)
-
-    # convert to zpk format
-    lti = lti.to_zpk()
+    try:
+        lti = args.to_zpk()
+    except AttributeError:
+        if (
+            isinstance(args, numpy.ndarray)
+            and args.ndim == 2
+            and args.shape[1] == 6
+        ):
+            lti = signal.lti(*signal.sos2zpk(args))
+        else:
+            lti = signal.lti(*args)
+        lti = lti.to_zpk()
 
     # convert to digital components
     if analog:
@@ -566,7 +565,7 @@ def bandpass(flow, fhigh, sample_rate, fstop=None, gpass=2, gstop=30,
                        pass_zero=False, **kwargs)
 
 
-def notch(frequency, sample_rate, type='iir', **kwargs):
+def notch(frequency, sample_rate, type='iir', output='zpk', **kwargs):
     """Design a ZPK notch filter for the given frequency and sampling rate
 
     Parameters
@@ -578,18 +577,21 @@ def notch(frequency, sample_rate, type='iir', **kwargs):
         filter will be applied
     type : `str`, optional, default: 'iir'
         type of filter to apply, currently only 'iir' is supported
+    output : `str`, optional, default: 'zpk'
+        output format for notch
     **kwargs
         other keyword arguments to pass to `scipy.signal.iirdesign`
 
     Returns
     -------
-    zpk : `tuple` of `complex` or `float`
-       the filter components in digital zero-pole-gain format
+    filter
+        the formatted filter; the output format for an IIR filter depends
+        on the input arguments, default is a tuple of `(zeros, poles, gain)`
 
     See also
     --------
     scipy.signal.iirdesign
-        for details on the IIR filter design method
+        for details on the IIR filter design method and the output formats
 
     Notes
     -----
@@ -622,7 +624,7 @@ def notch(frequency, sample_rate, type='iir', **kwargs):
         kwargs.setdefault('gpass', 1)
         kwargs.setdefault('gstop', 10)
         kwargs.setdefault('ftype', 'ellip')
-        return signal.iirdesign([low1, high1], [low2, high2], output='zpk',
+        return signal.iirdesign([low1, high1], [low2, high2], output=output,
                                 **kwargs)
     else:
         raise NotImplementedError("Generating %r notch filters has not been "
