@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2017-2021)
+# Copyright (C) Duncan Macleod (2017-2020)
 #
 # This file is part of GWpy.
 #
@@ -19,17 +19,41 @@
 """Utilities for signal-processing with windows
 """
 
-import numpy
-
+from functools import wraps
 from math import ceil
 
-from scipy.signal.windows import windows as scipy_windows
+import numpy
 
+from scipy.signal import get_window as _get_window
 from scipy.special import expit
+try:
+    from scipy.signal.windows._windows import _win_equiv as WINDOWS
+except ImportError:  # scipy < 1.8.0
+    from scipy.signal.windows.windows import _win_equiv as WINDOWS
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
 
 
+@wraps(_get_window)
+def get_window(window, Nx, *args, **kwargs):
+    """Wrapper around :func:`scipy.signal.get_window` to allow
+    pre-computed window arrays.
+    """
+    # try something floaty
+    try:
+        return _get_window(float(window), Nx, *args, **kwargs)
+    except (TypeError, ValueError):
+        pass
+    # otherwise a name or tuple of params
+    if isinstance(window, (str, tuple)):
+        return _get_window(window, Nx, *args, **kwargs)
+    # otherwise we were given an array
+    window = numpy.asarray(window)
+    assert window.ndim == 1, "multi-dimensional windows are not supported"
+    assert window.size == Nx, "window array wrong size"
+    return window
+
+
 def canonical_name(name):
     """Find the canonical name for the given window in scipy.signal
 
@@ -51,7 +75,7 @@ def canonical_name(name):
     Examples
     --------
     >>> from gwpy.signal.window import canonical_name
-    >>> canonical_name('hanning')
+    >>> canonical_name('hann')
     'hann'
     >>> canonical_name('ksr')
     'kaiser'
@@ -60,7 +84,7 @@ def canonical_name(name):
         return 'planck'
     try:  # use equivalence introduced in scipy 0.16.0
         # pylint: disable=protected-access
-        return scipy_windows._win_equiv[name.lower()].__name__
+        return WINDOWS[name.lower()].__name__
     except KeyError:  # no match
         raise ValueError('no window function in scipy.signal equivalent to %r'
                          % name,)
