@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -50,11 +50,15 @@ class TestSpectrogram(_TestArray2D):
         a = self.create(epoch=10)
         b = self.create(t0=10)
         utils.assert_quantity_sub_equal(a, b)
-        with pytest.raises(ValueError) as exc:
-            self.TEST_CLASS(self.data, epoch=1, t0=1)
-        assert str(exc.value) == 'give only one of epoch or t0'
 
-        # check times
+    def test_new_redundant_args(self):
+        with pytest.raises(
+            ValueError,
+            match="^give only one of epoch or t0$",
+        ):
+            self.TEST_CLASS(self.data, epoch=1, t0=1)
+
+    def test_new_times(self):
         times = numpy.arange(self.data.shape[0])
         a = self.create(times=times)
         utils.assert_quantity_equal(a.times, times * units.second)
@@ -144,7 +148,7 @@ class TestSpectrogram(_TestArray2D):
         with rc_context(rc={'text.usetex': False}):
             plot = array.plot(method=method)
             ax = plot.gca()
-            assert ax.lines == []
+            assert len(ax.lines) == 0
             if method == 'imshow':
                 assert len(ax.images) == 1
             else:
@@ -171,11 +175,11 @@ class TestSpectrogram(_TestArray2D):
 
         # test simple filter
         a2 = array.filter(*zpk)
-        utils.assert_array_equal(array * fresp, a2)
+        utils.assert_quantity_sub_equal(array * fresp, a2)
 
         # test inplace filtering
         array.filter(lti, inplace=True)
-        utils.assert_array_equal(array, a2)
+        utils.assert_quantity_sub_equal(array, a2)
 
         # test errors
         with pytest.raises(TypeError):
