@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -32,7 +32,7 @@ tables of time-stamped GW (or other) events.
 
 # load tables
 from astropy.table import (Column, Table)
-from .table import (EventColumn, EventTable)
+from .table import EventTable
 from .gravityspy import GravitySpyTable
 
 # attach unified I/O
