@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2017-2021)
+# Copyright (C) Louisiana State University (2017)
+#               Cardiff University (2017-2022)
 #
 # This file is part of GWpy.
 #
@@ -28,7 +29,7 @@ import numpy
 
 from gwosc.api import DEFAULT_URL as DEFAULT_GWOSC_URL
 
-from astropy.table import (Table, Column, vstack)
+from astropy.table import (Table, vstack)
 from astropy.io import registry
 
 from ..io.mp import read_multi as io_read_multi
@@ -36,7 +37,12 @@ from ..time import gps_types
 from .filter import (filter_table, parse_operator)
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
-__all__ = ['EventColumn', 'EventTable']
+
+TIME_LIKE_COLUMN_NAMES = [
+    "time",  # standard
+    "gps",  # GWOSC catalogues
+    "peakGPS",  # gravityspy
+]
 
 
 # -- utilities ----------------------------------------------------------------
@@ -104,36 +110,6 @@ def _rates_preprocess(func):
     return wrapped_func
 
 
-# -- Column -------------------------------------------------------------------
-
-class EventColumn(Column):
-    """Custom `Column` that allows filtering with segments
-    """
-    def __new__(cls, *args, **kwargs):
-        warnings.warn("the EventColumn is deprecated, and will be removed in "
-                      "a future gwpy release", DeprecationWarning)
-        super().__new__(*args, **kwargs)
-
-    def in_segmentlist(self, segmentlist):
-        """Return the index of values lying inside the given segmentlist
-
-        A `~gwpy.segments.Segment` represents a semi-open interval,
-        so for any segment `[a, b)`, a value `x` is 'in' the segment if
-
-            a <= x < b
-
-        """
-        from .filters import in_segmentlist
-        return in_segmentlist(self, segmentlist)
-
-    def not_in_segmentlist(self, segmentlist):
-        """Return the index of values not lying inside the given segmentlist
-
-        See `~EventColumn.in_segmentlist` for more details
-        """
-        return self.in_segmentlist(~segmentlist)
-
-
 # -- Table --------------------------------------------------------------------
 
 @inherit_io_registrations
@@ -151,35 +127,51 @@ class EventTable(Table):
     """
     # -- utilities ------------------------------
 
+    def _is_time_column(self, name):
+        """Return `True` if a column in this table represents 'time'
+
+        This method checks the name of the column against a hardcoded list
+        of time-like names, then checks the `dtype` of the column (or the
+        first element in the column) against a hardcoded list of time-like
+        dtypes (`gwpy.time.gps_types`).
+        """
+        # if the name looks like a time column, accept that
+        if name.lower() in TIME_LIKE_COLUMN_NAMES:
+            return True
+
+        # if the dtype of this column looks right, accept that
+        if self[name].dtype in gps_types:
+            return True
+        try:
+            return isinstance(self[name][0], gps_types)
+        except IndexError:
+            return False
+
     def _get_time_column(self):
         """Return the name of the 'time' column in this table.
 
         This method tries the following:
 
-        - look for a column named 'time'
+        - look for a single column named 'time', 'gps', or 'peakGPS'
         - look for a single column with a GPS type (e.g. `LIGOTimeGPS`)
 
         So, its not foolproof.
+
+        Raises a `ValueError` if either 0 or multiple matches are found.
         """
-        tcols = [
-            "time",  # standard
-            "tc",  # GWOSC catalogues
-            "peakGPS",  # gravityspy
-        ]
-        for col in tcols:
-            if col in self.columns:
-                return col
+        matches = list(filter(self._is_time_column, self.columns))
         try:
-            time, = [name for name in self.columns if
-                     isinstance(self[name][0], gps_types)]
-        except (ValueError, IndexError):
-            msg = (
-                "cannot identify time column for table, no column "
-                "named {0}, or {1!r}, and none with GPS dtypes".format(
-                    ", ".join(map(repr, tcols[:-1])),
-                    tcols[-1],
-                )
+            time, = matches
+        except ValueError:
+            tcolnames = ", or ".join(
+                ", ".join(map(repr, TIME_LIKE_COLUMN_NAMES)).rsplit(", ", 1),
             )
+            msg = (
+                "cannot identify time column for table, no columns "
+                "named {}, or with a GPS dtype".format(tcolnames)
+            )
+            if len(matches) > 1:
+                msg = msg.replace("no columns", "multiple columns")
             raise ValueError(msg)
         return time
 
@@ -312,7 +304,11 @@ class EventTable(Table):
 
         To download a table of all blip glitches from the Gravity Spy database:
 
-        >>> EventTable.fetch('gravityspy', 'glitches', selection='Label=Blip')
+        >>> EventTable.fetch(
+        ...     'gravityspy',
+        ...     'glitches',
+        ...     selection=['ml_label=Blip', 'ml_confidence>0.9'],
+        ... )
 
         To download a table from any SQL-type server
 
@@ -623,11 +619,8 @@ class EventTable(Table):
         from ..plot import Plot
         from ..plot.tex import label_to_latex
 
-        try:
-            tcol = self._get_time_column()
-        except ValueError:
-            tcol = None
-        if args[0].name == tcol:  # map X column to GPS axis
+        if self._is_time_column(args[0].name):
+            # map X column to GPS axis
             kwargs.setdefault('figsize', (12, 6))
             kwargs.setdefault('xscale', 'auto-gps')
 
@@ -718,7 +711,7 @@ class EventTable(Table):
         Custom operations can be defined using filter tuple definitions:
 
         >>> from gwpy.table.filters import in_segmentlist
-        >>> filter(my_table, ('time', in_segmentlist, segs))
+        >>> table.filter(('time', in_segmentlist, segs))
         """
         return filter_table(self, *column_filters)
 
@@ -760,14 +753,23 @@ class EventTable(Table):
         if window <= 0.0:
             raise ValueError('Window must be a positive value')
 
+        # If no rows, no need to cluster
+        if len(self) == 0:
+            return self.copy()
+
         # Generate index and rank vectors that are ordered
         orderidx = numpy.argsort(self[index])
         col = self[index][orderidx]
         param = self[rank][orderidx]
 
         # Find all points where the index vector changes by less than window
-        # and divide the resulting array into clusters of adjacent points
         clusterpoints = numpy.where(numpy.diff(col) <= window)[0]
+
+        # If no such cluster points, no need to cluster
+        if len(clusterpoints) == 0:
+            return self.copy()
+
+        # Divide points into clusters of adjacent points
         sublists = numpy.split(clusterpoints,
                                numpy.where(numpy.diff(clusterpoints) > 1)[0]+1)
 
