@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Louisiana State University (2014-2017)
+#               Cardiff University (2017-2021)
 #
 # This file is part of GWpy.
 #
@@ -37,7 +38,6 @@ This module defines the following classes
 user-facing objects.**
 """
 
-import os
 import sys
 import warnings
 from collections import OrderedDict
@@ -84,7 +84,9 @@ def _dynamic_scaled(scaled, channel):
     """Determine default for scaled based on channel name
 
     This is mainly to work around LIGO not correctly recording ADC
-    scaling parameters for most of Advanced LIGO (through 2019).
+    scaling parameters for most of Advanced LIGO (through 2023).
+    Scaling parameters for H0 and L0 data are also not correct
+    starting in mid-2020.
 
     Parameters
     ----------
@@ -108,7 +110,7 @@ def _dynamic_scaled(scaled, channel):
     """
     if scaled is not None:
         return scaled
-    return not str(channel).startswith(("H1", "L1"))
+    return not str(channel).startswith(("H0", "L0", "H1", "L1"))
 
 
 # -- TimeSeriesBase------------------------------------------------------------
@@ -243,8 +245,6 @@ class TimeSeriesBase(Series):
             del self.dt
             return
         self.dt = (1 / units.Quantity(val, units.Hertz)).to(self.xunit)
-        if numpy.isclose(self.dt.value, round(self.dt.value)):
-            self.dt = units.Quantity(round(self.dt.value), self.dt.unit)
 
     # -- duration
     @property
@@ -368,10 +368,10 @@ class TimeSeriesBase(Series):
             prefix for the progress meter
 
         type : `int`, optional
-            NDS2 channel type integer
+            NDS2 channel type integer or string name to match
 
         dtype : `type`, `numpy.dtype`, `str`, optional
-            identifier for desired output data type
+            NDS2 data type to match
         """
         return cls.DictClass.fetch(
             [channel], start, end, host=host, port=port, verbose=verbose,
@@ -380,9 +380,9 @@ class TimeSeriesBase(Series):
 
     @classmethod
     def fetch_open_data(cls, ifo, start, end, sample_rate=4096,
-                        tag=None, version=None,
-                        format='hdf5', host=GWOSC_DEFAULT_HOST,
-                        verbose=False, cache=None, **kwargs):
+                        version=None, format='hdf5',
+                        host=GWOSC_DEFAULT_HOST, verbose=False,
+                        cache=None, **kwargs):
         """Fetch open-access data from the LIGO Open Science Center
 
         Parameters
@@ -401,13 +401,9 @@ class TimeSeriesBase(Series):
 
         sample_rate : `float`, optional,
             the sample rate of desired data; most data are stored
-            by LOSC at 4096 Hz, however there may be event-related
+            by GWOSC at 4096 Hz, however there may be event-related
             data releases with a 16384 Hz rate, default: `4096`
 
-        tag : `str`, optional
-            file tag, e.g. ``'CLN'`` to select cleaned data, or ``'C00'``
-            for 'raw' calibrated data.
-
         version : `int`, optional
             version of files to download, defaults to highest discovered
             version
@@ -419,7 +415,7 @@ class TimeSeriesBase(Series):
             - ``'gwf'`` - requires |LDAStools.frameCPP|_
 
         host : `str`, optional
-            HTTP host name of LOSC server to access
+            HTTP host name of GWOSC server to access
 
         verbose : `bool`, optional, default: `False`
             print verbose output while fetching data
@@ -465,41 +461,31 @@ class TimeSeriesBase(Series):
                                epoch=1126259446.0))
 
         For the `StateVector`, the naming of the bits will be
-        ``format``-dependent, because they are recorded differently by LOSC
+        ``format``-dependent, because they are recorded differently by GWOSC
         in different formats.
 
-        For events published in O2 and later, LOSC typically provides
-        multiple data sets containing the original (``'C00'``) and cleaned
-        (``'CLN'``) data.
-        To select both data sets and plot a comparison, for example:
-
-        >>> orig = TimeSeries.fetch_open_data('H1', 1187008870, 1187008896,
-        ...                                   tag='C00')
-        >>> cln = TimeSeries.fetch_open_data('H1', 1187008870, 1187008896,
-        ...                                  tag='CLN')
-        >>> origasd = orig.asd(fftlength=4, overlap=2)
-        >>> clnasd = cln.asd(fftlength=4, overlap=2)
-        >>> plot = origasd.plot(label='Un-cleaned')
-        >>> ax = plot.gca()
-        >>> ax.plot(clnasd, label='Cleaned')
-        >>> ax.set_xlim(10, 1400)
-        >>> ax.set_ylim(1e-24, 1e-20)
-        >>> ax.legend()
-        >>> plot.show()
-
         Notes
         -----
         `StateVector` data are not available in ``txt.gz`` format.
         """
-        from .io.losc import fetch_losc_data
-        return fetch_losc_data(ifo, start, end, sample_rate=sample_rate,
-                               tag=tag, version=version, format=format,
-                               verbose=verbose, cache=cache,
-                               host=host, cls=cls, **kwargs)
+        from .io.losc import fetch_gwosc_data
+        return fetch_gwosc_data(
+            ifo,
+            start,
+            end,
+            sample_rate=sample_rate,
+            version=version,
+            format=format,
+            verbose=verbose,
+            cache=cache,
+            host=host,
+            cls=cls,
+            **kwargs,
+        )
 
     @classmethod
     def find(cls, channel, start, end, frametype=None, pad=None,
-             scaled=None, dtype=None, nproc=1, verbose=False, **readargs):
+             scaled=None, nproc=1, verbose=False, **readargs):
         """Find and read data from frames for a channel
 
         Parameters
@@ -527,10 +513,6 @@ class TimeSeriesBase(Series):
             value with which to fill gaps in the source data,
             by default gaps will result in a `ValueError`.
 
-        dtype : `numpy.dtype`, `str`, `type`, or `dict`
-            numeric data type for returned data, e.g. `numpy.float`, or
-            `dict` of (`channel`, `dtype`) pairs
-
         allow_tape : `bool`, optional, default: `True`
             allow reading from frame files on (slow) magnetic tape
 
@@ -548,7 +530,6 @@ class TimeSeriesBase(Series):
             verbose=verbose,
             pad=pad,
             scaled=scaled,
-            dtype=dtype,
             nproc=nproc,
             **readargs
         )[str(channel)]
@@ -582,10 +563,6 @@ class TimeSeriesBase(Series):
             apply slope and bias calibration to ADC data, for non-ADC data
             this option has no effect
 
-        dtype : `numpy.dtype`, `str`, `type`, or `dict`
-            numeric data type for returned data, e.g. `numpy.float`, or
-            `dict` of (`channel`, `dtype`) pairs
-
         nproc : `int`, optional, default: `1`
             number of parallel processes to use, serial process by
             default.
@@ -700,44 +677,68 @@ class TimeSeriesBase(Series):
     def from_lal(cls, lalts, copy=True):
         """Generate a new TimeSeries from a LAL TimeSeries of any type.
         """
-        from ..utils.lal import from_lal_unit
+        # convert the units
+        from ..utils.lal import (from_lal_unit, from_lal_type)
+        unit = from_lal_unit(lalts.sampleUnits)
+
         try:
-            unit = from_lal_unit(lalts.sampleUnits)
-        except (TypeError, ValueError) as exc:
-            warnings.warn("%s, defaulting to 'dimensionless'" % str(exc))
-            unit = None
-        channel = Channel(lalts.name, sample_rate=1/lalts.deltaT, unit=unit,
-                          dtype=lalts.data.data.dtype)
-        out = cls(lalts.data.data, channel=channel, t0=lalts.epoch,
-                  dt=lalts.deltaT, unit=unit, name=lalts.name, copy=False)
+            dtype = lalts.data.data.dtype
+        except AttributeError:  # no data
+            dtype = from_lal_type(lalts)
+            data = []
+        else:
+            data = lalts.data.data
+
+        # create new series
+        out = cls(
+            data,
+            dtype=dtype,
+            name=lalts.name or None,
+            unit=unit,
+            t0=lalts.epoch,
+            dt=lalts.deltaT,
+            channel=None,
+            copy=False,
+        )
+
         if copy:
             return out.copy()
         return out
 
     def to_lal(self):
         """Convert this `TimeSeries` into a LAL TimeSeries.
+
+        .. note::
+
+           This operation always copies data to new memory.
         """
         import lal
         from ..utils.lal import (find_typed_function, to_lal_unit)
 
         # map unit
         try:
-            unit = to_lal_unit(self.unit)
-        except ValueError as e:
-            warnings.warn("%s, defaulting to lal.DimensionlessUnit" % str(e))
+            unit, scale = to_lal_unit(self.unit)
+        except ValueError as exc:
+            warnings.warn(f"{exc}, defaulting to lal.DimensionlessUnit")
             unit = lal.DimensionlessUnit
+            scale = 1
 
         # create TimeSeries
         create = find_typed_function(self.dtype, 'Create', 'TimeSeries')
         lalts = create(
-            self.name,
+            self.name or str(self.channel or "") or None,
             LIGOTimeGPS(to_gps(self.epoch.gps)),
             0,
             self.dt.value,
             unit,
             self.shape[0],
         )
+
+        # assign data
         lalts.data.data = self.value
+        if scale != 1:
+            lalts.data.data *= scale
+
         return lalts
 
     @classmethod
@@ -792,31 +793,18 @@ class TimeSeriesBase(Series):
                 op_ = ufunc.__name__
             out = out.view(StateTimeSeries)
             out.__metadata_finalize__(orig)
-            out.override_unit('')
             oname = orig.name if isinstance(orig, type(self)) else orig
             vname = value.name if isinstance(value, type(self)) else value
             out.name = '{0!s} {1!s} {2!s}'.format(oname, op_, vname)
         return out
 
-    def __array_wrap__(self, obj, context=None):
-        # if output type is boolean, return a `StateTimeSeries`
-        if obj.dtype == numpy.dtype(bool):
-            from .statevector import StateTimeSeries
-            ufunc = context[0]
-            value = context[1][-1]
-            try:
-                op_ = _UFUNC_STRING[ufunc.__name__]
-            except KeyError:
-                op_ = ufunc.__name__
-            result = obj.view(StateTimeSeries)
-            result.override_unit('')
-            oname = obj.name if isinstance(obj, type(self)) else obj
-            vname = value.name if isinstance(value, type(self)) else value
-            result.name = '{0!s} {1!s} {2!s}'.format(oname, op_, vname)
-        # otherwise, return a regular TimeSeries
-        else:
-            result = super().__array_wrap__(obj, context=context)
-        return result
+    # Quantity overrides __eq__ and __ne__ in a way that doesn't work for us,
+    # so we just undo that
+    def __eq__(self, other):
+        return numpy.ndarray.__eq__(self, other)
+
+    def __ne__(self, other):
+        return numpy.ndarray.__ne__(self, other)
 
 
 # -- TimeSeriesBaseDict -------------------------------------------------------
@@ -1004,7 +992,7 @@ class TimeSeriesBaseDict(OrderedDict):
         return self
 
     def crop(self, start=None, end=None, copy=False):
-        """Crop each entry of this `dict`
+        """Crop each entry of this `dict`.
 
         This method calls the :meth:`crop` method of all entries and
         modifies this dict in place.
@@ -1019,6 +1007,10 @@ class TimeSeriesBaseDict(OrderedDict):
             GPS end time of required data, defaults to end of data found;
             any input parseable by `~gwpy.time.to_gps` is fine
 
+        copy : `bool`, optional, default: `False`
+            If `True` copy the data for each entry to fresh memory,
+            otherwise return a view.
+
         See also
         --------
         TimeSeries.crop
@@ -1098,11 +1090,10 @@ class TimeSeriesBaseDict(OrderedDict):
             access if necessary to retrieve the data
 
         type : `int`, `str`, optional
-            NDS2 channel type integer or string name.
+            NDS2 channel type integer or string name to match.
 
         dtype : `numpy.dtype`, `str`, `type`, or `dict`
-            numeric data type for returned data, e.g. `numpy.float`, or
-            `dict` of (`channel`, `dtype`) pairs
+            NDS2 data type to match
 
         Returns
         -------
@@ -1146,8 +1137,12 @@ class TimeSeriesBaseDict(OrderedDict):
                                          scaled=scaled, allow_tape=allow_tape_)
                     except (RuntimeError, ValueError) as exc:
                         error = str(exc)  # need to assign to take out of scope
-                        warnings.warn(error.split('\n', 1)[0],
-                                      io_nds2.NDSWarning)
+                        msg = error.split('\n', 1)[0]
+                        warnings.warn(
+                            f"failed to fetch data for {', '.join(channels)} "
+                            f"in interval [{start}, {end}): {msg}",
+                            io_nds2.NDSWarning,
+                        )
 
                 # if failing occurred because of data on tape, don't try
                 # reading channels individually, the same error will occur
@@ -1185,56 +1180,65 @@ class TimeSeriesBaseDict(OrderedDict):
 
     @classmethod
     def find(cls, channels, start, end, frametype=None,
-             frametype_match=None, pad=None, scaled=None, dtype=None, nproc=1,
+             frametype_match=None, pad=None, scaled=None, nproc=1,
              verbose=False, allow_tape=True, observatory=None, **readargs):
         """Find and read data from frames for a number of channels.
 
+        This method uses :mod:`gwdatafind` to discover the (`file://`) URLs
+        that provide the requested data, then reads those files using
+        :meth:`TimeSeriesDict.read()`.
+
         Parameters
         ----------
         channels : `list`
-            required data channels.
+            Required data channels.
 
         start : `~gwpy.time.LIGOTimeGPS`, `float`, `str`
             GPS start time of required data,
             any input parseable by `~gwpy.time.to_gps` is fine
 
-        end : `~gwpy.time.LIGOTimeGPS`, `float`, `str`, optional
+        end : `~gwpy.time.LIGOTimeGPS`, `float`, `str`
             GPS end time of required data, defaults to end of data found;
             any input parseable by `~gwpy.time.to_gps` is fine
 
-        frametype : `str`, optional
-            name of frametype in which this channel is stored, by default
-            will search for all required frame types
+        frametype : `str`
+            Name of frametype in which this channel is stored; if not given
+            all frametypes discoverable via GWDataFind will be searched for
+            the required channels.
 
-        frametype_match : `str`, optional
-            regular expression to use for frametype matching
+        frametype_match : `str`
+            Regular expression to use for frametype matching.
 
-        pad : `float`, optional
-            value with which to fill gaps in the source data,
+        pad : `float`
+            Value with which to fill gaps in the source data,
             by default gaps will result in a `ValueError`.
 
-        scaled : `bool`, optional
-            apply slope and bias calibration to ADC data, for non-ADC data
+        scaled : `bool`
+            Apply slope and bias calibration to ADC data, for non-ADC data
             this option has no effect.
 
-        dtype : `numpy.dtype`, `str`, `type`, or `dict`
-            numeric data type for returned data, e.g. `numpy.float`, or
-            `dict` of (`channel`, `dtype`) pairs
+        nproc : `int`
+            Number of parallel processes to use.
 
-        nproc : `int`, optional, default: `1`
-            number of parallel processes to use, serial process by
-            default.
-
-        allow_tape : `bool`, optional, default: `True`
-            allow reading from frame files on (slow) magnetic tape
+        allow_tape : `bool`
+            Allow reading from frame files on (slow) magnetic tape.
 
         verbose : `bool`, optional
-            print verbose output about read progress, if ``verbose``
+            Print verbose output about read progress, if ``verbose``
             is specified as a string, this defines the prefix for the
-            progress meter
+            progress meter.
 
-        **readargs
-            any other keyword arguments to be passed to `.read()`
+        readargs
+            Any other keyword arguments to be passed to `.read()`.
+
+        Raises
+        ------
+        requests.exceptions.HTTPError
+            If the GWDataFind query fails for any reason.
+
+        RuntimeError
+            If no files are found to read, or if the read operation
+            fails.
         """
         from ..io import datafind as io_datafind
 
@@ -1242,11 +1246,18 @@ class TimeSeriesBaseDict(OrderedDict):
         end = to_gps(end)
 
         # -- find frametype(s)
+
+        frametypes = {}
+
         if frametype is None:
             matched = io_datafind.find_best_frametype(
-                channels, start, end, frametype_match=frametype_match,
-                allow_tape=allow_tape)
-            frametypes = {}
+                channels,
+                start,
+                end,
+                frametype_match=frametype_match,
+                allow_tape=allow_tape,
+            )
+
             # flip dict to frametypes with a list of channels
             for name, ftype in matched.items():
                 try:
@@ -1255,49 +1266,67 @@ class TimeSeriesBaseDict(OrderedDict):
                     frametypes[ftype] = [name]
 
             if verbose and len(frametypes) > 1:
-                gprint("Determined %d frametypes to read" % len(frametypes))
+                gprint(f"Determined {len(frametypes)} frametypes to read")
             elif verbose:
-                gprint("Determined best frametype as %r"
-                       % list(frametypes.keys())[0])
-        else:
-            frametypes = {frametype: channels}
+                gprint(f"Determined best frametype as '{list(frametypes)[0]}'")
+        else:  # use the given frametype for all channels
+            frametypes[frametype] = channels
 
         # -- read data
+
         out = cls()
         for frametype, clist in frametypes.items():
             if verbose:
-                verbose = "Reading {} frames".format(frametype)
+                verbose = f"Reading '{frametype}' data"
+
             # parse as a ChannelList
             channellist = ChannelList.from_names(*clist)
             # strip trend tags from channel names
             names = [c.name for c in channellist]
+
             # find observatory for this group
             if observatory is None:
                 try:
-                    observatory = ''.join(
+                    obs = ''.join(
                         sorted(set(c.ifo[0] for c in channellist)))
                 except TypeError as exc:
-                    exc.args = "Cannot parse list of IFOs from channel names",
-                    raise
+                    raise ValueError(
+                        "Cannot parse list of IFOs from channel names",
+                    ) from exc
+
+            else:
+                obs = observatory
             # find frames
             cache = io_datafind.find_urls(
-                observatory,
+                obs,
                 frametype,
                 start,
                 end,
                 on_gaps="error" if pad is None else "warn",
             )
             if not cache:
-                raise RuntimeError("No %s-%s frame files found for [%d, %d)"
-                                   % (observatory, frametype, start, end))
+                raise RuntimeError(
+                    f"No {observatory}-{frametype} URLs found for "
+                    f"[{start}, {end})",
+                )
+
             # read data
-            readargs.setdefault('format', 'gwf')
-            new = cls.read(cache, names, start=start, end=end, pad=pad,
-                           scaled=scaled, dtype=dtype, nproc=nproc,
-                           verbose=verbose, **readargs)
+            new = cls.read(
+                cache,
+                names,
+                start=start,
+                end=end,
+                pad=pad,
+                scaled=scaled,
+                nproc=nproc,
+                verbose=verbose,
+                **readargs,
+            )
+
             # map back to user-given channel name and append
-            out.append(type(new)((key, new[chan]) for
-                                 (key, chan) in zip(clist, names)))
+            out.append(type(new)(
+                (key, new[chan]) for (key, chan) in zip(clist, names)
+            ))
         return out
 
     @classmethod
@@ -1333,10 +1362,6 @@ class TimeSeriesBaseDict(OrderedDict):
             apply slope and bias calibration to ADC data, for non-ADC data
             this option has no effect.
 
-        dtype : `numpy.dtype`, `str`, `type`, or `dict`
-            numeric data type for returned data, e.g. `numpy.float`, or
-            `dict` of (`channel`, `dtype`) pairs
-
         nproc : `int`, optional, default: `1`
             number of parallel processes to use, serial process by
             default.
@@ -1360,21 +1385,18 @@ class TimeSeriesBaseDict(OrderedDict):
         """
         # separate non-None nds2-only keywords here
         nds_kw = {}
-        for key in ('host', 'port', 'connection'):
+        for key in ('host', 'port', 'connection', 'type', 'dtype'):
             val = kwargs.pop(key, None)
             if val is not None:
                 nds_kw[key] = val
 
         # try and find from frames
-        if not nds_kw and (
-                os.getenv('LIGO_DATAFIND_SERVER')
-                or os.getenv('VIRGODATA')
-        ):
+        if not nds_kw:
             if verbose:
                 gprint("Attempting to access data from frames...")
             try:
                 return cls.find(channels, start, end, pad=pad, scaled=scaled,
-                                dtype=dtype, verbose=verbose,
+                                verbose=verbose,
                                 allow_tape=allow_tape or False,
                                 **kwargs)
             except (ImportError, RuntimeError, ValueError) as exc:
@@ -1460,9 +1482,18 @@ class TimeSeriesBaseDict(OrderedDict):
             all other keyword arguments are passed to the plotter as
             appropriate
         """
+        kwargs.update({
+            "method": method,
+            "label": label,
+        })
+
         # make plot
         from ..plot import Plot
-        plot = Plot(self.values(), method=method, label=label, **kwargs)
+
+        if kwargs.get("separate", False):
+            plot = Plot(*self.values(), **kwargs)
+        else:
+            plot = Plot(self.values(), **kwargs)
 
         # update labels
         artmap = {'plot': 'lines', 'scatter': 'collections'}
