@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -295,13 +295,9 @@ def read_frdata(frdata, epoch, start, end, scaled=True,
         ``[start, end)`` interval.
     """
     datastart = epoch + frdata.GetTimeOffset()
-    try:
-        trange = frdata.GetTRange()
-    except AttributeError:  # not proc channel
-        trange = 0.
 
     # check overlap with user-requested span
-    if (end and datastart >= end) or (trange and datastart + trange < start):
+    if end and datastart >= end:
         raise _Skip()
 
     # get scaling
@@ -312,6 +308,10 @@ def read_frdata(frdata, epoch, start, end, scaled=True,
         slope = None
         bias = None
     else:
+        # workaround https://git.ligo.org/ldastools/LDAS_Tools/-/issues/114
+        # by forcing the default slope to 1.
+        if bias == slope == 0.:
+            slope = 1.
         null_scaling = slope == 1. and bias == 0.
 
     out = None
@@ -401,6 +401,7 @@ def read_frvect(vect, epoch, start, end, name=None, series_class=TimeSeries):
     dim = vect.GetDim(0)
     dx = dim.dx
     x0 = dim.startX
+    xunit = dim.GetUnitX() or None
 
     # start and end GPS times of this FrVect
     dimstart = epoch + x0
@@ -428,8 +429,16 @@ def read_frvect(vect, epoch, start, end, name=None, series_class=TimeSeries):
     unit = vect.GetUnitY() or None
 
     # create array
-    series = series_class(arr, t0=dimstart+nxstart*dx, dt=dx, name=name,
-                          channel=name, unit=unit, copy=False)
+    series = series_class(
+        arr,
+        t0=dimstart+nxstart*dx,
+        dt=dx,
+        name=name,
+        channel=name,
+        xunit=xunit,
+        unit=unit,
+        copy=False,
+    )
 
     # add information to channel
     series.channel.sample_rate = series.sample_rate.value
