@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Louisiana State University (2014-2017)
+#               Cardiff University (2017-2021)
 #
 # This file is part of GWpy.
 #
@@ -183,8 +184,10 @@ class StateTimeSeries(TimeSeriesBase):
     def unit(self):
         return units.dimensionless_unscaled
 
-    def override_unit(self, unit, parse_strict='raise'):
-        return NotImplemented
+    def override_unit(self, *args, **kwargs):
+        raise NotImplementedError(
+            f"overriding units is not supported for {type(self).__name__}",
+        )
 
     def _to_own_unit(self, value, check_precision=True):
         if isinstance(value, units.Quantity) and value.unit != self.unit:
@@ -202,9 +205,6 @@ class StateTimeSeries(TimeSeriesBase):
             return out.view(bool)
         return out
 
-    def __array_wrap__(self, obj, context=None):
-        return super().__array_wrap__(obj, context=context).view(bool)
-
     def diff(self, n=1, axis=-1):
         slice1 = (slice(1, None),)
         slice2 = (slice(None, -1),)
@@ -429,8 +429,8 @@ class Bits(list):
             indent, self.__class__.__name__,
             mask, str(self.channel), str(self.epoch)))
 
-    def __array__(self):
-        return numpy.array([b or '' for b in self])
+    def __array__(self, dtype="U"):
+        return numpy.array([b or '' for b in self], dtype=dtype)
 
 
 # -- StateVector --------------------------------------------------------------
