@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -53,28 +53,38 @@ class TestTimeSeriesBase(_TestSeries):
     def test_new(self):
         """Test `gwpy.timeseries.TimeSeriesBase` constructor
         """
-        array = super().test_new()
+        array = self.create()
+        super().test_new()
 
         # check time-domain metadata
         assert array.epoch == GPS_EPOCH
         assert array.sample_rate == units.Quantity(1, 'Hertz')
         assert array.dt == units.Quantity(1, 'second')
 
-        # check handling of epoch vs t0
+    def test_new_epoch_t0(self):
+        """Test `gwpy.timeseries.TimeSeriesBase` handling of epoch vs t0.
+        """
         a = self.create(epoch=10)
         b = self.create(t0=10)
         utils.assert_quantity_sub_equal(a, b)
-        with pytest.raises(ValueError) as exc:
+        with pytest.raises(
+            ValueError,
+            match="^give only one of epoch or t0$",
+        ):
             self.TEST_CLASS(self.data, epoch=1, t0=1)
-        assert str(exc.value) == 'give only one of epoch or t0'
 
+    def test_new_sample_rate_dt(self):
+        """Test `gwpy.timeseries.TimeSeriesBase` handling of sample_rate vs dt.
+        """
         # check handling of sample_rate vs dt
         a = self.create(sample_rate=100)
         b = self.create(dt=0.01)
         utils.assert_quantity_sub_equal(a, b)
-        with pytest.raises(ValueError) as exc:
+        with pytest.raises(
+            ValueError,
+            match="^give only one of sample_rate or dt$",
+        ):
             self.TEST_CLASS(self.data, sample_rate=1, dt=1)
-        assert str(exc.value) == 'give only one of sample_rate or dt'
 
     def test_epoch(self):
         """Test `gwpy.timeseries.TimeSeriesBase.epoch`
@@ -98,26 +108,48 @@ class TestTimeSeriesBase(_TestSeries):
             a.t0, units.Quantity(1126259462, 's'))
 
     def test_sample_rate(self):
-        """Test `gwpy.timeseries.TimeSeriesBase.sample_rate`
+        """Test `gwpy.timeseries.TimeSeriesBase.sample_rate`.
         """
         # check basic conversion from dt -> sample_rate
         a = self.create(dt=0.5)
         assert a.sample_rate == 2 * units.Hz
 
+    def test_sample_rate_del(self, array):
+        """Test that `sample_rate` cannot be deleted.
+        """
         # test that we can't delete sample_rate
-        with pytest.raises(AttributeError):
-            del a.sample_rate
+        with pytest.raises(
+            AttributeError,
+            match="(can't delete attribute|has no deleter)",
+        ):
+            del array.sample_rate
 
+    def test_sample_rate_none(self, array):
+        """Test that `sample_rate = None` is effectively a deletion.
+        """
         # check None gets preserved
-        a.sample_rate = None
-        with pytest.raises(AttributeError):
-            a._t0
+        array.sample_rate = None
+        with pytest.raises(AttributeError, match="_t0"):
+            array._t0
 
-        # check other types
-        a.sample_rate = units.Quantity(128, units.Hz)
-        utils.assert_quantity_equal(a.dt, units.s / 128.)
-        a.sample_rate = units.Quantity(16.384, units.kiloHertz)
-        utils.assert_quantity_equal(a.dt, units.s / 16384)
+    @pytest.mark.parametrize(("samp", "dt"), [
+        (128 * units.Hz, units.s / 128.),
+        (16.384 * units.kiloHertz, units.s / 16384),
+        (10 / units.s, units.s / 10),
+    ])
+    def test_sample_rate_type(self, array, samp, dt):
+        """Test that units and types are handled when setting `sample_rate`.
+        """
+        array.sample_rate = samp
+        utils.assert_quantity_equal(array.dt, dt)
+
+    def test_sample_rate_ghz(self, array):
+        """Test that very large sample rates don't get rounded to dt=0.
+
+        Regression: https://gitlab.com/gwpy/gwpy/-/issues/1646
+        """
+        array.sample_rate = 1e9
+        assert array.dt.value > 0.
 
     def test_duration(self, array):
         assert array.duration == array.t0 + array.shape[0] * array.dt
@@ -133,7 +165,7 @@ class TestTimeSeriesBase(_TestSeries):
             plot.save(BytesIO(), format='png')
             plot.close()
 
-    @utils.skip_missing_dependency('nds2')
+    @pytest.mark.requires("nds2")
     def test_from_nds2_buffer(self):
         # build fake buffer
         nds_buffer = mocks.nds2_buffer(
@@ -171,21 +203,27 @@ class TestTimeSeriesBase(_TestSeries):
         assert b.dt == 1/128. * units.s
         assert shares_memory(nds_buffer.data, b.value)
 
-    @utils.skip_missing_dependency('lal')
+    @pytest.mark.requires("lal")
     def test_to_from_lal(self, array):
-        import lal
-
         # check that to + from returns the same array
         lalts = array.to_lal()
         a2 = type(array).from_lal(lalts)
-        utils.assert_quantity_sub_equal(array, a2, exclude=['name', 'channel'])
-        assert a2.name == ''
+        utils.assert_quantity_sub_equal(array, a2, exclude=['channel'])
 
-        # test copy=False
-        a2 = type(array).from_lal(lalts, copy=False)
-        assert shares_memory(a2.value, lalts.data.data)
+    @pytest.mark.requires("lal")
+    @pytest.mark.parametrize("copy", (False, True))
+    def test_to_from_lal_no_copy(self, array, copy):
+        """Check that copy=False shares data
+        """
+        lalts = array.to_lal()
+        a2 = type(array).from_lal(lalts, copy=copy)
+        assert shares_memory(a2.value, lalts.data.data) is not copy
 
-        # test units
+    @pytest.mark.requires("lal")
+    def test_to_from_lal_unrecognised_units(self, array):
+        """Test that unrecognised units get warned, but the operation continues
+        """
+        import lal
         array.override_unit('undef')
         with pytest.warns(UserWarning):
             lalts = array.to_lal()
@@ -193,8 +231,27 @@ class TestTimeSeriesBase(_TestSeries):
         a2 = self.TEST_CLASS.from_lal(lalts)
         assert a2.unit == units.dimensionless_unscaled
 
-    @utils.skip_missing_dependency('lal')
-    @utils.skip_missing_dependency('pycbc')
+    @pytest.mark.requires("lal")
+    def test_to_from_lal_pow10_units(self, array):
+        """Test that normal scaled units scale the data properly
+        """
+        import lal
+        array.override_unit("km")
+        lalts = array.to_lal()
+        utils.assert_array_equal(lalts.data.data, array.value)
+        assert lalts.sampleUnits == lal.MeterUnit * 1000.
+
+    @pytest.mark.requires("lal")
+    def test_to_from_lal_scaled_units(self, array):
+        """Test that weird scaled units scale the data properly
+        """
+        import lal
+        array.override_unit("123 m")
+        lalts = array.to_lal()
+        utils.assert_array_equal(lalts.data.data, array.value * 123.)
+        assert lalts.sampleUnits == lal.MeterUnit
+
+    @pytest.mark.requires("lal", "pycbc")
     def test_to_from_pycbc(self, array):
         from pycbc.types import TimeSeries as PyCBCTimeSeries
 
@@ -244,9 +301,13 @@ class TestTimeSeriesBaseDict(object):
         assert instance.span == reduce(
             operator.or_, (ts.span for ts in instance.values()), Segment(0, 0),
         )
-        with pytest.raises(ValueError) as exc:
+
+    def test_span_error_empty(self):
+        with pytest.raises(
+            ValueError,
+            match="cannot calculate span for empty ",
+        ):
             self.TEST_CLASS().span
-        assert 'cannot calculate span for empty ' in str(exc.value)
 
     def test_copy(self, instance):
         copy = instance.copy()
@@ -340,21 +401,14 @@ class TestTimeSeriesBaseDict(object):
 
     def test_resample(self, instance):
         if self.ENTRY_CLASS is TimeSeriesBase:  # currently only for subclasses
-            return NotImplemented
+            pytest.skip(f"not implemented for {type(instance).__name__}")
+
+        # for all subclasses
         a = instance.resample(.5)
         for key in a:
             assert a[key].dx == 1/.5 * a[key].xunit
 
-    def test_fetch(self):
-        return NotImplemented
-
-    def test_find(self):
-        return NotImplemented
-
-    def test_get(self):
-        return NotImplemented
-
-    @utils.skip_missing_dependency('nds2')
+    @pytest.mark.requires("nds2")
     def test_from_nds2_buffers(self):
         buffers = [
             mocks.nds2_buffer('X1:TEST', numpy.arange(100), 1000000000,
@@ -382,6 +436,22 @@ class TestTimeSeriesBaseDict(object):
             plot.save(BytesIO(), format='png')
             plot.close()
 
+    def test_plot_separate(self, instance):
+        """Test plotting `TimeSeriesDict` on separate axes.
+
+        See https://gitlab.com/gwpy/gwpy/-/issues/1609
+        """
+        with rc_context(rc={'text.usetex': False}):
+            plot = instance.plot(separate=True)
+            assert len(plot.axes) == len(instance.keys())
+            for ax, key in zip(plot.axes, instance):
+                utils.assert_array_equal(ax.lines[-1].get_xdata(),
+                                         instance[key].xindex.value)
+                utils.assert_array_equal(ax.lines[-1].get_ydata(),
+                                         instance[key].value)
+            plot.save(BytesIO(), format='png')
+            plot.close()
+
 
 # -- TimeSeriesBaseList -------------------------------------------------------
 
@@ -414,18 +484,22 @@ class TestTimeSeriesBaseList(object):
         assert all(isinstance(s, Segment) for s in sl)
         assert sl == [(0, 100), (101, 1101)]
 
-    def test_append(self):
-        tsl = self.create()
-
-        # test simple append
+    def test_append(self, instance):
+        """Test `TimeSeriesList.append`.
+        """
         new = self.ENTRY_CLASS([1, 2, 3, 4, 5], x0=1102, dx=1)
-        tsl.append(new)
+        instance.append(new)
+        assert len(instance) == 3
+        assert instance[-1] is new
 
-        # test mismatched type raises error
-        with pytest.raises(TypeError) as exc:
-            tsl.append([1, 2, 3, 4, 5])
-        assert str(exc.value) == (
-            "Cannot append type 'list' to %s" % type(tsl).__name__)
+    def test_append_typeerror(self, instance):
+        """Test `TimeSeriesList.append` errors on type differences.
+        """
+        with pytest.raises(
+            TypeError,
+            match=f"^Cannot append type 'list' to {self.TEST_CLASS.__name__}$",
+        ):
+            instance.append([1, 2, 3, 4, 5])
 
     def test_extend(self):
         a = self.create()
