@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -30,13 +30,13 @@ from astropy import units
 
 from ..segments import (Segment, SegmentList, DataQualityFlag)
 from ..signal import (filter_design, qtransform, spectral)
-from ..signal.window import (recommended_overlap, planck)
+from ..signal.window import (get_window, recommended_overlap, planck)
 from .core import (TimeSeriesBase, TimeSeriesBaseDict, TimeSeriesBaseList,
                    as_series_dict_class)
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
 
-DEFAULT_FFT_METHOD = None
+DEFAULT_FFT_METHOD = "median"
 
 
 # -- utilities ----------------------------------------------------------------
@@ -216,15 +216,7 @@ class TimeSeries(TimeSeriesBase):
         # format window
         if window is None:
             window = 'boxcar'
-        if isinstance(window, (str, tuple)):
-            win = signal.get_window(window, nfft)
-        else:
-            win = numpy.asarray(window)
-            if len(win.shape) != 1:
-                raise ValueError('window must be 1-D')
-            elif win.shape[0] != nfft:
-                raise ValueError('Window is the wrong size.')
-        win = win.astype(self.dtype)
+        win = get_window(window, nfft).astype(self.dtype)
         scaling = 1. / numpy.absolute(win).mean()
 
         if nfft % 2:
@@ -272,7 +264,7 @@ class TimeSeries(TimeSeriesBase):
             formats
 
         method : `str`, optional
-            FFT-averaging method (default: ``'welch'``),
+            FFT-averaging method (default: ``'median'``),
             see *Notes* for more details
 
         **kwargs
@@ -319,7 +311,7 @@ class TimeSeries(TimeSeriesBase):
             formats
 
         method : `str`, optional
-            FFT-averaging method (default: ``'welch'``),
+            FFT-averaging method (default: ``'median'``),
             see *Notes* for more details
 
         Returns
@@ -409,7 +401,7 @@ class TimeSeries(TimeSeriesBase):
             formats
 
         method : `str`, optional
-            FFT-averaging method (default: ``'welch'``),
+            FFT-averaging method (default: ``'median'``),
             see *Notes* for more details
 
         nproc : `int`
@@ -567,7 +559,7 @@ class TimeSeries(TimeSeriesBase):
             number of seconds in single FFT
 
         method : `str`, optional
-            FFT-averaging method (default: ``'welch'``),
+            FFT-averaging method (default: ``'median'``),
             see *Notes* for more details
 
         overlap : `float`, optional
@@ -634,7 +626,7 @@ class TimeSeries(TimeSeriesBase):
         return specgram.variance(bins=bins, low=low, high=high, nbins=nbins,
                                  log=log, norm=norm, density=density)
 
-    def rayleigh_spectrum(self, fftlength=None, overlap=None):
+    def rayleigh_spectrum(self, fftlength=None, overlap=0, window='hann'):
         """Calculate the Rayleigh `FrequencySeries` for this `TimeSeries`.
 
         The Rayleigh statistic is calculated as the ratio of the standard
@@ -647,8 +639,13 @@ class TimeSeries(TimeSeriesBase):
             covering the full duration
 
         overlap : `float`, optional
-            number of seconds of overlap between FFTs, defaults to that of
-            the relevant method.
+            number of seconds of overlap between FFTs, passing `None` will
+            choose based on the window method, default: ``0``
+
+        window : `str`, `numpy.ndarray`, optional
+            window function to apply to timeseries prior to FFT,
+            see :func:`scipy.signal.get_window` for details on acceptable
+            formats
 
         Returns
         -------
@@ -660,10 +657,11 @@ class TimeSeries(TimeSeriesBase):
             spectral.rayleigh,
             fftlength=fftlength,
             overlap=overlap,
+            window=window,
         )
 
     def rayleigh_spectrogram(self, stride, fftlength=None, overlap=0,
-                             nproc=1, **kwargs):
+                             window='hann', nproc=1, **kwargs):
         """Calculate the Rayleigh statistic spectrogram of this `TimeSeries`
 
         Parameters
@@ -675,7 +673,13 @@ class TimeSeries(TimeSeriesBase):
             number of seconds in single FFT.
 
         overlap : `float`, optional
-            number of seconds of overlap between FFTs, default: ``0``
+            number of seconds of overlap between FFTs, passing `None` will
+            choose based on the window method, default: ``0``
+
+        window : `str`, `numpy.ndarray`, optional
+            window function to apply to timeseries prior to FFT,
+            see :func:`scipy.signal.get_window` for details on acceptable
+            formats
 
         nproc : `int`, optional
             maximum number of independent frame reading processes, default
@@ -698,6 +702,7 @@ class TimeSeries(TimeSeriesBase):
             stride,
             fftlength=fftlength,
             overlap=overlap,
+            window=window,
             nproc=nproc,
             **kwargs
         )
@@ -1055,7 +1060,7 @@ class TimeSeries(TimeSeriesBase):
         >>> notches = [filter_design.notch(f, 4096.) for f in (60, 120, 180)]
         >>> zpk = filter_design.concatenate_zpks(bp, *notches)
 
-        And then can download some data from LOSC to apply it using
+        And then can download some data from GWOSC to apply it using
         `TimeSeries.filter`:
 
         >>> from gwpy.timeseries import TimeSeries
@@ -1101,6 +1106,64 @@ class TimeSeries(TimeSeriesBase):
         new._unit = self.unit
         return new
 
+    def transfer_function(self, other, fftlength=None, overlap=None,
+                          window='hann', average='mean', **kwargs):
+        """Calculate the transfer function between this `TimeSeries` and
+        another.
+
+        This `TimeSeries` is the 'A-channel', serving as the reference
+        (denominator) while the other time series is the test (numerator)
+
+        Parameters
+        ----------
+        other : `TimeSeries`
+            `TimeSeries` signal to calculate the transfer function with
+
+        fftlength : `float`, optional
+            number of seconds in single FFT, defaults to a single FFT
+            covering the full duration
+
+        overlap : `float`, optional
+            number of seconds of overlap between FFTs, defaults to the
+            recommended overlap for the given window (if given), or 0
+
+        window : `str`, `numpy.ndarray`, optional
+            window function to apply to timeseries prior to FFT,
+            see :func:`scipy.signal.get_window` for details on acceptable
+            formats
+
+        average : `str`, optional
+            FFT-averaging method (default: ``'mean'``) passed to
+            underlying csd() and psd() methods
+
+        **kwargs
+            any other keyword arguments accepted by
+            :meth:`TimeSeries.csd` or :meth:`TimeSeries.psd`
+
+        Returns
+        -------
+        transfer_function : `~gwpy.frequencyseries.FrequencySeries`
+            the transfer function `FrequencySeries` of this `TimeSeries`
+            with the other
+
+        Notes
+        -----
+        If `self` and `other` have difference
+        :attr:`TimeSeries.sample_rate` values, the higher sampled
+        `TimeSeries` will be down-sampled to match the lower.
+        """
+        csd = self.csd(other, fftlength=fftlength, overlap=overlap,
+                       window=window, average=average, **kwargs)
+        psd = self.psd(fftlength=fftlength, overlap=overlap, window=window,
+                       average=average, **kwargs)
+
+        # Take the minimum of the frequencyseries csd and psd because the
+        # sample rate of different channels might yield different length
+        # objects
+        size = min(csd.size, psd.size)
+
+        return csd[:size] / psd[:size]
+
     def coherence(self, other, fftlength=None, overlap=None,
                   window='hann', **kwargs):
         """Calculate the frequency-coherence between this `TimeSeries`
@@ -1144,42 +1207,17 @@ class TimeSeries(TimeSeriesBase):
 
         See also
         --------
-        matplotlib.mlab.cohere
+        scipy.signal.coherence
             for details of the coherence calculator
         """
-        from matplotlib import mlab
-        from ..frequencyseries import FrequencySeries
-        # check sampling rates
-        if self.sample_rate.to('Hertz') != other.sample_rate.to('Hertz'):
-            sampling = min(self.sample_rate.value, other.sample_rate.value)
-            # resample higher rate series
-            if self.sample_rate.value == sampling:
-                other = other.resample(sampling)
-                self_ = self
-            else:
-                self_ = self.resample(sampling)
-        else:
-            sampling = self.sample_rate.value
-            self_ = self
-        # check fft lengths
-        if overlap is None:
-            overlap = 0
-        else:
-            overlap = int((overlap * self_.sample_rate).decompose().value)
-        if fftlength is None:
-            fftlength = int(self_.size/2. + overlap/2.)
-        else:
-            fftlength = int((fftlength * self_.sample_rate).decompose().value)
-        if window is not None:
-            kwargs['window'] = signal.get_window(window, fftlength)
-        coh, freqs = mlab.cohere(self_.value, other.value, NFFT=fftlength,
-                                 Fs=sampling, noverlap=overlap, **kwargs)
-        out = coh.view(FrequencySeries)
-        out.xindex = freqs
-        out.epoch = self.epoch
-        out.name = 'Coherence between %s and %s' % (self.name, other.name)
-        out.unit = 'coherence'
-        return out
+        return spectral.psd(
+            (self, other),
+            spectral.coherence,
+            fftlength=fftlength,
+            overlap=overlap,
+            window=window,
+            **kwargs
+        )
 
     def auto_coherence(self, dt, fftlength=None, overlap=None,
                        window='hann', **kwargs):
@@ -1398,7 +1436,7 @@ class TimeSeries(TimeSeriesBase):
         # the taper window in segments that are too short
         for seg in (span - deadtime):
             k = int((seg[0] - tstart) * sample)
-            N = int(abs(seg) * sample)
+            N = math.ceil(abs(seg) * sample)
             nhalf = min(npad, N)
             window = planck(2*npad, nleft=(int(k != 0) * npad),
                             nright=(int(k + N != self.size) * npad))
@@ -1439,7 +1477,7 @@ class TimeSeries(TimeSeriesBase):
         --------
         Demodulation is useful when trying to examine steady sinusoidal
         signals we know to be contained within data. For instance,
-        we can download some data from LOSC to look at trends of the
+        we can download some data from GWOSC to look at trends of the
         amplitude and phase of LIGO Livingston's calibration line at 331.3 Hz:
 
         >>> from gwpy.timeseries import TimeSeries
@@ -1535,7 +1573,7 @@ class TimeSeries(TimeSeriesBase):
         >>> import numpy
         >>> f0 = 123.456789  # signal frequency (Hz)
         >>> fdot = -9.87654321e-7  # signal frequency derivative (Hz/s)
-        >>> fpeoch = 1131350417  # phase epoch
+        >>> fepoch = 1131350417  # phase epoch
         >>> amp = 1.5e-22  # signal amplitude
         >>> phase0 = 0.4  # signal phase at the phase epoch
         >>> times = data.times.value - fepoch
@@ -1667,7 +1705,7 @@ class TimeSeries(TimeSeriesBase):
         return out
 
     def whiten(self, fftlength=None, overlap=0, method=DEFAULT_FFT_METHOD,
-               window='hanning', detrend='constant', asd=None,
+               window='hann', detrend='constant', asd=None,
                fduration=2, highpass=None, **kwargs):
         """Whiten this `TimeSeries` using inverse spectrum truncation
 
@@ -1682,11 +1720,11 @@ class TimeSeries(TimeSeriesBase):
             recommended overlap for the given window (if given), or 0
 
         method : `str`, optional
-            FFT-averaging method (default: ``'welch'``)
+            FFT-averaging method (default: ``'median'``)
 
         window : `str`, `numpy.ndarray`, optional
             window function to apply to timeseries prior to FFT,
-            default: ``'hanning'``
+            default: ``'hann'``
             see :func:`scipy.signal.get_window` for details on acceptable
             formats
 
@@ -1755,7 +1793,11 @@ class TimeSeries(TimeSeriesBase):
         asd = asd.interpolate(1./self.duration.decompose().value)
         # design whitening filter, with highpass if requested
         ncorner = int(highpass / asd.df.decompose().value) if highpass else 0
-        ntaps = int((fduration * self.sample_rate).decompose().value)
+        if isinstance(window, (str, tuple)):
+            ntaps = int((fduration * self.sample_rate).decompose().value)
+        else:
+            window = numpy.asarray(window)
+            ntaps = len(window)
         tdw = filter_design.fir_from_transfer(1/asd.value, ntaps=ntaps,
                                               window=window, ncorner=ncorner)
         # condition the input data and apply the whitening filter
@@ -1763,6 +1805,56 @@ class TimeSeries(TimeSeriesBase):
         out = in_.convolve(tdw, window=window)
         return out * numpy.sqrt(2 * in_.dt.decompose().value)
 
+    def find_gates(self, tzero=1.0, whiten=True,
+                   threshold=50., cluster_window=0.5, **whiten_kwargs):
+        """Identify points that should be gates using a provided threshold
+        and clustered within a provided time window.
+
+        Parameters
+        ----------
+        tzero : `int`, optional
+            half-width time duration (seconds) in which the timeseries is
+            set to zero
+
+        whiten : `bool`, optional
+            if True, data will be whitened before gating points are discovered,
+            use of this option is highly recommended
+
+        threshold : `float`, optional
+            amplitude threshold, if the data exceeds this value a gating window
+            will be placed
+
+        cluster_window : `float`, optional
+            time duration (seconds) over which gating points will be clustered
+
+        **whiten_kwargs
+            other keyword arguments that will be passed to the
+            `TimeSeries.whiten` method if it is being used when discovering
+            gating points
+
+        Returns
+        -------
+        out : `~gwpy.segments.SegmentList`
+            a list of segments that should be gated based on the
+            provided parameters
+
+        See also
+        --------
+        TimeSeries.gate
+            for a method that applies the identified gates
+        """
+        # Find points to gate based on a threshold
+        sample = self.sample_rate.to('Hz').value
+        data = self.whiten(**whiten_kwargs) if whiten else self
+        window_samples = cluster_window * sample
+        gates = signal.find_peaks(abs(data.value), height=threshold,
+                                  distance=window_samples)[0]
+        # represent gates as time segments
+        return SegmentList([Segment(
+            self.t0.value + (k / sample) - tzero,
+            self.t0.value + (k / sample) + tzero,
+        ) for k in gates]).coalesce()
+
     def gate(self, tzero=1.0, tpad=0.5, whiten=True,
              threshold=50., cluster_window=0.5, **whiten_kwargs):
         """Removes high amplitude peaks from data using inverse Planck window.
@@ -1831,25 +1923,18 @@ class TimeSeries(TimeSeriesBase):
         --------
         TimeSeries.mask
             for the method that masks out unwanted data
+        TimeSeries.find_gates
+            for the method that identifies gating points
         TimeSeries.whiten
             for the whitening filter used to identify gating points
         """
-        from scipy.signal import find_peaks
-        # Find points to gate based on a threshold
-        sample = self.sample_rate.to('Hz').value
-        data = self.whiten(**whiten_kwargs) if whiten else self
-        window_samples = cluster_window * sample
-        gates = find_peaks(abs(data.value), height=threshold,
-                           distance=window_samples)[0]
-        # represent gates as time segments
-        deadtime = SegmentList([Segment(
-            self.t0.value + (k / sample) - tzero,
-            self.t0.value + (k / sample) + tzero,
-        ) for k in gates]).coalesce()
-        # return the self-gated timeseries
-        return self.mask(deadtime=deadtime, const=0, tpad=tpad)
+        gates = self.find_gates(tzero=tzero, whiten=whiten,
+                                threshold=threshold,
+                                cluster_window=cluster_window,
+                                **whiten_kwargs)
+        return self.mask(deadtime=gates, const=0, tpad=tpad)
 
-    def convolve(self, fir, window='hanning'):
+    def convolve(self, fir, window='hann'):
         """Convolve this `TimeSeries` with an FIR filter using the
            overlap-save method
 
@@ -1859,7 +1944,7 @@ class TimeSeries(TimeSeriesBase):
             the time domain filter to convolve with
 
         window : `str`, optional
-            window function to apply to boundaries, default: ``'hanning'``
+            window function to apply to boundaries, default: ``'hann'``
             see :func:`scipy.signal.get_window` for details on acceptable
             formats
 
@@ -1888,7 +1973,7 @@ class TimeSeries(TimeSeriesBase):
         nfft = min(8*fir.size, self.size)
         # condition the input data
         in_ = self.copy()
-        window = signal.get_window(window, fir.size)
+        window = get_window(window, fir.size)
         in_.value[:pad] *= window[:pad]
         in_.value[-pad:] *= window[-pad:]
         # if FFT length is long enough, perform only one convolution
@@ -1915,7 +2000,7 @@ class TimeSeries(TimeSeriesBase):
         out.__array_finalize__(self)
         return out
 
-    def correlate(self, mfilter, window='hanning', detrend='linear',
+    def correlate(self, mfilter, window='hann', detrend='linear',
                   whiten=False, wduration=2, highpass=None, **asd_kw):
         """Cross-correlate this `TimeSeries` with another signal
 
@@ -1926,7 +2011,7 @@ class TimeSeries(TimeSeriesBase):
 
         window : `str`, optional
             window function to apply to timeseries prior to FFT,
-            default: ``'hanning'``
+            default: ``'hann'``
             see :func:`scipy.signal.get_window` for details on acceptable
             formats
 
