@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -23,6 +23,8 @@ import numpy
 
 from astropy.units import Quantity
 
+from .array import COPY_IF_NEEDED
+
 
 class Index(Quantity):
     """1-D `~astropy.units.Quantity` array for indexing a `Series`
@@ -57,12 +59,22 @@ class Index(Quantity):
         """
         if dtype is None:
             dtype = max(
-                numpy.array(start, subok=True, copy=False).dtype,
-                numpy.array(step, subok=True, copy=False).dtype,
+                numpy.array(start, subok=True, copy=COPY_IF_NEEDED).dtype,
+                numpy.array(step, subok=True, copy=COPY_IF_NEEDED).dtype,
             )
-        start = start.astype(dtype, copy=False)
-        step = step.astype(dtype, copy=False)
-        return cls(start + numpy.arange(num, dtype=dtype) * step, copy=False)
+        start = Quantity(start, dtype=dtype, copy=COPY_IF_NEEDED)
+        step = Quantity(step, dtype=dtype, copy=COPY_IF_NEEDED).to(start.unit)
+        stop = start + step * num
+        return cls(
+            numpy.arange(
+                start.value,
+                stop.value,
+                step.value,
+                dtype=dtype,
+            )[:num],
+            unit=start.unit,
+            copy=COPY_IF_NEEDED,
+        )
 
     @property
     def regular(self):
