@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -168,8 +168,8 @@ class Series(Array):
 
         Examples
         --------
-        >>> self._update_index("x0", 0)
-        >>> self._update_index("dx", 0)
+        >>> self._update_index("x", "x0", 0)
+        >>> self._update_index("x", "dx", 0)
 
         To actually set an index array, use `_set_index`
         """
@@ -210,21 +210,32 @@ class Series(Array):
         """Set a new index array for this series
         """
         axis = key[0]
-        origin = "{}0".format(axis)
-        delta = "d{}".format(axis)
+
+        # if given None, delete the current index
         if index is None:
             return delattr(self, key)
+
+        origin = f"{axis}0"
+        delta = f"d{axis}"
+
+        # format input as an Index array
         if not isinstance(index, Index):
             try:
                 unit = index.unit
             except AttributeError:
                 unit = getattr(self, "_default_{}unit".format(axis))
             index = Index(index, unit=unit, copy=False)
-        setattr(self, origin, index[0])
-        if index.regular:
-            setattr(self, delta, index[1] - index[0])
-        else:
-            delattr(self, delta)
+
+        # reset other axis attributes
+        if index.size:
+            setattr(self, origin, index[0])
+        if index.size > 1:
+            if index.regular:  # delta will reset from index
+                setattr(self, delta, index[1] - index[0])
+            else:
+                delattr(self, delta)
+
+        # update index array
         setattr(self, "_{}".format(key), index)
 
     def _index_span(self, axis):
@@ -255,7 +266,10 @@ class Series(Array):
         try:
             return self._x0
         except AttributeError:
-            self._x0 = Quantity(0, self.xunit)
+            try:
+                self._x0 = self._xindex[0]
+            except (AttributeError, IndexError):
+                self._x0 = Quantity(0, self.xunit)
             return self._x0
 
     @x0.setter
@@ -645,32 +659,79 @@ class Series(Array):
         `~Series.unit` match.
         """
         if isinstance(other, type(self)):
-            # check step size, if possible
-            try:
-                if not self.dx == other.dx:
-                    raise ValueError("%s sample sizes do not match: "
-                                     "%s vs %s." % (type(self).__name__,
-                                                    self.dx, other.dx))
-            except AttributeError:
-                raise ValueError("Series with irregular xindexes cannot "
-                                 "be compatible")
-            # check units
-            if not self.unit == other.unit and not (
-                    self.unit in [dimensionless_unscaled, None]
-                    and other.unit in [dimensionless_unscaled, None]
+            return self._is_compatible_gwpy(other)
+        return self._is_compatible_numpy(other)
+
+    def _compatibility_error(self, other, attr, name):
+        return ValueError(
+            "{} {} do not match: {} vs {}".format(
+                type(self).__name__,
+                name,
+                getattr(self, attr, "none"),
+                getattr(other, attr, "none")
+            ),
+        )
+
+    def _compare_index(self, other, axis="x"):
+        """Compare index attributes/arrays between self and other
+
+        Raises
+        ------
+        ValueError
+            if ``dx`` doesn't match, or ``xindex`` values are not present/are
+            identical (as appropriate)
+        """
+        try:  # check step size, if possible
+            _delta = "d{}".format(axis)
+            deltaa = getattr(self, _delta)
+            deltab = getattr(other, _delta)
+            if deltaa != deltab:
+                raise self._compatibility_error(
+                    other,
+                    _delta,
+                    "{}-axis sample sizes".format(axis),
+                )
+        except AttributeError:  # irregular index
+            _index = "_{}index".format(axis)
+            idxa = getattr(self, _index, None)
+            idxb = getattr(other, _index, None)
+            if (
+                idxa is None  # no index on 'self'
+                or idxb is None  # no index on 'other'
+                or not numpy.array_equal(idxa, idxb)  # indexes don't match
             ):
-                raise ValueError("%s units do not match: %s vs %s."
-                                 % (type(self).__name__, str(self.unit),
-                                    str(other.unit)))
-        else:
-            # assume an array-like object, and just check that the shape
-            # and dtype match
-            arr = numpy.asarray(other)
-            if arr.ndim != self.ndim:
-                raise ValueError("Dimensionality does not match")
-            if arr.dtype != self.dtype:
-                warn("Array data types do not match: %s vs %s"
-                     % (self.dtype, other.dtype))
+                raise self._compatibility_error(
+                    other,
+                    _index,
+                    "{}-axis indexes".format(axis),
+                )
+
+    def _is_compatible_gwpy(self, other):
+        """Check whether this series and another series are compatible
+        """
+        self._compare_index(other, axis="x")
+
+        # check units
+        if not (
+            self.unit == other.unit
+            or {self.unit, other.unit}.issubset(
+                {dimensionless_unscaled, None},
+            )
+        ):
+            raise self._compatibility_error(other, "unit", "units")
+
+        # compatibility!
+        return True
+
+    def _is_compatible_numpy(self, other):
+        """Check whether this series and a numpy.ndarray are compatible
+        """
+        arr = numpy.asarray(other)
+        if arr.ndim != self.ndim:
+            raise ValueError("Dimensionality does not match")
+        if arr.dtype != self.dtype:
+            warn("Array data types do not match: %s vs %s"
+                 % (self.dtype, other.dtype))
         return True
 
     def append(self, other, inplace=True, pad=None, gap=None, resize=True):
@@ -778,8 +839,7 @@ class Series(Array):
             N = min(self.shape[0], other.shape[0])
 
         # if units are the same, can shortcut
-        # NOTE: why not use isinstance here?
-        if type(other) == type(self) and other.unit == self.unit:
+        if isinstance(other, Series) and other.unit == self.unit:
             self.value[-N:] = other.value[-N:]
         # otherwise if its just a numpy array
         elif type(other) is type(self.value) or (  # noqa: E721
@@ -886,25 +946,26 @@ class Series(Array):
         Parameters
         ----------
         start : `float`, optional
-            lower limit of x-axis to crop to, defaults to
-            current `~Series.x0`
+            Lower limit of x-axis to crop to, defaults to
+            :attr:`~Series.x0`.
 
         end : `float`, optional
-            upper limit of x-axis to crop to, defaults to current series end
+            Upper limit of x-axis to crop to, defaults to series end.
 
-        copy : `bool`, optional, default: `False`
-            copy the input data to fresh memory, otherwise return a view
+        copy : `bool`, optional
+            Copy the input data to fresh memory,
+            otherwise return a view (default).
 
         Returns
         -------
         series : `Series`
-            A new series with a sub-set of the input data
+            A new series with a sub-set of the input data.
 
         Notes
         -----
         If either ``start`` or ``end`` are outside of the original
         `Series` span, warnings will be printed and the limits will
-        be restricted to the :attr:`~Series.xspan`
+        be restricted to the :attr:`~Series.xspan`.
         """
         x0, x1 = self.xspan
         xtype = type(x0)
@@ -917,33 +978,53 @@ class Series(Array):
         if start == x0:
             start = None
         elif start is not None and xtype(start) < x0:
-            warn('%s.crop given start smaller than current start, '
-                 'crop will begin when the Series actually starts.'
-                 % type(self).__name__)
+            warn(
+                f"{type(self).__name__}.crop given start smaller than current "
+                "start, crop will begin when the Series actually starts.",
+            )
             start = None
 
         # pin late ends to time-series end
         if end == x1:
             end = None
         if end is not None and xtype(end) > x1:
-            warn('%s.crop given end larger than current end, '
-                 'crop will end when the Series actually ends.'
-                 % type(self).__name__)
+            warn(
+                f"{type(self).__name__}.crop given end larger than current "
+                "end, crop will begin when the Series actually ends.",
+            )
             end = None
 
+        # check if series is irregular
+        try:
+            self.dx
+        except AttributeError:
+            irregular = True
+        else:
+            irregular = False
+
         # find start index
         if start is None:
             idx0 = None
+        elif irregular:
+            idx0 = numpy.searchsorted(
+                self.xindex.value,
+                xtype(start),
+                side="left",
+            )
         else:
-            idx0 = int((xtype(start) - x0) // self.dx.value)
+            idx0 = floor((xtype(start) - x0) / self.dx.value)
 
         # find end index
         if end is None:
             idx1 = None
+        elif irregular:
+            idx1 = numpy.searchsorted(
+                self.xindex.value,
+                xtype(end),
+                side="left",
+            )
         else:
-            idx1 = int((xtype(end) - x0) // self.dx.value)
-            if idx1 >= self.size:
-                idx1 = None
+            idx1 = floor((xtype(end) - x0) / self.dx.value)
 
         # crop
         if copy:
