@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2018-2021)
+# Copyright (C) Duncan Macleod (2018-2020)
 #
 # This file is part of GWpy.
 #
@@ -107,7 +107,11 @@ def null_slice(slice_):
     except TypeError:
         return False
 
-    if isinstance(slice_, numpy.ndarray) and numpy.all(slice_):
+    if (
+        isinstance(slice_, numpy.ndarray)
+        and slice_.dtype == bool
+        and slice_.all()
+    ):
         return True
     if isinstance(slice_, slice) and slice_ in (
             slice(None, None, None), slice(0, None, 1)
