@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2018-2021)
+# Copyright (C) Duncan Macleod (2018-2020)
 #
 # This file is part of GWpy.
 #
@@ -193,17 +193,44 @@ class TestArray2D(_TestSeries):
             exclude=['epoch'],
         )
 
-    def test_is_compatible(self, array):
-        super().test_is_compatible(array)
+    def test_single_column_slice(self):
+        """Check that we can slice an `Array2D` into a single column.
 
-        a2 = self.create(dy=2)
-        with pytest.raises(ValueError):
-            array.is_compatible(a2)
+        But still represent the output as an `Array2D` with `Index` arrays.
 
-        y = numpy.logspace(0, 2, num=self.data.shape[0])
-        a2 = self.create(yindex=y)
-        with pytest.raises(ValueError):
-            array.is_compatible(a2)
+        This tests regression of https://gitlab.com/gwpy/gwpy/-/issues/1504.
+        """
+        # create an array with indices
+        a = self.create()
+        a.xindex
+        a.yindex
+
+        # select a slice of width 1 (as opposed to indexing a single column)
+        b = a[0:1]
+
+        # and check that the index arrays were correctly preserved
+        assert isinstance(b, self.TEST_CLASS)
+        for attr in ("x0", "dx", "xunit", "y0", "dy", "yunit"):
+            assert getattr(a, attr) == getattr(b, attr)
+        utils.assert_array_equal(b[0], a[0])
+        utils.assert_array_equal(b.xindex, a.xindex[0:1])
+        utils.assert_array_equal(b.yindex, a.yindex)
+
+    def test_is_compatible_yindex(self):
+        """Check that irregular arrays are compatible if their yindexes match
+        """
+        y = numpy.logspace(0, 2, num=self.data.shape[1])
+        a = self.create(yindex=y)
+        b = self.create(yindex=y)
+        assert a.is_compatible(b)
+
+    def test_is_compatible_error_yindex(self, array):
+        """Check that `Array2D.is_compatible` errors with mismatching indexes
+        """
+        y = numpy.logspace(0, 2, num=self.data.shape[1])
+        other = self.create(yindex=y)
+        with pytest.raises(ValueError, match="indexes do not match"):
+            array.is_compatible(other)
 
     def test_value_at(self, array):
         assert array.value_at(2, 3) == self.data[2][3] * array.unit
@@ -212,14 +239,14 @@ class TestArray2D(_TestSeries):
         with pytest.raises(IndexError):
             array.value_at(1.6, 4.8)
 
-    @pytest.mark.skip("not implemented for >1D arrays")
     def test_pad(self):
-        return NotImplemented
+        pytest.skip("not implemented for >1D arrays")
 
-    @pytest.mark.skip("not implemented for >1D arrays")
     def test_pad_index(self):
-        return NotImplemented
+        pytest.skip("not implemented for >1D arrays")
 
-    @pytest.mark.skip("not implemented for >1D arrays")
     def test_pad_asymmetric(self):
-        return NotImplemented
+        pytest.skip("not implemented for >1D arrays")
+
+    def test_single_getitem_not_created(self):
+        pytest.skip("not implemented for >1D arrays")
