@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -22,7 +22,9 @@ This module requires lal >= 6.14.0
 """
 
 import operator
+import re
 from collections import OrderedDict
+from fractions import Fraction
 from functools import reduce
 
 import numpy
@@ -70,6 +72,9 @@ LAL_TYPE_FROM_NUMPY = {
 
 LAL_TYPE_STR_FROM_NUMPY = {k: LAL_TYPE_STR[v] for
                            (k, v) in LAL_TYPE_FROM_NUMPY.items()}
+LAL_NUMPY_FROM_TYPE_STR = {v: k for k, v in LAL_TYPE_STR_FROM_NUMPY.items()}
+
+LAL_TYPE_REGEX = re.compile(r'(U?INT|REAL|COMPLEX)\d+')
 
 
 def to_lal_type_str(pytype):
@@ -144,36 +149,48 @@ def find_typed_function(pytype, prefix, suffix, module=lal):
     return getattr(module, '{0}{1}{2}'.format(prefix, laltype, suffix))
 
 
+def from_lal_type(laltype):
+    """Convert the data type of a LAL instance or type into a numpy data type.
+
+    Parameters
+    ----------
+    laltype : `SwigPyObject` or `type`
+        the input LAL instance or type
+
+    Returns
+    -------
+    dtype : `type`
+        the numpy data type, such as `numpy.uint32`, `numpy.float64`, etc.
+
+    Raises
+    ------
+    ValueError
+        if the numpy data type cannot be inferred from the LAL object
+    """
+    if not isinstance(laltype, type):
+        laltype = type(laltype)
+    name = laltype.__name__
+    match = LAL_TYPE_REGEX.match(name)
+    if not match or match[0] not in LAL_NUMPY_FROM_TYPE_STR:
+        raise ValueError(f'{name!r} has no known numpy type equivalent')
+    return LAL_NUMPY_FROM_TYPE_STR[match[0]]
+
+
 # -- units --------------------------------------------------------------------
 
 LAL_UNIT_INDEX = [  # the order corresponds to how LAL stores compound units
-    lal.MeterUnit,
-    lal.KiloGramUnit,
-    lal.SecondUnit,
-    lal.AmpereUnit,
-    lal.KelvinUnit,
-    lal.StrainUnit,
-    lal.ADCCountUnit,
+    units.meter,
+    units.kilogram,
+    units.second,
+    units.ampere,
+    units.Kelvin,
+    units.Unit('strain'),
+    units.count,
 ]
 
 
-def _lal_unit_from_astropy(u):
-    """Convert an `astropy.units.Unit` into a `lal.Unit`
-    """
-    for lalu in LAL_UNIT_INDEX:
-        if u == units.Unit(str(lalu)):
-            return lalu
-    raise KeyError(str(u))
-
-
 def to_lal_unit(aunit):
-    """Convert the input unit into a `LALUnit`
-
-    For example::
-
-       >>> u = to_lal_unit('m**2 / kg ** 4')
-       >>> print(u)
-       m^2 kg^-4
+    """Convert the input unit into a `lal.Unit` and a scaling factor.
 
     Parameters
     ----------
@@ -182,33 +199,70 @@ def to_lal_unit(aunit):
 
     Returns
     -------
-    unit : `LALUnit`
-        the LALUnit representation of the input
+    unit : `lal.Unit`
+        the LAL representation of the base unit.
+
+    scale : `float`
+        the linear scaling factor that should be applied to any associated
+        data, see _Notes_ below.
+
+    Notes
+    -----
+    Astropy supports 'scaled' units of the form ``<N> <u>``
+    ere ``<N>`` is a `float` and ``<u>`` the base `astropy.units.Unit`,
+    e.g. ``'123 m'``, e.g:
+
+    >>> from astropy.units import Quantity
+    >>> x = Quantity(4, '123m')
+    >>> print(x)
+    4.0 123 m
+    >>> print(x.decompose())
+    492.0 m
+
+    LAL doesn't support scaled units in this way, so this function simply
+    returns the scaling factor of the unit so that it may be applied
+    manually to any associated data.
+
+    Examples
+    --------
+    >>> print(to_lal_unit('m**2 / kg ** 4'))
+    (m^2 kg^-4, 1.0)
+    >>> print(to_lal_unit('123 m'))
+    (m, 123.0)
 
     Raises
     ------
     ValueError
         if LAL doesn't understand the base units for the input
     """
+    # format incoming unit
     if isinstance(aunit, str):
         aunit = units.Unit(aunit)
     aunit = aunit.decompose()
-    lunit = lal.Unit()
+
+    # handle scaled units
+    pow10 = numpy.log10(aunit.scale)
+    if pow10 and pow10.is_integer():
+        lunit = lal.Unit(f"10^{int(pow10)}")
+        scale = 1
+    else:
+        lunit = lal.Unit()
+        scale = aunit.scale
+
+    # decompose unit into LAL base units
     for base, power in zip(aunit.bases, aunit.powers):
         try:  # try this base
-            lalbase = _lal_unit_from_astropy(base)
-        except KeyError:  # otherwise loop through the equivalent bases
-            for eqbase in base.find_equivalent_units():
-                try:
-                    lalbase = _lal_unit_from_astropy(eqbase)
-                except KeyError:
-                    continue
-                break
-            # if we didn't find anything, raise an exception
-            else:
-                raise ValueError("LAL has no unit corresponding to %r" % base)
-        lunit *= lalbase ** power
-    return lunit
+            i = LAL_UNIT_INDEX.index(base)
+        except ValueError as exc:
+            exc.args = (
+                f"LAL has no unit corresponding to '{base}'",
+            )
+            raise
+        frac = Fraction(power)
+        lunit.unitNumerator[i] = frac.numerator
+        lunit.unitDenominatorMinusOne[i] = frac.denominator - 1
+
+    return lunit, scale
 
 
 def from_lal_unit(lunit):
@@ -231,9 +285,16 @@ def from_lal_unit(lunit):
     ValueError
         if Astropy doesn't understand the base units for the input
     """
-    return reduce(operator.mul, (
-        units.Unit(str(LAL_UNIT_INDEX[i])) ** exp for
-        i, exp in enumerate(lunit.unitNumerator)))
+    return reduce(
+        operator.mul,
+        (
+            LAL_UNIT_INDEX[i] ** Fraction(int(num), int(den + 1))
+            for i, (num, den) in enumerate(zip(
+                lunit.unitNumerator,
+                lunit.unitDenominatorMinusOne,
+            ))
+        ),
+    ) * 10**lunit.powerOfTen
 
 
 def to_lal_ligotimegps(gps):
