@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2014-2021)
+# Copyright (C) Duncan Macleod (2014-2020)
 #
 # This file is part of GWpy.
 #
@@ -42,7 +42,8 @@ def test_gprint(capsys):
 def test_null_context():
     """Test for :func:`gwpy.utils.misc.null_context`
     """
-    ctx = utils_misc.null_context()
+    with pytest.warns(DeprecationWarning):
+        ctx = utils_misc.null_context()
     with ctx:
         print('this should work')
 
@@ -59,16 +60,17 @@ def test_round_to_power():
     base = 10.
     rounded = utils_misc.round_to_power(9, base=base)
     assert base == rounded
-    assert type(base) == type(rounded)
+    assert type(base) == type(rounded)  # noqa: E721
 
 
 def test_round_to_power_error():
     """Test for an errored use case of :func:`gwpy.utils.misc.round_to_power`
     """
-    with pytest.raises(ValueError) as exc:
+    with pytest.raises(
+        ValueError,
+        match="^'which' argument must be one of 'lower', 'upper', or None$",
+    ):
         utils_misc.round_to_power(7, which='')
-    assert str(exc.value) == (
-        "'which' argument must be one of 'lower', 'upper', or None")
 
 
 def test_unique():
